/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizappointmentrecord.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import jakarta.servlet.http.HttpServletResponse;
import org.apache.commons.lang3.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.biz.modular.bizappointmentrecord.param.*;
import vip.xiaonuo.biz.modular.bizorder.param.BizOrderPageParam;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.annotation.CommonNoRepeat;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.bizappointmentrecord.entity.BizAppointmentRecord;
import vip.xiaonuo.biz.modular.bizappointmentrecord.service.BizAppointmentRecordService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;

import java.io.IOException;
import java.util.List;
import java.util.Map;

/**
 * 预约记录控制器
 *
 * @author fanzherong
 * @date  2025/03/24 14:47
 */
@Tag(name = "预约记录控制器")
@RestController
@Validated
public class BizAppointmentRecordController {

    @Resource
    private BizAppointmentRecordService bizAppointmentRecordService;

    /**
     * 获取预约记录分页
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    @Operation(summary = "获取预约记录分页")
    @SaCheckPermission("/biz/bizappointmentrecord/page")
    @GetMapping("/biz/bizappointmentrecord/page")
    public CommonResult<Page<BizAppointmentRecord>> page(BizAppointmentRecordPageParam bizAppointmentRecordPageParam) {
        return CommonResult.data(bizAppointmentRecordService.page(bizAppointmentRecordPageParam));
    }

    /**
     * 添加预约记录
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    @Operation(summary = "添加预约记录")
    @CommonLog("添加预约记录")
    @CommonNoRepeat
    @PostMapping("/biz/bizappointmentrecord/add")
    public CommonResult<String> add(@RequestBody @Valid BizAppointmentRecordAddParam bizAppointmentRecordAddParam) {
        bizAppointmentRecordService.add(bizAppointmentRecordAddParam);
        return CommonResult.ok();
    }


    /**
     * 添加临时预约记录
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    @Operation(summary = "添加临时预约记录")
    @CommonLog("添加临时预约记录")
    @CommonNoRepeat
    @PostMapping("/biz/bizappointmentrecord/addTemp")
    public CommonResult<String> addTemp(@RequestBody @Valid BizAppointmentRecordAddParam bizAppointmentRecordAddParam) {
        bizAppointmentRecordService.addTemp(bizAppointmentRecordAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑预约记录
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    @Operation(summary = "编辑预约记录")
    @CommonLog("编辑预约记录")
    @PostMapping("/biz/bizappointmentrecord/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        bizAppointmentRecordService.edit(bizAppointmentRecordEditParam);
        return CommonResult.ok();
    }

    /**
     * 编辑临时预约记录
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    @Operation(summary = "编辑临时预约记录")
    @CommonLog("编辑临时预约记录")
    @PostMapping("/biz/bizappointmentrecord/editTemp")
    public CommonResult<String> editTemp(@RequestBody @Valid BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        bizAppointmentRecordService.editTemp(bizAppointmentRecordEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除预约记录
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    @Operation(summary = "删除预约记录")
    @CommonLog("删除预约记录")
    @PostMapping("/biz/bizappointmentrecord/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizAppointmentRecordIdParam> bizAppointmentRecordIdParamList) {
        bizAppointmentRecordService.delete(bizAppointmentRecordIdParamList);
        return CommonResult.ok();
    }

    /**
     * 司机调度订单
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    @Operation(summary = "司机调度订单")
    @CommonLog("司机调度订单")
    @PostMapping("/biz/bizappointmentrecord/replaceAppoint")
    public CommonResult<String> replaceAppoint(@RequestBody @Valid BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        bizAppointmentRecordService.replaceAppoint(bizAppointmentRecordEditParam);
        return CommonResult.ok();
    }

    /**
     * 获取预约记录详情
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    @Operation(summary = "获取预约记录详情")
    @GetMapping("/biz/bizappointmentrecord/detail")
    public CommonResult<BizAppointmentRecord> detail(@Valid BizAppointmentRecordIdParam bizAppointmentRecordIdParam) {
        return CommonResult.data(bizAppointmentRecordService.detail(bizAppointmentRecordIdParam));
    }


    /**
     * 审核
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    @Operation(summary = "审核")
    @CommonLog("审核")
    @PostMapping("/biz/bizappointmentrecord/auditRecord")
    public CommonResult<String> auditRecord(@RequestBody @Valid BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        bizAppointmentRecordService.auditRecord(bizAppointmentRecordEditParam);
        return CommonResult.ok();
    }

    /**
     * 审核临时预约
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    @Operation(summary = "审核临时预约")
    @CommonLog("审核临时预约")
    @PostMapping("/biz/bizappointmentrecord/auditTemp")
    public CommonResult<String> auditTemp(@RequestBody @Valid BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        bizAppointmentRecordService.auditTemp(bizAppointmentRecordEditParam);
        return CommonResult.ok();
    }


    /**
     * 导出预约报表
     */
    @Operation(summary = "导出预约报表")
    @SaCheckPermission("/biz/bizappointmentrecord/exportRecord")
    @GetMapping(value = "/biz/bizappointmentrecord/exportRecord", produces = MediaType.APPLICATION_OCTET_STREAM_VALUE)
    public void exportRecord(BizAppointmentRecordPageParam bizAppointmentRecordPageParam, HttpServletResponse response) throws IOException {
        bizAppointmentRecordService.exportRecord(bizAppointmentRecordPageParam,response);
    }

    /**
     * 地磅端校验是否有预约
     */
    @Operation(summary = "地磅端校验是否有预约")
    @GetMapping(value = "/biz/bizappointmentrecord/checkAppointmentRecord")
    public CommonResult<BizAppointmentRecord> checkAppointmentRecord(BizAppointmentRecordPageParam bizAppointmentRecordPageParam) {
        BizAppointmentRecord bizAppointmentRecord = bizAppointmentRecordService.checkAppointmentRecord(bizAppointmentRecordPageParam);
        if(StringUtils.equals(bizAppointmentRecord.getIsFlag(),"4")){
            return CommonResult.get(201,"没有待入场记录，不可过门禁！",null);
        }else if(StringUtils.equals(bizAppointmentRecord.getIsFlag(),"5")){
            return CommonResult.get(202,"没有已入场记录，不可一次过磅！",null);
        }else if(StringUtils.equals(bizAppointmentRecord.getIsFlag(),"7")){
            return CommonResult.get(203,"没有完成装货记录，不可二次过磅！",null);
        }else if(StringUtils.equals(bizAppointmentRecord.getIsFlag(),"9")){
            return CommonResult.get(204,"没有待出场记录，不可出门禁！",null);
        }else if(ObjectUtil.isEmpty(bizAppointmentRecord.getIsFlag())){
            return CommonResult.get(205,"流程异常，请联系管理员",null);
        }
        return CommonResult.get(200,"操作成功",bizAppointmentRecord);
    }

    /**
     * 取消排队
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    @Operation(summary = "取消排队")
    @CommonLog("取消排队")
    @PostMapping("/biz/bizappointmentrecord/cancelAppointmentRecord")
    public CommonResult<String> cancelAppointmentRecord(@RequestBody @Valid BizAppointmentRecordIdParam bizAppointmentRecordIdParam) {
        bizAppointmentRecordService.cancelAppointmentRecord(bizAppointmentRecordIdParam);
        return CommonResult.ok();
    }

    /**
     * 调整订单
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    @Operation(summary = "调整订单")
    @CommonLog("调整订单")
    @PostMapping("/biz/bizappointmentrecord/adjustOrder")
    public CommonResult<String> adjustOrder(@RequestBody @Valid BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        bizAppointmentRecordService.adjustOrder(bizAppointmentRecordEditParam);
        return CommonResult.ok();
    }

    /**
     * 车辆执行状态分析
     */
    @Operation(summary = "车辆执行状态分析")
    @GetMapping("/biz/bizappointmentrecord/gerVehicleTotal")
    public CommonResult<List<Map<String,Object>>> gerVehicleTotal(BizAppointmentRecordPageParam bizAppointmentRecordPageParam){
        return CommonResult.data(bizAppointmentRecordService.gerVehicleTotal(bizAppointmentRecordPageParam));
    }


    /**
     * 取消预约
     */
    @Operation(summary = "取消预约")
    @CommonLog("取消预约")
    @PostMapping("/biz/bizappointmentrecord/cancel")
    public CommonResult<String> cancel(@RequestBody BizAppointmentRecordIdParam bizAppointmentRecordIdParam){
        bizAppointmentRecordService.cancel(bizAppointmentRecordIdParam);
        return CommonResult.ok();
    }

    /**
     * 授权出场
     */
    @Operation(summary = "授权出场")
    @CommonLog("授权出场")
    @PostMapping("/biz/bizappointmentrecord/exit")
    public CommonResult<String> exit(@RequestBody BizAppointmentRecordIdParam bizAppointmentRecordIdParam){
        bizAppointmentRecordService.exit(bizAppointmentRecordIdParam);
        return CommonResult.ok();
    }

    /**
     * 临时预约授权出场
     */
    @Operation(summary = "临时预约授权出场")
    @CommonLog("授权出场")
    @PostMapping("/biz/bizappointmentrecord/exitTemp")
    public CommonResult<String> exitTemp(@RequestBody BizAppointmentRecordIdParam bizAppointmentRecordIdParam){
        bizAppointmentRecordService.exitTemp(bizAppointmentRecordIdParam);
        return CommonResult.ok();
    }


    /**
     * 添加起卸预约
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    @Operation(summary = "添加起卸预约")
    @CommonLog("添加起卸预约")
    @CommonNoRepeat
    @PostMapping("/biz/bizappointmentrecord/addLoad")
    public CommonResult<String> addLoad(@RequestBody @Valid BizAppointmentRecordAddParam bizAppointmentRecordAddParam) {
        bizAppointmentRecordService.addLoad(bizAppointmentRecordAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑起卸预约记录
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    @Operation(summary = "编辑起卸预约记录")
    @CommonLog("编辑起卸预约记录")
    @PostMapping("/biz/bizappointmentrecord/editLoad")
    public CommonResult<String> editLoad(@RequestBody @Valid BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        bizAppointmentRecordService.editLoad(bizAppointmentRecordEditParam);
        return CommonResult.ok();
    }

    /**
     * 获取起卸预约列表
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    @Operation(summary = "获取起卸预约列表")
    @SaCheckPermission("/biz/bizappointmentrecord/getLoadPage")
    @GetMapping("/biz/bizappointmentrecord/getLoadPage")
    public CommonResult<Page<BizAppointmentRecord>> getLoadPage(BizAppointmentRecordPageParam bizAppointmentRecordPageParam) {
        return CommonResult.data(bizAppointmentRecordService.getLoadPage(bizAppointmentRecordPageParam));
    }

    /**
     * 起卸预约_强制结束
     */
    @Operation(summary = "起卸预约_强制结束")
    @CommonLog("起卸预约_强制结束")
    @PostMapping("/biz/bizappointmentrecord/endLoadAppoint")
    public CommonResult<String> endLoadAppoint(@RequestBody @Valid BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        bizAppointmentRecordService.endLoadAppoint(bizAppointmentRecordEditParam);
        return CommonResult.ok();
    }


    /**
     * 导出起卸预约报表
     */
    @Operation(summary = "导出起卸预约报表")
    @SaCheckPermission("/biz/bizappointmentrecord/exportLoadRecord")
    @GetMapping(value = "/biz/bizappointmentrecord/exportLoadRecord", produces = MediaType.APPLICATION_OCTET_STREAM_VALUE)
    public void exportLoadRecord(BizAppointmentRecordPageParam bizAppointmentRecordPageParam, HttpServletResponse response) throws IOException {
        bizAppointmentRecordService.exportLoadRecord(bizAppointmentRecordPageParam,response);
    }

    /**
     * 导出管桩预约报表
     */
    @Operation(summary = "导出管桩预约报表")
    @SaCheckPermission("/biz/bizappointmentrecord/exportPipeRecord")
    @GetMapping(value = "/biz/bizappointmentrecord/exportPipeRecord", produces = MediaType.APPLICATION_OCTET_STREAM_VALUE)
    public void exportPipeRecord(BizAppointmentRecordPageParam bizAppointmentRecordPageParam, HttpServletResponse response) throws IOException {
        bizAppointmentRecordService.exportPipeRecord(bizAppointmentRecordPageParam,response);
    }

    /**
     * 添加管桩预约
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    @Operation(summary = "添加管桩预约")
    @CommonLog("添加管桩预约")
    @CommonNoRepeat
    @PostMapping("/biz/bizappointmentrecord/addPipeAppoint")
    public CommonResult<String> addPipeAppoint(@RequestBody @Valid BizAppointmentRecordAddParam bizAppointmentRecordAddParam) {
        bizAppointmentRecordService.addPipeAppoint(bizAppointmentRecordAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑管桩预约记录
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    @Operation(summary = "编辑管桩预约记录")
    @CommonLog("编辑管桩预约记录")
    @PostMapping("/biz/bizappointmentrecord/editPipeAppoint")
    public CommonResult<String> editPipeAppoint(@RequestBody @Valid BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        bizAppointmentRecordService.editPipeAppoint(bizAppointmentRecordEditParam);
        return CommonResult.ok();
    }

    /**
     * 管桩预约完成装货
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    @Operation(summary = "管桩预约完成装货")
    @CommonLog("管桩预约完成装货")
    @PostMapping("/biz/bizappointmentrecord/completePipeAppoint")
    public CommonResult<String> completePipeAppoint(@RequestBody @Valid BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        bizAppointmentRecordService.completePipeAppoint(bizAppointmentRecordEditParam);
        return CommonResult.ok();
    }

    /**
     * 获取管桩预约列表
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    @Operation(summary = "获取管桩预约列表")
    @SaCheckPermission("/biz/bizappointmentrecord/getPipePage")
    @GetMapping("/biz/bizappointmentrecord/getPipePage")
    public CommonResult<Page<BizAppointmentRecord>> getPipePage(BizAppointmentRecordPageParam bizAppointmentRecordPageParam) {
        return CommonResult.data(bizAppointmentRecordService.getPipePage(bizAppointmentRecordPageParam));
    }

    /**
     * 取消管桩预约记录
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    @Operation(summary = "取消管桩预约记录")
    @CommonLog("取消管桩预约记录")
    @PostMapping("/biz/bizappointmentrecord/replacePipeAppoint")
    public CommonResult<String> replacePipeAppoint(@RequestBody @Valid BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        bizAppointmentRecordService.replacePipeAppoint(bizAppointmentRecordEditParam);
        return CommonResult.ok();
    }

    /**
     * 管桩预约_强制结束
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    @Operation(summary = "管桩预约_强制结束")
    @CommonLog("管桩预约_强制结束")
    @PostMapping("/biz/bizappointmentrecord/endPipeAppoint")
    public CommonResult<String> endPipeAppoint(@RequestBody @Valid BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        bizAppointmentRecordService.endPipeAppoint(bizAppointmentRecordEditParam);
        return CommonResult.ok();
    }

    /**
     * 其他预约_记录分页
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    @Operation(summary = "其他预约_记录分页")
    @SaCheckPermission("/biz/bizotherappointment/page")
    @GetMapping("/biz/bizotherappointment/page")
    public CommonResult<Page<BizAppointmentRecord>> bizOtherAppointmentPage(BizAppointmentRecordPageParam bizAppointmentRecordPageParam) {
        return CommonResult.data(bizAppointmentRecordService.page(bizAppointmentRecordPageParam));
    }


    /**
     * 其他预约_添加
     *
     * @author xumudong
     * @date  2025/07/02 11:47
     */
    @Operation(summary = "其他预约_添加")
    @CommonLog("其他预约_添加")
    @CommonNoRepeat
    @PostMapping("/biz/bizotherappointment/addOtherAppointment")
    public CommonResult<String> addOtherAppointment(@RequestBody @Valid BizOtherAppointmentAddParam bizOtherAppointmentAddParam) {
        bizAppointmentRecordService.addOtherAppointment(bizOtherAppointmentAddParam);
        return CommonResult.ok();
    }

    /**
     * 其他预约_编辑
     *
     * @author xumudong
     * @date  2025/07/02 11:47
     */
    @Operation(summary = "其他预约_编辑")
    @CommonLog("其他预约_编辑")
    @PostMapping("/biz/bizotherappointment/editOtherAppointment")
    public CommonResult<String> editOtherAppointment(@RequestBody @Valid BizOtherAppointmentEditParam bizOtherAppointmentEditParam) {
        bizAppointmentRecordService.editOtherAppointment(bizOtherAppointmentEditParam);
        return CommonResult.ok();
    }
    /**
     * 其他预约_删除
     *
     * @author xumudong
     * @date  2025/07/02 11:47
     */
    @Operation(summary = "其他预约_删除")
    @CommonLog("其他预约_删除")
    @PostMapping("/biz/bizotherappointment/deleteOtherAppointment")
    public CommonResult<String> deleteOtherAppointment(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                               List<BizAppointmentRecordIdParam> bizAppointmentRecordIdParamList) {
        bizAppointmentRecordService.delete(bizAppointmentRecordIdParamList);
        return CommonResult.ok();
    }


    /**
     * 其他预约_强制结束
     */
    @Operation(summary = "其他预约_强制结束")
    @CommonLog("其他预约_强制结束")
    @PostMapping("/biz/bizotherappointment/bizOtherAppointmentExit")
    public CommonResult<String> bizOtherAppointmentExit(@RequestBody BizAppointmentRecordIdParam bizAppointmentRecordIdParam){
        bizAppointmentRecordService.bizOtherAppointmentExit(bizAppointmentRecordIdParam);
        return CommonResult.ok();
    }

    /**
     * 其他预约_完成装货
     */
    @Operation(summary = "其他预约_完成装货")
    @CommonLog("其他预约_完成装货")
    @PostMapping("/biz/bizotherappointment/bizOtherAppointmentComplete")
    public CommonResult<String> bizOtherAppointmentComplete(@RequestBody BizAppointmentRecordIdParam bizAppointmentRecordIdParam){
        bizAppointmentRecordService.bizOtherAppointmentComplete(bizAppointmentRecordIdParam);
        return CommonResult.ok();
    }

    /**
     * 其他预约_授权离场
     */
    @Operation(summary = "其他预约_授权离场")
    @CommonLog("其他预约_授权离场")
    @PostMapping("/biz/bizotherappointment/bizOtherAppointmentAuthorize")
    public CommonResult<String> bizOtherAppointmentAuthorize(@RequestBody BizAppointmentRecordIdParam bizAppointmentRecordIdParam){
        bizAppointmentRecordService.bizOtherAppointmentAuthorize(bizAppointmentRecordIdParam);
        return CommonResult.ok();
    }



    /**
     * 临时预约_导出
     */
    @Operation(summary = "临时预约_导出")
    @SaCheckPermission("/biz/bizotherappointment/bizOtherAppointmentExport")
    @GetMapping(value = "/biz/bizotherappointment/bizOtherAppointmentExport", produces = MediaType.APPLICATION_OCTET_STREAM_VALUE)
    public void bizOtherAppointmentExport(BizAppointmentRecordPageParam bizAppointmentRecordPageParam, HttpServletResponse response) throws IOException {
        bizAppointmentRecordService.bizOtherAppointmentExport(bizAppointmentRecordPageParam,response);
    }




    /**
     * 充电预约_记录分页
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    @Operation(summary = "充电预约_记录分页")
    @SaCheckPermission("/biz/bizchargestationreservation/page")
    @GetMapping("/biz/bizchargestationreservation/page")
    public CommonResult<Page<BizAppointmentRecord>> bizchargestationreservationPage(BizAppointmentRecordPageParam bizAppointmentRecordPageParam) {
        return CommonResult.data(bizAppointmentRecordService.page(bizAppointmentRecordPageParam));
    }


    /**
     * 充电预约__添加
     *
     * @author xumudong
     * @date  2025/07/02 11:47
     */
    @Operation(summary = "充电预约__添加")
    @CommonLog("充电预约__添加")
    @CommonNoRepeat
    @PostMapping("/biz/bizchargestationreservation/addChargeStationReservation")
    public CommonResult<String> addChargeStationReservation(@RequestBody @Valid BizChargeStationReservationAddParam bizChargeStationReservationAddParam) {
        bizAppointmentRecordService.addChargeStationReservation(bizChargeStationReservationAddParam);
        return CommonResult.ok();
    }


    /**
     * 充电预约_编辑
     *
     * @author xumudong
     * @date  2025/07/02 11:47
     */
    @Operation(summary = "充电预约_编辑")
    @CommonLog("充电预约_编辑")
    @PostMapping("/biz/bizchargestationreservation/editChargeStationReservation")
    public CommonResult<String> editChargeStationReservation(@RequestBody @Valid BizChargeStationReservationEditParam bizChargeStationReservationEditParam) {
        bizAppointmentRecordService.editChargeStationReservation(bizChargeStationReservationEditParam);
        return CommonResult.ok();
    }
    /**
     * 充电预约_删除
     *
     * @author xumudong
     * @date  2025/07/02 11:47
     */
    @Operation(summary = "充电预约_删除")
    @CommonLog("充电预约_删除")
    @PostMapping("/biz/bizchargestationreservation/deleteChargeStationReservation")
    public CommonResult<String> deleteChargeStationReservation(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                               List<BizAppointmentRecordIdParam> bizAppointmentRecordIdParamList) {
        bizAppointmentRecordService.deleteChargeStationReservation(bizAppointmentRecordIdParamList);
        return CommonResult.ok();
    }


    /**
     * 充电预约_充电结束
     */
    @Operation(summary = "充电预约_充电结束")
    @CommonLog("充电预约_充电结束")
    @PostMapping("/biz/bizchargestationreservation/bizChargeStationReservationExit")
    public CommonResult<String> bizChargeStationReservationExit(@RequestBody BizAppointmentRecordIdParam bizAppointmentRecordIdParam){
        bizAppointmentRecordService.bizChargeStationReservationExit(bizAppointmentRecordIdParam);
        return CommonResult.ok();
    }

    /**
     * 充电预约_强制结束
     */
    @Operation(summary = "充电预约_强制结束")
    @CommonLog("充电预约_强制结束")
    @PostMapping("/biz/bizchargestationreservation/bizChargeStationEnd")
    public CommonResult<String> bizChargeStationEnd(@RequestBody BizAppointmentRecordIdParam bizAppointmentRecordIdParam){
        bizAppointmentRecordService.bizChargeStationEnd(bizAppointmentRecordIdParam);
        return CommonResult.ok();
    }


    /**
     * 地磅端司机确认
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    @Operation(summary = "地磅端司机确认")
    @CommonLog("地磅端司机确认")
    @PostMapping("/biz/bizappointmentrecord/localConfirm")
    public CommonResult<String> localConfirm(@RequestBody @Valid BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        bizAppointmentRecordService.localConfirm(bizAppointmentRecordEditParam);
        return CommonResult.ok();
    }

    /**
     * 地磅端司机取消
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    @Operation(summary = "地磅端司机取消")
    @CommonLog("地磅端司机取消")
    @PostMapping("/biz/bizappointmentrecord/localCancel")
    public CommonResult<String> localCancel(@RequestBody @Valid BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        bizAppointmentRecordService.localCancel(bizAppointmentRecordEditParam);
        return CommonResult.ok();
    }

    /**
     * 云端司机取消
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    @Operation(summary = "云端司机取消")
    @CommonLog("云端司机取消")
    @PostMapping("/biz/bizappointmentrecord/cloudCancel")
    public CommonResult<String> cloudCancel(@RequestBody @Valid BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        bizAppointmentRecordService.cloudCancel(bizAppointmentRecordEditParam);
        return CommonResult.ok();
    }


}
