/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizappointmentrecord.entity;

import com.baomidou.mybatisplus.annotation.*;
import com.fhs.core.trans.anno.Trans;
import com.fhs.core.trans.constant.TransType;
import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.validation.constraints.NotBlank;
import lombok.Getter;
import lombok.Setter;
import vip.xiaonuo.common.pojo.CommonEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 预约记录实体
 *
 * @author fanzherong
 * @date  2025/03/24 14:47
 **/
@Getter
@Setter
@TableName("biz_appointment_record")
public class BizAppointmentRecord extends CommonEntity {

    /** 主键ID */
    @TableId
    @Schema(description = "主键ID")
    private String id;

    /** 订单id */
    @Schema(description = "订单id")
    private String orderId;

    /** 车牌号 */
    @Schema(description = "车牌号")
    private String licenseNumber;

    /** 预约时段id */
    @Schema(description = "预约时段id")
    private String timeId;

    /** 司机姓名 */
    @Schema(description = "司机姓名")
    private String driverName;

    /** 司机电话 */
    @Schema(description = "司机电话")
    private String driverMobile;
    /**
     * 司机用户ID
     */
    @Schema(description = "司机用户ID")
    private String driverId;

    /** 状态（1：待审核  2：审核不通过   3：排队中  4：可入场  5：已入场  6：一次过磅  7：完成装货   8：二次过磅   9：待出场  10：已出场   11：已签收   12:自动审核   13：销售已审核   14：已取消） */
    @Trans(type = TransType.DICTIONARY, key = "appointment_status")
    private String status;

    /**审核备注*/
    private String appointmentReason;

    /**订单编号*/
    @TableField(exist = false)
    private String orderNumber;

    /**订单名称*/
    @TableField(exist = false)
    private String orderName;

    /**客户名称*/
    @TableField(exist = false)
    private String customerName;

    /**货品名称*/
    @TableField(exist = false)
    private String goodsName;

    /**货品规格*/
    @TableField(exist = false)
    private String goodsModel;

    /**开始时间段*/
    @TableField(exist = false)
    private String beginTime;

    /**结束时间段*/
    @TableField(exist = false)
    private String endTime;

    /**标识*/
    @TableField(exist = false)
    private String isFlag;

    /**超限配置id*/
    private String overId;

    /**订单余量*/
    @TableField(exist = false)
    private BigDecimal orderBalance;

    /**超限重量*/
    @TableField(exist = false)
    private BigDecimal overWeight;

    /**订单重量校验*/
    @TableField(exist = false)
    private String orderWeightSwitch;

    @TableField(exist = false)
    /**车辆轴数*/
    private Integer axleNumber;

    /**过磅记录id*/
    @TableField(exist = false)
    private String recordId;

    /**排队号*/
    private Integer queueNumber;

    @TableField(exist = false)
    /**司机签名*/
    private String driverSign;

    @TableField(exist = false)
    /**订单类型*/
    private String orderType;

    @TableField(exist = false)
    /**卸货重量*/
    private BigDecimal unloadWeight;

    /**单据图片*/
    @TableField(exist = false)
    private String unloadImg;
    @TableField(exist = false)
    private String unloadName;

    @TableField(exist = false)
    private String customerContactName;

    @TableField(exist = false)
    private String auditSign;

    @TableField(exist = false)
    private String goodsCode;

    /**预约类型（1：订单预约   2：临时预约   3：起卸预约）*/
    @Trans(type = TransType.DICTIONARY, key = "appointment_type")
    private String appointmentType;

    /**预约分类（1、充电预约  2、管桩预约   3、其他预约）*/
    private String appointmentClassify;


    /** 收货单位 */
    @TableField(exist = false)
    private String receiptCompany;

    /** 发货单位 */
    @TableField(exist = false)
    private String shippingCompany;

    /**装卸点位id**/
    private String loadPointId;

    /**装卸时间ID**/
    private String loadTimeId;

    /**是否过磅 1-是 2-否**/
    @Trans(type = TransType.DICTIONARY, key = "is_weigh")
    private String isWeigh;

    /**备注**/
    private String remark;

    /**装卸点位*/
    @TableField(exist = false)
    private String loadPoint;

    /**装卸开始时间*/
    @TableField(exist = false)
    private String loadBeginTime;

    /**装卸结束时间*/
    @TableField(exist = false)
    private String loadEndTime;

    /**可约次数*/
    @TableField(exist = false)
    private Integer availableNumber;

    /**已约次数*/
    @TableField(exist = false)
    private Integer alreadyNumber;

    /**供应商*/
    @TableField(exist = false)
    private String supplierName;

    /**完成装货时间*/
    @TableField(exist = false)
    private Date completeSendTime;

    /**起卸单号*/
    @TableField(exist = false)
    private String loadNumber;


    /**
     * 其他预约_强制结束操作人
     */
    @Schema(description = "操作人")
    private String exitOperator;
    /**
     * 其他预约_强制结束操作时间
     */
    @Schema(description = "操作时间")
    private String exitTime;

    /**
     * 其他预约_授权离场操作人
     */
    @Schema(description = "操作人")
    private String authorizeOperator;
    /**
     * 其他预约_授权离场操作时间
     */
    @Schema(description = "操作时间")
    private String authorizeTime;

    /**管桩计划单号*/
    @TableField(exist = false)
    private String planNumber;


    /**入场时间*/
    private Date enterTime;

    /**出场时间*/
    private Date leaveTime;


    /**其他预约单号*/
    private String otherNumber;

    /**管桩预约开始时间*/
    @TableField(exist = false)
    private Date planBeginTime;

    /***管桩预约结束时间*/
    @TableField(exist = false)
    private Date planEndTime;

}
