/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizappointmentrecord.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import jakarta.servlet.http.HttpServletResponse;
import vip.xiaonuo.biz.modular.bizappointmentrecord.entity.BizAppointmentRecord;
import vip.xiaonuo.biz.modular.bizappointmentrecord.param.*;
import vip.xiaonuo.biz.modular.bizorder.param.BizOrderPageParam;

import java.io.IOException;
import java.util.List;
import java.util.Map;

/**
 * 预约记录Service接口
 *
 * @author fanzherong
 * @date  2025/03/24 14:47
 **/
public interface BizAppointmentRecordService extends IService<BizAppointmentRecord> {

    /**
     * 获取预约记录分页
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    Page<BizAppointmentRecord> page(BizAppointmentRecordPageParam bizAppointmentRecordPageParam);

    /**
     * 添加预约记录
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    void add(BizAppointmentRecordAddParam bizAppointmentRecordAddParam);

    /**
     * 新增临时预约
     * @param bizAppointmentRecordAddParam
     */
    void addTemp(BizAppointmentRecordAddParam bizAppointmentRecordAddParam);

    /**
     * 编辑预约记录
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    void edit(BizAppointmentRecordEditParam bizAppointmentRecordEditParam);

    /**
     * 编辑临时预约
     * @param bizAppointmentRecordEditParam
     */
    void editTemp(BizAppointmentRecordEditParam bizAppointmentRecordEditParam);

    /**
     * 删除预约记录
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    void delete(List<BizAppointmentRecordIdParam> bizAppointmentRecordIdParamList);

    /**
     * 订单调度
     * @param bizAppointmentRecordEditParam
     */
    void replaceAppoint(BizAppointmentRecordEditParam bizAppointmentRecordEditParam);

    /**
     * 获取预约记录详情
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    BizAppointmentRecord detail(BizAppointmentRecordIdParam bizAppointmentRecordIdParam);

    /**
     * 获取预约记录详情
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     **/
    BizAppointmentRecord queryEntity(String id);

    /**审核*/
    void auditRecord(BizAppointmentRecordEditParam bizAppointmentRecordEditParam);

    /**审核临时预约*/
    void auditTemp(BizAppointmentRecordEditParam bizAppointmentRecordEditParam);

    /**导出报表*/
    void exportRecord(BizAppointmentRecordPageParam bizAppointmentRecordPageParam, HttpServletResponse response) throws IOException;

    /**地磅端门禁和过磅校验*/
    BizAppointmentRecord checkAppointmentRecord(BizAppointmentRecordPageParam bizAppointmentRecordPageParam);

    /**取消排队**/
    void cancelAppointmentRecord(BizAppointmentRecordIdParam bizAppointmentRecordIdParam);

    /**调整订单*/
    void adjustOrder(BizAppointmentRecordEditParam bizAppointmentRecordEditParam);

    /**获取当前时间的预约*/
    BizAppointmentRecord getAppointmentRecord(BizAppointmentRecordPageParam bizAppointmentRecordPageParam);

    /**车辆执行状态分析*/
    List<Map<String,Object>> gerVehicleTotal(BizAppointmentRecordPageParam bizAppointmentRecordPageParam);

    void sendAccount(BizAppointmentRecord bizAppointmentRecord);

    void cancel(BizAppointmentRecordIdParam bizAppointmentRecordIdParam);

    void exit(BizAppointmentRecordIdParam bizAppointmentRecordIdParam);

    void exitTemp(BizAppointmentRecordIdParam bizAppointmentRecordIdParam);

    /**起卸预约列表**/
    Page<BizAppointmentRecord> getLoadPage(BizAppointmentRecordPageParam bizAppointmentRecordPageParam);

    /**起卸预约新增*/
    void addLoad(BizAppointmentRecordAddParam bizAppointmentRecordAddParam);

    /**起卸预约编辑*/
    void editLoad(BizAppointmentRecordEditParam bizAppointmentRecordEditParam);

    /**起卸预约_强制结束*/
    void endLoadAppoint(BizAppointmentRecordEditParam bizAppointmentRecordEditParam);

    /**导出起卸报表*/
    void exportLoadRecord(BizAppointmentRecordPageParam bizAppointmentRecordPageParam, HttpServletResponse response) throws IOException;

    /**管桩预约新增*/
    void addPipeAppoint(BizAppointmentRecordAddParam bizAppointmentRecordAddParam);

    /**管桩预约编辑*/
    void editPipeAppoint(BizAppointmentRecordEditParam bizAppointmentRecordEditParam);

    /**管桩预约列表**/
    Page<BizAppointmentRecord> getPipePage(BizAppointmentRecordPageParam bizAppointmentRecordPageParam);

    /**取消管桩预约*/
    void replacePipeAppoint(BizAppointmentRecordEditParam bizAppointmentRecordEditParam);

    /**管桩预约完成装货*/
    void completePipeAppoint(BizAppointmentRecordEditParam bizAppointmentRecordEditParam);

    /**管桩预约_强制结束*/
    void endPipeAppoint(BizAppointmentRecordEditParam bizAppointmentRecordEditParam);

    /**导出管桩预约报表*/
    void exportPipeRecord(BizAppointmentRecordPageParam bizAppointmentRecordPageParam, HttpServletResponse response) throws IOException;


    /**
     * 其他预约_新增
     * @param bizOtherAppointmentAddParam
     */
    void addOtherAppointment(BizOtherAppointmentAddParam bizOtherAppointmentAddParam);
    /**
     * 其他预约_编辑
     * @param bizOtherAppointmentEditParam
     */
    void editOtherAppointment(BizOtherAppointmentEditParam bizOtherAppointmentEditParam);


    /**
     * 其他预约_强制结束
     * @param bizAppointmentRecordIdParam
     */
    void bizOtherAppointmentExit(BizAppointmentRecordIdParam bizAppointmentRecordIdParam);
    /**
     * 其他预约_授权离场
     * @param bizAppointmentRecordIdParam
     */
    void bizOtherAppointmentAuthorize(BizAppointmentRecordIdParam bizAppointmentRecordIdParam);

    /**
     * 其他预约_完成装货
     */
    void bizOtherAppointmentComplete(BizAppointmentRecordIdParam bizAppointmentRecordIdParam);


    /**
     * 其他预约_导出
     * @param bizAppointmentRecordPageParam
     * @param response
     * @throws IOException
     */
    void bizOtherAppointmentExport(BizAppointmentRecordPageParam bizAppointmentRecordPageParam, HttpServletResponse response) throws IOException;



    /**
     * 充电预约_新增
     * @param bizChargeStationReservationAddParam
     */
    void addChargeStationReservation(BizChargeStationReservationAddParam bizChargeStationReservationAddParam);
    /**
     * 充电预约_编辑
     * @param bizChargeStationReservationEditParam
     */
    void editChargeStationReservation(BizChargeStationReservationEditParam bizChargeStationReservationEditParam);

    /**
     * 充电预约_删除
     *
     * @author fanzherong
     * @date  2025/03/24 14:47
     */
    void deleteChargeStationReservation(List<BizAppointmentRecordIdParam> bizAppointmentRecordIdParamList);
    /**
     * 充电预约_充电完成
     * @param bizAppointmentRecordIdParam
     */
    void bizChargeStationReservationExit(BizAppointmentRecordIdParam bizAppointmentRecordIdParam);

    /**
     * 充电预约_强制结束
     */
    void bizChargeStationEnd(BizAppointmentRecordIdParam bizAppointmentRecordIdParam);

    /**
     * 地磅端确认
     */
    void localConfirm(BizAppointmentRecordEditParam bizAppointmentRecordEditParam);

    /**
     * 地磅端取消
     */
    void localCancel(BizAppointmentRecordEditParam bizAppointmentRecordEditParam);

    /**
     * 云端取消
     */
    void cloudCancel(BizAppointmentRecordEditParam bizAppointmentRecordEditParam);

}
