/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizappointmentrecord.service.impl;

import cn.dev33.satoken.stp.StpUtil;
import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.PhoneUtil;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fhs.trans.service.impl.TransService;
import com.google.common.collect.Maps;
import jakarta.annotation.Resource;
import jakarta.servlet.http.HttpServletResponse;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.compress.utils.Lists;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.auth.core.pojo.SaBaseLoginUser;
import vip.xiaonuo.auth.core.util.StpLoginUserUtil;
import vip.xiaonuo.biz.modular.api.param.WxUserMsgParam;
import vip.xiaonuo.biz.modular.api.service.ApiService;
import vip.xiaonuo.biz.modular.bizappointmentrecord.param.*;
import vip.xiaonuo.biz.modular.bizappointmenttime.service.BizAppointmentTimeService;
import vip.xiaonuo.biz.modular.bizappointreplace.entity.BizAppointReplace;
import vip.xiaonuo.biz.modular.bizappointreplace.service.BizAppointReplaceService;
import vip.xiaonuo.biz.modular.bizchargestation.entity.BizChargeStation;
import vip.xiaonuo.biz.modular.bizchargestation.service.BizChargeStationService;
import vip.xiaonuo.biz.modular.bizconfig.entity.BizConfig;
import vip.xiaonuo.biz.modular.bizconfig.service.BizConfigService;
import vip.xiaonuo.biz.modular.bizexcessconfig.entity.BizExcessConfig;
import vip.xiaonuo.biz.modular.bizexcessconfig.service.BizExcessConfigService;
import vip.xiaonuo.biz.modular.bizloadappoint.entity.BizLoadAppoint;
import vip.xiaonuo.biz.modular.bizloadappoint.service.BizLoadAppointService;
import vip.xiaonuo.biz.modular.bizloadappointsupplier.entity.BizLoadAppointSupplier;
import vip.xiaonuo.biz.modular.bizloadappointsupplier.service.BizLoadAppointSupplierService;
import vip.xiaonuo.biz.modular.bizloadtime.entity.BizLoadTime;
import vip.xiaonuo.biz.modular.bizloadtime.service.BizLoadTimeService;
import vip.xiaonuo.biz.modular.bizorder.entity.BizOrder;
import vip.xiaonuo.biz.modular.bizorder.service.BizOrderService;
import vip.xiaonuo.biz.modular.bizorderconfig.entity.BizOrderConfig;
import vip.xiaonuo.biz.modular.bizorderconfig.service.BizOrderConfigService;
import vip.xiaonuo.biz.modular.bizordersupplier.entity.BizOrderSupplier;
import vip.xiaonuo.biz.modular.bizordersupplier.service.BizOrderSupplierService;
import vip.xiaonuo.biz.modular.bizpipeplan.entity.BizPipePlan;
import vip.xiaonuo.biz.modular.bizpipeplan.service.BizPipePlanService;
import vip.xiaonuo.biz.modular.bizservicecustomer.entity.BizServiceCustomer;
import vip.xiaonuo.biz.modular.bizservicecustomer.service.BizServiceCustomerService;
import vip.xiaonuo.biz.modular.bizsupplier.entity.BizSupplierTransport;
import vip.xiaonuo.biz.modular.bizsupplier.service.BizSupplierTransportService;
import vip.xiaonuo.biz.modular.customer.entity.BizCustomer;
import vip.xiaonuo.biz.modular.customer.service.BizCustomerService;
import vip.xiaonuo.biz.modular.goods.entity.BizGoods;
import vip.xiaonuo.biz.modular.goods.service.BizGoodsService;
import vip.xiaonuo.biz.modular.goodsConf.entity.BizGoodsConf;
import vip.xiaonuo.biz.modular.goodsConf.service.BizGoodsConfService;
import vip.xiaonuo.biz.modular.mq.MqttSubscribeClient;
import vip.xiaonuo.biz.modular.oawxsendlog.entity.OaWxSendLog;
import vip.xiaonuo.biz.modular.officialinfo.entity.OfficialInfo;
import vip.xiaonuo.biz.modular.officialinfo.service.OfficialInfoService;
import vip.xiaonuo.biz.modular.record.entity.BizRecord;
import vip.xiaonuo.biz.modular.record.service.BizRecordService;
import vip.xiaonuo.biz.modular.user.entity.BizUser;
import vip.xiaonuo.biz.modular.user.service.BizUserService;
import vip.xiaonuo.biz.modular.utils.CommonExportUtil;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizappointmentrecord.entity.BizAppointmentRecord;
import vip.xiaonuo.biz.modular.bizappointmentrecord.mapper.BizAppointmentRecordMapper;
import vip.xiaonuo.biz.modular.bizappointmentrecord.service.BizAppointmentRecordService;
import vip.xiaonuo.common.prop.CommonProperties;

import java.io.IOException;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.concurrent.locks.ReentrantLock;
import java.util.regex.Pattern;

/**
 * 预约记录Service接口实现类
 *
 * @author fanzherong
 * @date 2025/03/24 14:47
 **/
@Slf4j
@Service
public class BizAppointmentRecordServiceImpl extends ServiceImpl<BizAppointmentRecordMapper, BizAppointmentRecord> implements BizAppointmentRecordService {

    private final ReentrantLock lock = new ReentrantLock();
    @Resource
    private BizConfigService bizConfigService;
    @Resource
    private BizAppointmentTimeService bizAppointmentTimeService;
    @Resource
    private TransService transService;
    @Resource
    private BizOrderService bizOrderService;
    @Resource
    private BizGoodsService bizGoodsService;
    @Resource
    private BizRecordService bizRecordService;
    @Resource
    private BizExcessConfigService bizExcessConfigService;
    @Resource
    private BizGoodsConfService bizGoodsConfService;
    @Resource
    private BizOrderConfigService bizOrderConfigService;
    @Resource
    private BizUserService bizUserService;
    @Resource
    private OfficialInfoService officialInfoService;
    @Resource
    private CommonProperties commonProperties;
    @Resource
    private ApiService apiService;
    @Resource
    private BizCustomerService bizCustomerService;

    @Resource
    private MqttSubscribeClient mqttSubscribeClient;

    @Resource
    private BizSupplierTransportService bizSupplierTransportService;

    @Resource
    private BizLoadTimeService bizLoadTimeService;

    @Resource
    private BizOrderSupplierService bizOrderSupplierService;

    @Resource
    private BizLoadAppointService bizLoadAppointService;

    @Resource
    private BizLoadAppointSupplierService bizLoadAppointSupplierService;

    @Resource
    private BizPipePlanService bizPipePlanService;


    @Resource
    private BizChargeStationService bizChargeStationService;

    @Resource
    private BizAppointReplaceService bizAppointReplaceService;

    @Resource
    private BizServiceCustomerService bizServiceCustomerService;

    @Override
    public Page<BizAppointmentRecord> page(BizAppointmentRecordPageParam bizAppointmentRecordPageParam) {
        QueryWrapper<BizAppointmentRecord> queryWrapper = getQueryWrapper(bizAppointmentRecordPageParam);
        return this.getBaseMapper().getPage(CommonPageRequest.defaultPage(), queryWrapper);
    }

    public QueryWrapper<BizAppointmentRecord> getQueryWrapper(BizAppointmentRecordPageParam bizAppointmentRecordPageParam) {
        QueryWrapper<BizAppointmentRecord> queryWrapper = new QueryWrapper<BizAppointmentRecord>().checkSqlInjection();
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordPageParam.getType())) {
            queryWrapper.eq("bar.appointment_type", bizAppointmentRecordPageParam.getType());
        }
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordPageParam.getAppointmentClassify())) {
            queryWrapper.eq("bar.appointment_classify", bizAppointmentRecordPageParam.getAppointmentClassify());
        }
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordPageParam.getOrderName())) {
            queryWrapper.like("bo.order_name", bizAppointmentRecordPageParam.getOrderName());
        }
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordPageParam.getOtherNumber())) {
            queryWrapper.like("bar.other_number", bizAppointmentRecordPageParam.getOtherNumber());
        }
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordPageParam.getOrderNumber())) {
            queryWrapper.like("bo.order_number", bizAppointmentRecordPageParam.getOrderNumber());
        }
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordPageParam.getCustomerName())) {
            queryWrapper.like("bc.name", bizAppointmentRecordPageParam.getCustomerName());
        }
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordPageParam.getDriverName())) {
            queryWrapper.like("bar.driver_name", bizAppointmentRecordPageParam.getDriverName());
        }
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordPageParam.getDriverMobile())) {
            queryWrapper.like("bar.driver_mobile", bizAppointmentRecordPageParam.getDriverMobile());
        }
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordPageParam.getGoodsName())) {
            queryWrapper.like("bg.GOODS_NAME", bizAppointmentRecordPageParam.getGoodsName());
        }
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordPageParam.getLicenseNumber())) {
            queryWrapper.like("bar.license_number", bizAppointmentRecordPageParam.getLicenseNumber());
        }
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordPageParam.getStatus())) {
            queryWrapper.eq("bar.status", bizAppointmentRecordPageParam.getStatus());
        }
        //车辆排队去除审核状态
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordPageParam.getAppointmentFlag())) {
            queryWrapper.notIn("bar.status", "1", "2");
        }
        // 校验数据范围
        List<String> loginUserDataScope = StpLoginUserUtil.getLoginUserDataScope();
        if (ObjectUtil.isEmpty(loginUserDataScope)) {
            queryWrapper.eq("bar.driver_id", StpUtil.getLoginIdAsString());
        }
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordPageParam.getLoadNumber())) {
            queryWrapper.like("bla.load_number", bizAppointmentRecordPageParam.getLoadNumber());
        }
        //管桩计划单号
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordPageParam.getPlanNumber())) {
            queryWrapper.like("bpp.plan_number", bizAppointmentRecordPageParam.getPlanNumber());
        }
        // 小程序端查询条件
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordPageParam.getSearchKey())) {
            queryWrapper.and(q -> q.like("bar.license_number", bizAppointmentRecordPageParam.getSearchKey())
                    .or().like("bpp.plan_number", bizAppointmentRecordPageParam.getSearchKey()));
        }
        queryWrapper.eq("bar.delete_flag", "NOT_DELETE");
        queryWrapper.orderByDesc("bar.create_time");
        return queryWrapper;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizAppointmentRecordAddParam bizAppointmentRecordAddParam) {
        checkParam(bizAppointmentRecordAddParam);
        //获取流程配置判断预约是否需要审核
        BizConfig bizConfig = bizConfigService.getOne(new QueryWrapper<BizConfig>().lambda().last("limit 1"));
        BizAppointmentRecord bizAppointmentRecord = BeanUtil.toBean(bizAppointmentRecordAddParam, BizAppointmentRecord.class);
        bizAppointmentRecord.setTimeId(bizOrderService.queryEntity(bizAppointmentRecordAddParam.getOrderId()).getDeliveryTimeId());
        bizAppointmentRecord.setAppointmentType("1");
        //查询是否有充电结束的预约记录
        BizAppointmentRecord appointmentRecord = this.getOne(new QueryWrapper<BizAppointmentRecord>().lambda().
                eq(BizAppointmentRecord::getLicenseNumber, bizAppointmentRecordAddParam.getLicenseNumber()).
                eq(BizAppointmentRecord::getAppointmentType, "4").
                eq(BizAppointmentRecord::getStatus, "18").
                last("limit 1"));
        if(ObjectUtil.isNotNull(appointmentRecord)){
            //存在充电结束的充电预约
            bizAppointmentRecord.setStatus("5");
            appointmentRecord.setStatus("19");
            this.updateById(appointmentRecord);
        }else{
            if (ObjectUtil.isNotNull(bizConfig)) {
                if (StringUtils.equals(bizConfig.getAuditSwitch(), "1")) {
                    //开启审核，设置待审核状态
                    bizAppointmentRecord.setStatus("1");
                } else {
                    //未开启审核，设置排队中状态
                    //bizAppointmentRecord.setStatus("3");
                    //未开启审核，设置待入场状态，可直接过门禁
                    bizAppointmentRecord.setStatus("4");
                }
            }
        }
        if(ObjectUtil.isNotEmpty(bizAppointmentRecordAddParam.getDriverId())){
            BizUser bizUser = bizUserService.getById(bizAppointmentRecordAddParam.getDriverId());
            if(ObjectUtil.isNotNull(bizUser)){
                if(ObjectUtil.isEmpty(bizAppointmentRecordAddParam.getDriverName())){
                    bizAppointmentRecord.setDriverName(bizUser.getName());
                }
                if(ObjectUtil.isEmpty(bizAppointmentRecordAddParam.getDriverMobile())){
                    bizAppointmentRecord.setDriverMobile(bizUser.getPhone());
                }
            }
        }
        //this.save(bizAppointmentRecord);
        saveRecord(bizAppointmentRecord);

        BizOrder bizOrder = bizOrderService.getById(bizAppointmentRecordAddParam.getOrderId());
        bizOrder.setOrderStatus("4");
        bizOrderService.updateById(bizOrder);

        //更新时间段内已预约数
        BizOrderConfig bizAppointmentTime = bizOrderConfigService.getOne(new QueryWrapper<BizOrderConfig>().lambda().
                eq(BizOrderConfig::getOrderId, bizAppointmentRecordAddParam.getOrderId()).
                last("limit 1"));
        if (ObjectUtil.isNotNull(bizAppointmentTime)) {
            bizAppointmentTime.setApplyNumberAlready(bizAppointmentTime.getApplyNumberAlready() + 1);
            bizOrderConfigService.updateById(bizAppointmentTime);
        }
        //更新装卸时间段的已约次数
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordAddParam.getLoadTimeId())) {
            BizLoadTime bizLoadTime = bizLoadTimeService.getById(bizAppointmentRecordAddParam.getLoadTimeId());
            if (ObjectUtil.isNotNull(bizLoadTime)) {
                bizLoadTime.setAlreadyNumber(bizLoadTime.getAlreadyNumber() + 1);
                bizLoadTimeService.updateById(bizLoadTime);
            }
        }

        /*if(StringUtils.equals(bizAppointmentRecord.getStatus(),"3")){
            sendAccount(bizAppointmentRecord,null);
        }*/
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void addTemp(BizAppointmentRecordAddParam bizAppointmentRecordAddParam) {
        checkTempParam(bizAppointmentRecordAddParam);
        //获取流程配置判断预约是否需要审核
        BizConfig bizConfig = bizConfigService.getOne(new QueryWrapper<BizConfig>().lambda().last("limit 1"));
        BizAppointmentRecord bizAppointmentRecord = BeanUtil.toBean(bizAppointmentRecordAddParam, BizAppointmentRecord.class);
        if (ObjectUtil.isNotNull(bizConfig)) {
            if (StringUtils.equals(bizConfig.getTemporaryAuditSwitch(), "1")) {
                //开启审核，设置待审核状态
                bizAppointmentRecord.setStatus("1");
            } else {
                //未开启审核，设置待入场状态
                bizAppointmentRecord.setStatus("4");
            }
        }
        bizAppointmentRecord.setAppointmentType("2");
        this.save(bizAppointmentRecord);
    }

    //临时预约校验
    public void checkTempParam(BizAppointmentRecordAddParam bizAppointmentRecordAddParam) {
        //校验车牌号
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordAddParam.getLicenseNumber())) {
            bizAppointmentRecordAddParam.setLicenseNumber(bizAppointmentRecordAddParam.getLicenseNumber().toUpperCase().trim());
            //校验车牌号是否添加过预约，排除11：已签收、 13:销售已审核  、 14：已取消
            long count = this.count(new QueryWrapper<BizAppointmentRecord>().lambda().
                    eq(BizAppointmentRecord::getLicenseNumber, bizAppointmentRecordAddParam.getLicenseNumber()).
                    notIn(BizAppointmentRecord::getStatus, "10", "11", "12", "13", "14", "15","19"));
            if (count > 0) {
                throw new CommonException("车牌号：{}已经添加过预约！", bizAppointmentRecordAddParam.getLicenseNumber());
            }
        }
        //校验手机号
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordAddParam.getDriverMobile())) {
            if (!PhoneUtil.isMobile(bizAppointmentRecordAddParam.getDriverMobile())) {
                throw new CommonException("手机号码：{}格式错误", bizAppointmentRecordAddParam.getDriverMobile());
            }
        }
    }

    public void checkTempParam(BizAppointmentRecordEditParam bizAppointmentRecordEditParam, BizAppointmentRecord bizAppointmentRecord) {
        //校验车牌号
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordEditParam.getLicenseNumber())) {
            bizAppointmentRecordEditParam.setLicenseNumber(bizAppointmentRecordEditParam.getLicenseNumber().toUpperCase().trim());
            if (!StringUtils.equals(bizAppointmentRecordEditParam.getLicenseNumber(), bizAppointmentRecord.getLicenseNumber())) {
                //校验车牌号是否添加过预约，排除11：已签收、 13:销售已审核  、 14：已取消
                long count = this.count(new QueryWrapper<BizAppointmentRecord>().lambda().
                        eq(BizAppointmentRecord::getLicenseNumber, bizAppointmentRecordEditParam.getLicenseNumber()).
                        notIn(BizAppointmentRecord::getStatus, "10", "11", "12", "13", "14", "15","19"));
                if (count > 0) {
                    throw new CommonException("车牌号：{}已经添加过预约！", bizAppointmentRecordEditParam.getLicenseNumber());
                }
            }

        }
        //校验手机号
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordEditParam.getDriverMobile())) {
            if (!PhoneUtil.isMobile(bizAppointmentRecordEditParam.getDriverMobile())) {
                throw new CommonException("手机号码：{}格式错误", bizAppointmentRecordEditParam.getDriverMobile());
            }
        }
    }

    public void saveRecord(BizAppointmentRecord bizAppointmentRecord) {
        //排队中
        lock.lock();
        try {
            //查询当天预约记录条数
            String format = DateUtil.format(DateUtil.date(), "yyyy-MM-dd");
            BizGoodsConf bizGoodsConf = bizGoodsConfService.getById(bizAppointmentRecord.getTimeId());
            if (ObjectUtil.isNotNull(bizGoodsConf)) {
                format = DateUtil.format(bizGoodsConf.getConfStartTime(), "yyyy-MM-dd");
            }
            long count = this.count(new QueryWrapper<BizAppointmentRecord>().lambda().
                    between(BizAppointmentRecord::getCreateTime, format + " 00:00:00", format + " 23:59:59"));
            bizAppointmentRecord.setQueueNumber((int) (count + 1));
            this.save(bizAppointmentRecord);
        } finally {
            lock.unlock(); // 释放锁
        }

    }

    public void checkParam(BizAppointmentRecordAddParam bizAppointmentRecordAddParam) {
        //校验车牌号
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordAddParam.getLicenseNumber())) {
            bizAppointmentRecordAddParam.setLicenseNumber(bizAppointmentRecordAddParam.getLicenseNumber().toUpperCase().trim());
            if (!isCarNumber(bizAppointmentRecordAddParam.getLicenseNumber())) {
                //throw new CommonException("车牌号：{}格式错误",bizAppointmentRecordAddParam.getLicenseNumber().toUpperCase().trim());
            }
            //校验车牌号是否添加过预约，排除11：已签收、 13:销售已审核  、 14：已取消
            long count = this.count(new QueryWrapper<BizAppointmentRecord>().lambda().
                    eq(BizAppointmentRecord::getLicenseNumber, bizAppointmentRecordAddParam.getLicenseNumber()).
                    notIn(BizAppointmentRecord::getStatus, "10", "11", "12", "13", "14", "15","18","19"));
            if (count > 0) {
                throw new CommonException("车牌号：{}已经添加过预约！", bizAppointmentRecordAddParam.getLicenseNumber());
            }

            //查询是否存在没有回签的记录
            QueryWrapper<BizAppointmentRecord> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("bar.delete_flag", "NOT_DELETE");
            queryWrapper.isNull("br.unload_weight");
            queryWrapper.eq("bo.order_type", "1");
            queryWrapper.eq("bar.`status`", "10");
            queryWrapper.eq("bar.license_number", bizAppointmentRecordAddParam.getLicenseNumber());
            List<BizAppointmentRecord> recordList = this.getBaseMapper().getRecordList(queryWrapper);
            if (ObjectUtil.isNotEmpty(recordList)) {
                throw new CommonException("请先填写回签信息，再进行预约！");
            }
        }
        //校验手机号
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordAddParam.getDriverMobile())) {
            if (!PhoneUtil.isMobile(bizAppointmentRecordAddParam.getDriverMobile())) {
                throw new CommonException("手机号码：{}格式错误", bizAppointmentRecordAddParam.getDriverMobile());
            }
        }
        //校验订单
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordAddParam.getOrderId())) {
            BizOrder bizOrder = bizOrderService.getById(bizAppointmentRecordAddParam.getOrderId());
            if (ObjectUtil.isNotNull(bizOrder)) {
                if (!StringUtils.equals(bizOrder.getOrderStatus(), "3") && !StringUtils.equals(bizOrder.getOrderStatus(), "4")) {
                    throw new CommonException("当前订单不可预约！");
                }
                BizGoodsConf bizGoodsConf = bizGoodsConfService.getById(bizOrder.getDeliveryTimeId());
                if (ObjectUtil.isNotNull(bizGoodsConf)) {
                    if (new Date().getTime() > bizGoodsConf.getConfEndTime().getTime()) {
                        throw new CommonException("提货时间段已过，不可预约！");
                    }
                }

                //查询订单下的供应商
                List<BizOrderSupplier> supplierList = bizOrderSupplierService.list(new QueryWrapper<BizOrderSupplier>().lambda().
                        eq(BizOrderSupplier::getOrderId, bizAppointmentRecordAddParam.getOrderId()));
                List<String> supplierIdList = Lists.newArrayList();
                supplierList.forEach(supplier -> supplierIdList.add(supplier.getSupplierId()));
                //查询车辆是否在供应商名下
                BizSupplierTransport transport = bizSupplierTransportService.getOne(new QueryWrapper<BizSupplierTransport>().lambda().
                        in(BizSupplierTransport::getSupplierId, supplierIdList).
                        eq(BizSupplierTransport::getTransportNo, bizAppointmentRecordAddParam.getLicenseNumber()).
                        eq(BizSupplierTransport::getAuditStatus, "2").
                        last("limit 1"));
                if (ObjectUtil.isNull(transport)) {
                    throw new CommonException("该车辆没有绑定在供应商下，不可预约！");
                }
            }
        }
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordAddParam.getOrderId())) {
            bizAppointmentRecordAddParam.setTimeId(bizOrderService.queryEntity(bizAppointmentRecordAddParam.getOrderId()).getDeliveryTimeId());
            //查询预约时间段内可预约次数
            //BizAppointmentTime bizAppointmentTime = bizAppointmentTimeService.getById(bizAppointmentRecordAddParam.getTimeId());
            getTimeCount(bizAppointmentRecordAddParam);
        }


    }

    public void getTimeCount(BizAppointmentRecordAddParam bizAppointmentRecordAddParam) {
        lock.lock();
        try {
            BizOrderConfig bizOrderConfig = bizOrderConfigService.getOne(new QueryWrapper<BizOrderConfig>().lambda().
                    eq(BizOrderConfig::getOrderId, bizAppointmentRecordAddParam.getOrderId()).
                    last("limit 1"));
            if (ObjectUtil.isNotNull(bizOrderConfig)) {
                //校验预约时间段是否预约满
                if (bizOrderConfig.getApplyNumber() - bizOrderConfig.getApplyNumberAlready() <= 0) {
                    throw new CommonException("该订单已经预约满！");
                }
            }
            //判断装卸预约次数是否满足
            if (ObjectUtil.isNotEmpty(bizAppointmentRecordAddParam.getLoadTimeId())) {
                BizLoadTime bizLoadTime = bizLoadTimeService.queryEntity(bizAppointmentRecordAddParam.getLoadTimeId());
                if (bizLoadTime.getAvailableNumber() - bizLoadTime.getAlreadyNumber() <= 0) {
                    throw new CommonException("当前装卸时段预约已满，不可预约！");
                }
                if (new Date().getTime() > bizLoadTime.getEndTime().getTime()) {
                    throw new CommonException("装卸时间段已过，不可预约！");
                }
            }
        } finally {
            lock.unlock(); // 释放锁
        }

    }

    public void getTimeCount(BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        lock.lock();
        try {
            //判断装卸预约次数是否满足
            if (ObjectUtil.isNotEmpty(bizAppointmentRecordEditParam.getLoadTimeId())) {
                BizLoadTime bizLoadTime = bizLoadTimeService.queryEntity(bizAppointmentRecordEditParam.getLoadTimeId());
                if (bizLoadTime.getAvailableNumber() - bizLoadTime.getAlreadyNumber() <= 0) {
                    throw new CommonException("当前装卸时段预约已满，不可预约！");
                }
                if (new Date().getTime() > bizLoadTime.getEndTime().getTime()) {
                    throw new CommonException("装卸时间段已过，不可预约！");
                }
            }
        } finally {
            lock.unlock(); // 释放锁
        }

    }

    public void checkParam(BizAppointmentRecordEditParam bizAppointmentRecordEditParam, BizAppointmentRecord bizAppointmentRecord) {
        //校验车牌号
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordEditParam.getLicenseNumber())) {
            bizAppointmentRecordEditParam.setLicenseNumber(bizAppointmentRecordEditParam.getLicenseNumber().toUpperCase().trim());
            if (!StringUtils.equals(bizAppointmentRecord.getLicenseNumber(), bizAppointmentRecordEditParam.getLicenseNumber())) {
                //车牌号修改过
                if (!isCarNumber(bizAppointmentRecordEditParam.getLicenseNumber())) {
                    //throw new CommonException("车牌号：{}格式错误",bizAppointmentRecordEditParam.getLicenseNumber().toUpperCase().trim());
                }
                //校验车牌号是否添加过预约，排除11：已签收、 13:销售已审核  、 14：已取消
                long count = this.count(new QueryWrapper<BizAppointmentRecord>().lambda().
                        eq(BizAppointmentRecord::getLicenseNumber, bizAppointmentRecordEditParam.getLicenseNumber()).
                        notIn(BizAppointmentRecord::getStatus, "10", "11", "12", "13", "14", "15","19"));
                if (count > 0) {
                    throw new CommonException("车牌号：{}已经添加过预约！", bizAppointmentRecordEditParam.getLicenseNumber());
                }

                //查询是否存在没有回签的记录
                QueryWrapper<BizAppointmentRecord> queryWrapper = new QueryWrapper<>();
                queryWrapper.eq("bar.delete_flag", "NOT_DELETE");
                queryWrapper.isNull("br.unload_weight");
                queryWrapper.eq("bo.order_type", "1");
                queryWrapper.eq("bar.`status`", "10");
                queryWrapper.eq("bar.license_number", bizAppointmentRecordEditParam.getLicenseNumber());
                List<BizAppointmentRecord> recordList = this.getBaseMapper().getRecordList(queryWrapper);
                if (ObjectUtil.isNotEmpty(recordList)) {
                    throw new CommonException("请先填写回签信息，再进行预约！");
                }
            }
        }
        //校验手机号
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordEditParam.getDriverMobile())) {
            if (!PhoneUtil.isMobile(bizAppointmentRecordEditParam.getDriverMobile())) {
                throw new CommonException("手机号码：{}格式错误", bizAppointmentRecordEditParam.getDriverMobile());
            }
        }
        //校验订单
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordEditParam.getOrderId())) {
            BizOrder bizOrder = bizOrderService.getById(bizAppointmentRecordEditParam.getOrderId());
            if (ObjectUtil.isNotNull(bizOrder)) {
                if (!StringUtils.equals(bizOrder.getOrderStatus(), "3") && !StringUtils.equals(bizOrder.getOrderStatus(), "4")) {
                    throw new CommonException("当前订单不可预约！");
                }
                BizGoodsConf bizGoodsConf = bizGoodsConfService.getById(bizOrder.getDeliveryTimeId());
                if (ObjectUtil.isNotNull(bizGoodsConf)) {
                    if (new Date().getTime() > bizGoodsConf.getConfEndTime().getTime()) {
                        throw new CommonException("提货时间段已过，不可预约！");
                    }
                }

                //查询订单下的供应商
                List<BizOrderSupplier> supplierList = bizOrderSupplierService.list(new QueryWrapper<BizOrderSupplier>().lambda().
                        eq(BizOrderSupplier::getOrderId, bizAppointmentRecordEditParam.getOrderId()));
                List<String> supplierIdList = Lists.newArrayList();
                supplierList.forEach(supplier -> supplierIdList.add(supplier.getSupplierId()));
                //查询车辆是否在供应商名下
                BizSupplierTransport transport = bizSupplierTransportService.getOne(new QueryWrapper<BizSupplierTransport>().lambda().
                        in(BizSupplierTransport::getSupplierId, supplierIdList).
                        eq(BizSupplierTransport::getTransportNo, bizAppointmentRecordEditParam.getLicenseNumber()).
                        eq(BizSupplierTransport::getAuditStatus, "2").
                        last("limit 1"));
                if (ObjectUtil.isNull(transport)) {
                    throw new CommonException("该车辆没有绑定在供应商下，不可预约！");
                }
            }
        }
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordEditParam.getOrderId())) {
            bizAppointmentRecordEditParam.setTimeId(bizOrderService.queryEntity(bizAppointmentRecordEditParam.getOrderId()).getDeliveryTimeId());
            //查询预约时间段内可预约次数
            //BizAppointmentTime bizAppointmentTime = bizAppointmentTimeService.getById(bizAppointmentRecordAddParam.getTimeId());
            BizOrderConfig bizOrderConfig = bizOrderConfigService.getOne(new QueryWrapper<BizOrderConfig>().lambda().
                    eq(BizOrderConfig::getOrderId, bizAppointmentRecordEditParam.getOrderId()).
                    last("limit 1"));
            if (ObjectUtil.isNotNull(bizOrderConfig)) {
                //校验预约时间段是否预约满
                //查询预约时间段内的预约记录,10：已出场   11：已签收   12:自动审核  13:销售已审核   14：已取消这些状态都占用预约名额
                if (bizOrderConfig.getApplyNumber() - bizOrderConfig.getApplyNumberAlready() <= 0) {
                    throw new CommonException("该订单已经预约满！");
                }
            }
        }

        if (!StringUtils.equals(bizAppointmentRecord.getLoadTimeId(), bizAppointmentRecordEditParam.getLoadTimeId())) {
            getTimeCount(bizAppointmentRecordEditParam);
        }

    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        BizAppointmentRecord bizAppointmentRecord = this.queryEntity(bizAppointmentRecordEditParam.getId());
        if (ObjectUtil.isEmpty(bizAppointmentRecordEditParam.getStatus())) {
            bizAppointmentRecordEditParam.setStatus(bizAppointmentRecord.getStatus());
        }
        checkParam(bizAppointmentRecordEditParam, bizAppointmentRecord);
        if (!StringUtils.equals(bizAppointmentRecord.getOrderId(), bizAppointmentRecordEditParam.getOrderId())) {
            //调整了预约时段，释放之前预约时段的预约次数
            BizOrderConfig bizAppointmentTime = bizOrderConfigService.getOne(new QueryWrapper<BizOrderConfig>().lambda().
                    eq(BizOrderConfig::getOrderId, bizAppointmentRecord.getOrderId()).
                    last("limit 1"));
            if (ObjectUtil.isNotNull(bizAppointmentTime)) {
                bizAppointmentTime.setApplyNumberAlready(bizAppointmentTime.getApplyNumberAlready() - 1);
                bizOrderConfigService.updateById(bizAppointmentTime);
            }


            //新的预约时段，增加已约次数
            BizOrderConfig time = bizOrderConfigService.getOne(new QueryWrapper<BizOrderConfig>().lambda().
                    eq(BizOrderConfig::getOrderId, bizAppointmentRecordEditParam.getOrderId()).
                    last("limit 1"));
            if (ObjectUtil.isNotNull(time)) {
                time.setApplyNumberAlready(time.getApplyNumberAlready() + 1);
                bizOrderConfigService.updateById(time);
            }

        }
        if (!StringUtils.equals(bizAppointmentRecord.getLoadTimeId(), bizAppointmentRecordEditParam.getLoadTimeId())) {
            //调整了装卸时段，释放之前的已约次数，更新新的时段已约次数
            if (ObjectUtil.isNotEmpty(bizAppointmentRecordEditParam.getLoadTimeId())) {
                BizLoadTime bizLoadTime = bizLoadTimeService.getById(bizAppointmentRecordEditParam.getLoadTimeId());
                if (ObjectUtil.isNotNull(bizLoadTime)) {
                    bizLoadTime.setAlreadyNumber(bizLoadTime.getAlreadyNumber() + 1);
                    bizLoadTimeService.updateById(bizLoadTime);
                }
            }

            if (ObjectUtil.isNotEmpty(bizAppointmentRecord.getLoadTimeId())) {
                BizLoadTime bizLoadTime = bizLoadTimeService.getById(bizAppointmentRecord.getLoadTimeId());
                if (ObjectUtil.isNotNull(bizLoadTime)) {
                    bizLoadTime.setAlreadyNumber(bizLoadTime.getAlreadyNumber() - 1);
                    bizLoadTimeService.updateById(bizLoadTime);
                }
            }
        }
        if (!StringUtils.equals(bizAppointmentRecord.getOrderId(), bizAppointmentRecordEditParam.getOrderId())) {
            bizAppointmentRecordEditParam.setTimeId(bizOrderService.queryEntity(bizAppointmentRecordEditParam.getOrderId()).getDeliveryTimeId());
        }
        if(ObjectUtil.isNotEmpty(bizAppointmentRecordEditParam.getDriverId())){
            if(!StringUtils.equals(bizAppointmentRecordEditParam.getDriverId(),bizAppointmentRecord.getDriverId())){
                BizUser bizUser = bizUserService.getById(bizAppointmentRecordEditParam.getDriverId());
                if(ObjectUtil.isNotNull(bizUser)){
                    bizAppointmentRecord.setDriverName(bizUser.getName());
                    bizAppointmentRecord.setDriverMobile(bizUser.getPhone());
                }
            }
        }
        BeanUtil.copyProperties(bizAppointmentRecordEditParam, bizAppointmentRecord);
        if (StringUtils.equals(bizAppointmentRecord.getStatus(), "2")) {
            //如果当前状态是审核不通过的状态，修改后重新提交审核
            bizAppointmentRecord.setStatus("1");
        }
        this.updateById(bizAppointmentRecord);
    }

    @Override
    public void editTemp(BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        BizAppointmentRecord bizAppointmentRecord = this.queryEntity(bizAppointmentRecordEditParam.getId());
        if (ObjectUtil.isEmpty(bizAppointmentRecordEditParam.getStatus())) {
            bizAppointmentRecordEditParam.setStatus(bizAppointmentRecord.getStatus());
        }
        checkTempParam(bizAppointmentRecordEditParam, bizAppointmentRecord);
        BeanUtil.copyProperties(bizAppointmentRecordEditParam, bizAppointmentRecord);
        if (StringUtils.equals(bizAppointmentRecord.getStatus(), "2")) {
            //如果当前状态是审核不通过的状态，修改后重新提交审核
            bizAppointmentRecord.setStatus("1");
        }
        this.updateById(bizAppointmentRecord);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizAppointmentRecordIdParam> bizAppointmentRecordIdParamList) {
        //释放预约数
        for (BizAppointmentRecordIdParam bizAppointmentRecordIdParam : bizAppointmentRecordIdParamList) {
            BizAppointmentRecord bizAppointmentRecord = this.queryEntity(bizAppointmentRecordIdParam.getId());
            BizOrderConfig bizAppointmentTime = bizOrderConfigService.getOne(new QueryWrapper<BizOrderConfig>().lambda().
                    eq(BizOrderConfig::getOrderId, bizAppointmentRecord.getOrderId()).
                    last("limit 1"));
            //BizAppointmentTime bizAppointmentTime = bizAppointmentTimeService.getById(bizAppointmentRecord.getTimeId());
            if (ObjectUtil.isNotNull(bizAppointmentTime)) {
                bizAppointmentTime.setApplyNumberAlready(bizAppointmentTime.getApplyNumberAlready() - 1);
                bizOrderConfigService.updateById(bizAppointmentTime);
            }

            if (ObjectUtil.isNotEmpty(bizAppointmentRecord.getLoadTimeId())) {
                BizLoadTime bizLoadTime = bizLoadTimeService.getById(bizAppointmentRecord.getLoadTimeId());
                if (ObjectUtil.isNotNull(bizLoadTime)) {
                    bizLoadTime.setAlreadyNumber(bizLoadTime.getAlreadyNumber() - 1);
                    bizLoadTimeService.updateById(bizLoadTime);
                }
            }
        }
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizAppointmentRecordIdParamList, BizAppointmentRecordIdParam::getId));
    }

    @Transactional
    @Override
    public void replaceAppoint(BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        BizAppointmentRecord bizAppointmentRecord = this.queryEntity(bizAppointmentRecordEditParam.getId());
        if(!StringUtils.equals(bizAppointmentRecord.getOrderId(),bizAppointmentRecordEditParam.getOrderId())){
            //添加调度审批记录
            BizAppointReplace bizAppointReplace = new BizAppointReplace();
            //更换前订单id
            bizAppointReplace.setOldOrderId(bizAppointmentRecord.getOrderId());
            //更换后订单id
            bizAppointReplace.setNewOrderId(bizAppointmentRecordEditParam.getOrderId());
            //更换前装卸点位id
            bizAppointReplace.setOldLoadPointId(bizAppointmentRecord.getLoadPointId());
            //更换后装卸点位id
            bizAppointReplace.setNewLoadPointId(bizAppointmentRecordEditParam.getLoadPointId());
            //更换前装卸时间id
            bizAppointReplace.setOldLoadTimeId(bizAppointmentRecord.getLoadTimeId());
            //更换后装卸时间id
            bizAppointReplace.setNewLoadTimeId(bizAppointmentRecordEditParam.getLoadTimeId());
            bizAppointReplace.setAppointId(bizAppointmentRecord.getId());
            bizAppointReplace.setAppointStatus(bizAppointmentRecord.getStatus());
            bizAppointReplaceService.save(bizAppointReplace);

            //调度待审批
            bizAppointmentRecord.setStatus("20");
            this.updateById(bizAppointmentRecord);
        }
    }

    @Override
    public BizAppointmentRecord detail(BizAppointmentRecordIdParam bizAppointmentRecordIdParam) {
        return this.queryEntity(bizAppointmentRecordIdParam.getId());
    }

    @Override
    public BizAppointmentRecord queryEntity(String id) {
        BizAppointmentRecord bizAppointmentRecord = this.getById(id);
        if (ObjectUtil.isEmpty(bizAppointmentRecord)) {
            throw new CommonException("预约记录不存在，id值为：{}", id);
        }
        return bizAppointmentRecord;
    }

    @Override
    public void auditRecord(BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        BizAppointmentRecord bizAppointmentRecord = this.queryEntity(bizAppointmentRecordEditParam.getId());
        UpdateWrapper<BizAppointmentRecord> updateWrapper = new UpdateWrapper<>();
        updateWrapper.eq("id", bizAppointmentRecord.getId());
        String status = null;
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordEditParam.getAuditFlag())) {
            if (StringUtils.equals(bizAppointmentRecordEditParam.getAuditFlag(), "true")) {
                //bizAppointmentRecord.setStatus("2");
                status = "2";
            } else {
                //bizAppointmentRecord.setStatus("3");
                status = "4";
            }
            //bizAppointmentRecord.setAppointmentReason(bizAppointmentRecordEditParam.getAppointmentReason());
            updateWrapper.set("status", status);
            updateWrapper.set("appointment_reason", bizAppointmentRecordEditParam.getAppointmentReason());
            //this.updateById(bizAppointmentRecord);
            this.update(updateWrapper);

            /*if(StringUtils.equals(status,"3")){
                sendAccount(bizAppointmentRecord,null);
            }*/
        }
    }

    @Override
    public void auditTemp(BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        BizAppointmentRecord bizAppointmentRecord = this.queryEntity(bizAppointmentRecordEditParam.getId());
        UpdateWrapper<BizAppointmentRecord> updateWrapper = new UpdateWrapper<>();
        updateWrapper.eq("id", bizAppointmentRecord.getId());
        String status = null;
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordEditParam.getAuditFlag())) {
            if (StringUtils.equals(bizAppointmentRecordEditParam.getAuditFlag(), "true")) {
                status = "2";
            } else {
                status = "4";
            }
            updateWrapper.set("status", status);
            updateWrapper.set("appointment_reason", bizAppointmentRecordEditParam.getAppointmentReason());
            this.update(updateWrapper);
        }
    }

    @Override
    public void exportRecord(BizAppointmentRecordPageParam bizAppointmentRecordPageParam, HttpServletResponse response) throws IOException {
        QueryWrapper<BizAppointmentRecord> queryWrapper = getQueryWrapper(bizAppointmentRecordPageParam);
        List<BizAppointmentRecord> recordList = this.getBaseMapper().getPage(queryWrapper);
        String fileName = "预约报表.xlsx";
        List<BizAppointmentExportResult> list = Lists.newArrayList();
        transService.transBatch(recordList);
        for (BizAppointmentRecord bizAppointmentRecord : recordList) {
            BizAppointmentExportResult bizAppointmentExportResult = new BizAppointmentExportResult();
            BeanUtil.copyProperties(bizAppointmentRecord, bizAppointmentExportResult);
            bizAppointmentExportResult.setStatusName((String) bizAppointmentRecord.getTransMap().get("statusName"));
            bizAppointmentExportResult.setAxleNumber(bizAppointmentRecord.getAxleNumber() + "轴");
            list.add(bizAppointmentExportResult);
        }
        CommonExportUtil.export(fileName, BizAppointmentExportResult.class, list, response, "预约报表");
    }

    @Override
    public BizAppointmentRecord checkAppointmentRecord(BizAppointmentRecordPageParam bizAppointmentRecordPageParam) {
        //根据车牌号和状态查询
        BizAppointmentRecord bizAppointmentRecord = this.getOne(new QueryWrapper<BizAppointmentRecord>().lambda().
                eq(BizAppointmentRecord::getLicenseNumber, bizAppointmentRecordPageParam.getLicenseNumber()).
                orderByDesc(BizAppointmentRecord::getCreateTime).
                last("limit 1"));
        if (StringUtils.equals(bizAppointmentRecordPageParam.getStatus(), "4")) {
            //待入场,如果为空，没有待入场的记录，不可进门禁
            if (ObjectUtil.isNull(bizAppointmentRecord)) {
                bizAppointmentRecord = new BizAppointmentRecord();
                bizAppointmentRecord.setIsFlag("4");
            } else {
                if (StringUtils.equals(bizAppointmentRecord.getStatus(), "4")) {
                    if (StringUtils.equals(bizAppointmentRecord.getAppointmentType(), "1")) {
                        //订单预约
                        bizAppointmentRecord = setBizAppointmentRecord(bizAppointmentRecord);
                    }
                    if (StringUtils.equals(bizAppointmentRecord.getAppointmentType(), "5")){
                        //管桩预约
                        bizAppointmentRecord.setIsFlag("1");
                    }
                    if (StringUtils.equals(bizAppointmentRecord.getAppointmentType(), "2")){
                        //临时预约
                        bizAppointmentRecord.setIsFlag("1");
                    }
                    if  (StringUtils.equals(bizAppointmentRecord.getAppointmentType(),"6")){
                        //其他预约
                        bizAppointmentRecord.setIsFlag("1");
                    }
                    if (StringUtils.equals(bizAppointmentRecord.getAppointmentType(),"4")){
                        //充电预约
                        bizAppointmentRecord.setIsFlag("1");
                    }
                    if (StringUtils.equals(bizAppointmentRecord.getAppointmentType(),"3")){
                        //起卸预约
                        bizAppointmentRecord.setIsFlag("1");
                    }
                } else {
                    bizAppointmentRecord.setIsFlag("4");
                }
            }
        } else if (StringUtils.equals(bizAppointmentRecordPageParam.getStatus(), "5")) {
            //已入场，如果为空，没有已入场的记录，不可一次过磅
            if (ObjectUtil.isNull(bizAppointmentRecord)) {
                bizAppointmentRecord = new BizAppointmentRecord();
                bizAppointmentRecord.setIsFlag("5");
            } else {
                if (StringUtils.equals(bizAppointmentRecord.getStatus(), "5")) {
                    if (StringUtils.equals(bizAppointmentRecord.getAppointmentType(), "1")) {
                        bizAppointmentRecord = setBizAppointmentRecord(bizAppointmentRecord);
                    }
                    if (StringUtils.equals(bizAppointmentRecord.getAppointmentType(), "2")){
                        //临时预约
                        bizAppointmentRecord.setIsFlag("5");
                    }
                    if (StringUtils.equals(bizAppointmentRecord.getAppointmentType(),"6")){
                        //其他预约
                        //bizAppointmentRecord.setIsFlag("1");
                        bizAppointmentRecord = setBizAppointmentOther(bizAppointmentRecord);
                    }
                    if (StringUtils.equals(bizAppointmentRecord.getAppointmentType(),"3")){
                        //起卸预约
                        //bizAppointmentRecord.setIsFlag("1");
                        bizAppointmentRecord = setBizAppointmentLoad(bizAppointmentRecord);
                    }
                } else {
                    bizAppointmentRecord.setIsFlag("5");
                }
            }
        } else if (StringUtils.equals(bizAppointmentRecordPageParam.getStatus(), "7")) {
            //完成装货，如果为空，没有完成装货的记录，不可二次过磅
            if (ObjectUtil.isNull(bizAppointmentRecord)) {
                bizAppointmentRecord = new BizAppointmentRecord();
                bizAppointmentRecord.setIsFlag("7");
            } else {
                if (StringUtils.equals(bizAppointmentRecord.getStatus(), "7")) {
                    if (StringUtils.equals(bizAppointmentRecord.getAppointmentType(), "1")) {
                        bizAppointmentRecord = setBizAppointmentRecord(bizAppointmentRecord);
                    }
                    if (StringUtils.equals(bizAppointmentRecord.getAppointmentType(), "2")){
                        bizAppointmentRecord.setIsFlag("7");
                    }
                    if (StringUtils.equals(bizAppointmentRecord.getAppointmentType(), "6")){
                        //其他预约
                        bizAppointmentRecord = setBizAppointmentOther(bizAppointmentRecord);
                    }
                    if (StringUtils.equals(bizAppointmentRecord.getAppointmentType(), "3")){
                        //起卸预约
                        bizAppointmentRecord = setBizAppointmentLoad(bizAppointmentRecord);
                    }
                } else if (StringUtils.equals(bizAppointmentRecord.getStatus(), "8")) {
                    if (StringUtils.equals(bizAppointmentRecord.getAppointmentType(), "1")) {
                        bizAppointmentRecord = setBizAppointmentRecord(bizAppointmentRecord);
                    } else {
                        bizAppointmentRecord.setIsFlag("7");
                    }
                } else {
                    bizAppointmentRecord.setIsFlag("7");
                }
            }
        } else if (StringUtils.equals(bizAppointmentRecordPageParam.getStatus(), "9")) {
            //待出场，如果为空，没有待出场的记录，不可出门禁
            if (ObjectUtil.isNull(bizAppointmentRecord)) {
                bizAppointmentRecord = new BizAppointmentRecord();
                bizAppointmentRecord.setIsFlag("9");
            } else {
                if (StringUtils.equals(bizAppointmentRecord.getStatus(), "9")) {
                    if (StringUtils.equals(bizAppointmentRecord.getAppointmentType(), "1")) {
                        bizAppointmentRecord = setBizAppointmentRecord(bizAppointmentRecord);
                    }
                    if (StringUtils.equals(bizAppointmentRecord.getAppointmentType(), "2")){
                        bizAppointmentRecord.setIsFlag("1");
                    }
                    if (StringUtils.equals(bizAppointmentRecord.getAppointmentType(), "5")){
                        //临时预约
                        bizAppointmentRecord.setIsFlag("1");
                    }
                    if (StringUtils.equals(bizAppointmentRecord.getAppointmentType(),"6")){
                        //其他预约
                        bizAppointmentRecord.setIsFlag("1");
                    }
                    if (StringUtils.equals(bizAppointmentRecord.getAppointmentType(),"4")){
                        //充电预约
                        bizAppointmentRecord.setIsFlag("1");
                    }
                    if (StringUtils.equals(bizAppointmentRecord.getAppointmentType(),"3")){
                        //起卸预约
                        bizAppointmentRecord = setBizAppointmentLoad(bizAppointmentRecord);
                    }
                } else {
                    if(StringUtils.equals(bizAppointmentRecord.getAppointmentType(),"4")){
                        //充电预约
                        if(StringUtils.equals(bizAppointmentRecord.getStatus(),"5")){
                            bizAppointmentRecord.setIsFlag("1");
                        }
                    }else{
                        bizAppointmentRecord.setIsFlag("9");
                    }
                }

            }
        }
        return bizAppointmentRecord;
    }

    public BizAppointmentRecord setBizAppointmentRecord(BizAppointmentRecord bizAppointmentRecord) {
        bizAppointmentRecord.setIsFlag("1");
        if (ObjectUtil.isNotEmpty(bizAppointmentRecord.getOrderId())) {
            BizOrder bizOrder = bizOrderService.getById(bizAppointmentRecord.getOrderId());
            if (ObjectUtil.isNotNull(bizOrder)) {
                bizAppointmentRecord.setOrderBalance(bizOrder.getOrderWeight().subtract(bizOrder.getNetWeight()));
                bizAppointmentRecord.setReceiptCompany(bizOrder.getShipAddress());
                if (ObjectUtil.isNotEmpty(bizOrder.getGoodId())) {
                    BizGoods bizGoods = bizGoodsService.getById(bizOrder.getGoodId());
                    if (ObjectUtil.isNotNull(bizGoods)) {
                        bizAppointmentRecord.setGoodsName(bizGoods.getGoodsName());
                        bizAppointmentRecord.setGoodsModel(bizGoods.getGoodsCode());
                    }
                }
                if (ObjectUtil.isNotEmpty(bizOrder.getCustomerId())) {
                    BizCustomer bizCustomer = bizCustomerService.getById(bizOrder.getCustomerId());
                    if (ObjectUtil.isNotNull(bizCustomer)) {
                        bizAppointmentRecord.setShippingCompany(bizCustomer.getName());
                    }
                }
            }
        }
        log.info("地磅端对接：overId:" + bizAppointmentRecord.getOverId());
        if (ObjectUtil.isNotEmpty(bizAppointmentRecord.getOverId())) {
            BizExcessConfig excessConfig = bizExcessConfigService.getById(bizAppointmentRecord.getOverId());
            if (ObjectUtil.isNotNull(excessConfig)) {
                bizAppointmentRecord.setOverWeight(excessConfig.getExcessWeight());
            }
        }
        BizConfig bizConfig = bizConfigService.getOne(new QueryWrapper<BizConfig>().lambda().last("limit 1"));
        if (ObjectUtil.isNotNull(bizConfig)) {
            bizAppointmentRecord.setOrderWeightSwitch(bizConfig.getOrderWeightSwitch());
        }
        return bizAppointmentRecord;
    }

    public BizAppointmentRecord setBizAppointmentLoad(BizAppointmentRecord bizAppointmentRecord) {
        bizAppointmentRecord.setIsFlag("1");
        if (ObjectUtil.isNotEmpty(bizAppointmentRecord.getOrderId())) {
            //查询起卸订单
            BizLoadAppoint loadAppoint = bizLoadAppointService.getById(bizAppointmentRecord.getOrderId());
            if (ObjectUtil.isNotNull(loadAppoint)) {
                bizAppointmentRecord.setOrderBalance(loadAppoint.getOrderWeight().subtract(loadAppoint.getNetWeight()));
                //bizAppointmentRecord.setReceiptCompany(bizOrder.getShipAddress());
                if (ObjectUtil.isNotEmpty(loadAppoint.getGoodsId())) {
                    BizGoods bizGoods = bizGoodsService.getById(loadAppoint.getGoodsId());
                    if (ObjectUtil.isNotNull(bizGoods)) {
                        bizAppointmentRecord.setGoodsName(bizGoods.getGoodsName());
                        bizAppointmentRecord.setGoodsModel(bizGoods.getGoodsCode());
                    }
                }
                if (ObjectUtil.isNotEmpty(loadAppoint.getCustomerId())) {
                    BizServiceCustomer serviceCustomer = bizServiceCustomerService.getById(loadAppoint.getCustomerId());
                    if (ObjectUtil.isNotNull(serviceCustomer)) {
                        bizAppointmentRecord.setShippingCompany(serviceCustomer.getName());
                    }
                }
            }
        }
        log.info("地磅端对接：overId:" + bizAppointmentRecord.getOverId());
        if (ObjectUtil.isNotEmpty(bizAppointmentRecord.getOverId())) {
            BizExcessConfig excessConfig = bizExcessConfigService.getById(bizAppointmentRecord.getOverId());
            if (ObjectUtil.isNotNull(excessConfig)) {
                bizAppointmentRecord.setOverWeight(excessConfig.getExcessWeight());
            }
        }
        BizConfig bizConfig = bizConfigService.getOne(new QueryWrapper<BizConfig>().lambda().last("limit 1"));
        if (ObjectUtil.isNotNull(bizConfig)) {
            bizAppointmentRecord.setOrderWeightSwitch(bizConfig.getOrderWeightSwitch());
        }
        return bizAppointmentRecord;
    }

    public BizAppointmentRecord setBizAppointmentOther(BizAppointmentRecord bizAppointmentRecord) {
        bizAppointmentRecord.setIsFlag("1");
        log.info("地磅端对接：overId:" + bizAppointmentRecord.getOverId());
        if (ObjectUtil.isNotEmpty(bizAppointmentRecord.getOverId())) {
            BizExcessConfig excessConfig = bizExcessConfigService.getById(bizAppointmentRecord.getOverId());
            if (ObjectUtil.isNotNull(excessConfig)) {
                bizAppointmentRecord.setOverWeight(excessConfig.getExcessWeight());
            }
        }
        return bizAppointmentRecord;
    }

    @Transactional
    @Override
    public void cancelAppointmentRecord(BizAppointmentRecordIdParam bizAppointmentRecordIdParam) {
        BizAppointmentRecord bizAppointmentRecord = this.queryEntity(bizAppointmentRecordIdParam.getId());
        //设置已取消
        bizAppointmentRecord.setStatus("14");
        this.updateById(bizAppointmentRecord);

        //释放预约数
        BizOrderConfig bizAppointmentTime = bizOrderConfigService.getOne(new QueryWrapper<BizOrderConfig>().lambda().
                eq(BizOrderConfig::getOrderId, bizAppointmentRecord.getOrderId()).
                last("limit 1"));
        if (ObjectUtil.isNotNull(bizAppointmentTime)) {
            bizAppointmentTime.setApplyNumberAlready(bizAppointmentTime.getApplyNumberAlready() - 1);
            bizOrderConfigService.updateById(bizAppointmentTime);
        }
    }

    @Transactional
    @Override
    public void adjustOrder(BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        BizAppointmentRecord bizAppointmentRecord = this.queryEntity(bizAppointmentRecordEditParam.getId());
        //校验订单
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordEditParam.getOrderId())) {
            BizOrder bizOrder = bizOrderService.getById(bizAppointmentRecordEditParam.getOrderId());
            if (ObjectUtil.isNotNull(bizOrder)) {
                if (!StringUtils.equals(bizOrder.getOrderStatus(), "3") && !StringUtils.equals(bizOrder.getOrderStatus(), "4")) {
                    throw new CommonException("当前订单不可调度！");
                }
                BizGoodsConf bizGoodsConf = bizGoodsConfService.getById(bizOrder.getDeliveryTimeId());
                if (ObjectUtil.isNotNull(bizGoodsConf)) {
                    if (new Date().getTime() > bizGoodsConf.getConfEndTime().getTime()) {
                        throw new CommonException("提货时间段已过，不可调度！");
                    }
                }
            }
        }
        if (!StringUtils.equals(bizAppointmentRecord.getOrderId(), bizAppointmentRecordEditParam.getOrderId())) {
            //调整了预约时段，释放之前预约时段的预约次数
            BizOrderConfig bizAppointmentTime = bizOrderConfigService.getOne(new QueryWrapper<BizOrderConfig>().lambda().
                    eq(BizOrderConfig::getOrderId, bizAppointmentRecord.getOrderId()).
                    last("limit 1"));
            if (ObjectUtil.isNotNull(bizAppointmentTime)) {
                bizAppointmentTime.setApplyNumberAlready(bizAppointmentTime.getApplyNumberAlready() - 1);
                bizOrderConfigService.updateById(bizAppointmentTime);
            }


            //新的预约时段，增加已约次数
            BizOrderConfig time = bizOrderConfigService.getOne(new QueryWrapper<BizOrderConfig>().lambda().
                    eq(BizOrderConfig::getOrderId, bizAppointmentRecordEditParam.getOrderId()).
                    last("limit 1"));
            if (ObjectUtil.isNotNull(time)) {
                time.setApplyNumberAlready(time.getApplyNumberAlready() + 1);
                bizOrderConfigService.updateById(time);
            }

            //调整过订单
            if (StringUtils.equals(bizAppointmentRecord.getStatus(), "8") || StringUtils.equals(bizAppointmentRecord.getStatus(), "9")) {
                //查询过磅记录重量
                BizRecord bizRecord = bizRecordService.getOne(new QueryWrapper<BizRecord>().lambda().
                        eq(BizRecord::getAppointmentId, bizAppointmentRecord.getId()).
                        last("limit 1"));
                //当前状态已完成二次过磅，重量已经添加到订单中，要扣去添加的重量
                BizOrder bizOrder = bizOrderService.getById(bizAppointmentRecord.getOrderId());
                if (ObjectUtil.isNotNull(bizOrder)) {
                    if (ObjectUtil.isNotNull(bizRecord)) {
                        bizOrder.setNetWeight(bizOrder.getNetWeight().subtract(bizRecord.getNetWeight()));
                    }
                }

                //修改后的订单加上净重
                BizOrder order = bizOrderService.getById(bizAppointmentRecordEditParam.getOrderId());
                if (ObjectUtil.isNotNull(order)) {
                    if (ObjectUtil.isNotNull(bizRecord)) {
                        order.setNetWeight(order.getNetWeight().add(bizRecord.getNetWeight()));
                    }
                }
            } else {
                bizAppointmentRecord.setOrderId(bizAppointmentRecordEditParam.getOrderId());
            }

            bizAppointmentRecord.setTimeId(bizOrderService.queryEntity(bizAppointmentRecordEditParam.getOrderId()).getDeliveryTimeId());
            this.updateById(bizAppointmentRecord);
        }
    }

    @Override
    public BizAppointmentRecord getAppointmentRecord(BizAppointmentRecordPageParam bizAppointmentRecordPageParam) {
        QueryWrapper<BizAppointmentRecord> queryWrapper = new QueryWrapper<>();
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordPageParam.getDateNow())) {
            queryWrapper.ge("bgc.CONF_START_TIME", bizAppointmentRecordPageParam.getDateNow());
            queryWrapper.lt("bgc.CONF_END_TIME", bizAppointmentRecordPageParam.getDateNow());
        }
        queryWrapper.eq("bar.delete_flag", "NOT_DELETE");
        queryWrapper.orderByAsc("bar.create_time");
        queryWrapper.last("limit 1");
        //BizAppointmentRecord record = this.getBaseMapper().getRecord(queryWrapper);
        return null;
    }

    @Override
    public List<Map<String, Object>> gerVehicleTotal(BizAppointmentRecordPageParam bizAppointmentRecordPageParam) {
        String beginTime = null;
        String endTime = null;
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordPageParam.getBeginTime())) {
            beginTime = bizAppointmentRecordPageParam.getBeginTime() + " 00:00:00";
        } else {
            //beginTime = DateUtil.format(DateUtil.date(),"yyyy-MM-dd");
        }
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordPageParam.getEndTime())) {
            endTime = bizAppointmentRecordPageParam.getEndTime() + " 23:59:59";
        } else {
            //endTime = DateUtil.format(DateUtil.date(),"yyyy-MM-dd");
        }
        List<Map<String, Object>> list = this.getBaseMapper().gerVehicleTotal(beginTime, endTime);
        return list;
    }



    /**
     * 车牌号校验
     *
     * @param carNumber
     * @return
     */
    public boolean isCarNumber(String carNumber) {
        String carNumberPattern = "([京津沪渝冀豫云辽黑湘皖鲁新苏浙赣鄂桂甘晋蒙陕吉闽贵粤青藏川宁琼]{1}(([A-HJ-Z]{1}[A-HJ-NP-Z0-9]{5})|([A-HJ-Z]{1}(([DF]{1}[A-HJ-NP-Z0-9]{1}[0-9]{4})|([0-9]{5}[DF]{1})))|([A-HJ-Z]{1}[A-D0-9]{1}[0-9]{3}警)))|([0-9]{6}使)|((([沪粤川云桂鄂陕蒙藏黑辽渝]{1}A)|鲁B|闽D|蒙E|蒙H)[0-9]{4}领)|(WJ[京津沪渝冀豫云辽黑湘皖鲁新苏浙赣鄂桂甘晋蒙陕吉闽贵粤青藏川宁琼·•]{1}[0-9]{4}[TDSHBXJ0-9]{1})|([VKHBSLJNGCE]{1}[A-DJ-PR-TVY]{1}[0-9]{5})";
        return Pattern.matches(carNumberPattern, carNumber);
    }


    /**
     * 发送微信公众号推送消息
     */
    public void sendAccount(BizAppointmentRecord bizAppointmentRecord) {
        BizUser bizUser = bizUserService.queryEntity(bizAppointmentRecord.getCreateUser());
        if (ObjectUtil.isNotEmpty(bizUser.getUnionId())) {
            log.info("当前用户:" + bizUser.getName() + "存在unionId");
            //根据unionId查询微信公众号openId
            OfficialInfo officialInfo = officialInfoService.getOne(new QueryWrapper<OfficialInfo>().lambda().
                    eq(OfficialInfo::getUnionId, bizUser.getUnionId()).
                    eq(OfficialInfo::getStatus, "1").last("limit 1"));

            if (ObjectUtil.isNotNull(officialInfo)) {
                log.info("当前用户:" + bizUser.getName() + "存在openId");
                OaWxSendLog oaWxSendLog = new OaWxSendLog();
                oaWxSendLog.setSendUserId(bizUser.getId());
                oaWxSendLog.setSendUserName(bizUser.getName());
                WxUserMsgParam wxUserMsgParam = new WxUserMsgParam();
                wxUserMsgParam.setTemplateId(commonProperties.getOfficialTemplete());
                wxUserMsgParam.setOpenId(officialInfo.getOfficialOpenId());
                wxUserMsgParam.setParam1("car_number9");
                wxUserMsgParam.setParamData1(bizAppointmentRecord.getLicenseNumber());
                wxUserMsgParam.setParam2("time6");
                String time = null;
                BizGoodsConf bizGoodsConf = bizGoodsConfService.getById(bizAppointmentRecord.getTimeId());
                if (ObjectUtil.isNotNull(bizGoodsConf)) {
                    time = DateUtil.format(bizGoodsConf.getConfStartTime(), "yyyy-MM-dd HH:mm:ss") + "~" + DateUtil.format(bizGoodsConf.getConfEndTime(), "yyyy-MM-dd HH:mm:ss");
                }
                wxUserMsgParam.setParamData2(time);
                wxUserMsgParam.setParam3("thing2");
                wxUserMsgParam.setParamData3(bizAppointmentRecord.getQueueNumber().toString());
                apiService.sendProjectExpireMsg(oaWxSendLog, wxUserMsgParam);
            } else {
                log.info("为查询到用户" + bizUser.getName() + "的关注公众号信息！");
            }
        }
    }

    @Override
    public void cancel(BizAppointmentRecordIdParam bizAppointmentRecordIdParam) {
        BizAppointmentRecord bizAppointmentRecord = this.queryEntity(bizAppointmentRecordIdParam.getId());
        //取消
        bizAppointmentRecord.setStatus("14");
        this.updateById(bizAppointmentRecord);

        //释放物流订单预约数
        BizOrderConfig bizAppointmentTime = bizOrderConfigService.getOne(new QueryWrapper<BizOrderConfig>().lambda().
                eq(BizOrderConfig::getOrderId, bizAppointmentRecord.getOrderId()).
                last("limit 1"));
        if (ObjectUtil.isNotNull(bizAppointmentTime)) {
            bizAppointmentTime.setApplyNumberAlready(bizAppointmentTime.getApplyNumberAlready() - 1);
            bizOrderConfigService.updateById(bizAppointmentTime);
        }

        //释放装卸时间已约次数
        BizLoadTime bizLoadTime = bizLoadTimeService.getById(bizAppointmentRecord.getLoadTimeId());
        if (ObjectUtil.isNotNull(bizLoadTime)) {
            bizLoadTime.setAlreadyNumber(bizLoadTime.getAlreadyNumber() - 1);
            bizLoadTimeService.updateById(bizLoadTime);
        }
    }

    @Transactional
    @Override
    public void exit(BizAppointmentRecordIdParam bizAppointmentRecordIdParam) {
        //修改过磅记录已出场
        BizAppointmentRecord bizAppointmentRecord = this.queryEntity(bizAppointmentRecordIdParam.getId());
        //bizAppointmentRecord.setStatus("10");
        this.removeById(bizAppointmentRecord);

        //删除过磅记录
        List<BizRecord> recordList = bizRecordService.list(new QueryWrapper<BizRecord>().lambda().
                eq(BizRecord::getAppointmentId, bizAppointmentRecord.getId()));
        for (BizRecord bizRecord : recordList) {
            //下发mqtt，地磅端删除过磅记录
            Map<String, Object> map = Maps.newHashMap();
            map.put("id", bizRecord.getRelationId());
            map.put("type", "20");
            //mqtt发送过磅记录id给地磅端，告诉地磅端可打印磅单，抬道闸
            mqttSubscribeClient.publishMessage(commonProperties.getMqttTopic(), JSONObject.toJSONString(map));
            log.info("授权出场mqtt下发车牌号：" + bizRecord.getLicensePlate());
            bizRecordService.removeById(bizRecord.getId());
        }
    }

    @Override
    public void exitTemp(BizAppointmentRecordIdParam bizAppointmentRecordIdParam) {
        //修改过磅记录已出场
        BizAppointmentRecord bizAppointmentRecord = this.queryEntity(bizAppointmentRecordIdParam.getId());
        bizAppointmentRecord.setStatus("10");
        this.updateById(bizAppointmentRecord);
    }

    @Override
    public Page<BizAppointmentRecord> getLoadPage(BizAppointmentRecordPageParam bizAppointmentRecordPageParam) {
        QueryWrapper<BizAppointmentRecord> queryWrapper = getQueryWrapper(bizAppointmentRecordPageParam);
        Page<BizAppointmentRecord> loadPage = this.getBaseMapper().getLoadPage(CommonPageRequest.defaultPage(), queryWrapper);
        return loadPage;
    }

    @Transactional
    @Override
    public void addLoad(BizAppointmentRecordAddParam bizAppointmentRecordAddParam) {
        checkLoadParam(bizAppointmentRecordAddParam);
        //获取流程配置判断预约是否需要审核
        BizConfig bizConfig = bizConfigService.getOne(new QueryWrapper<BizConfig>().lambda().last("limit 1"));
        BizAppointmentRecord bizAppointmentRecord = BeanUtil.toBean(bizAppointmentRecordAddParam, BizAppointmentRecord.class);
        //查询车辆是否存在充电结束的预约记录
        BizAppointmentRecord appointmentRecord = this.getOne(new QueryWrapper<BizAppointmentRecord>().lambda().
                eq(BizAppointmentRecord::getLicenseNumber, bizAppointmentRecordAddParam.getLicenseNumber()).
                eq(BizAppointmentRecord::getAppointmentType, "4").
                eq(BizAppointmentRecord::getStatus, "18").
                last("limit 1"));
        if(ObjectUtil.isNotNull(appointmentRecord)){
            //存在充电结束的充电预约
            bizAppointmentRecord.setStatus("5");
            appointmentRecord.setStatus("19");
            this.updateById(appointmentRecord);
        }else{
            bizAppointmentRecord.setStatus("4");
        }
        bizAppointmentRecord.setAppointmentType("3");
        this.save(bizAppointmentRecord);

        //修改起卸订单状态
        BizLoadAppoint loadAppoint = bizLoadAppointService.getById(bizAppointmentRecordAddParam.getOrderId());
        loadAppoint.setStatus("6");
        bizLoadAppointService.updateById(loadAppoint);

        //更新装卸时间段的已约次数
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordAddParam.getLoadTimeId())) {
            BizLoadTime bizLoadTime = bizLoadTimeService.getById(bizAppointmentRecordAddParam.getLoadTimeId());
            if (ObjectUtil.isNotNull(bizLoadTime)) {
                bizLoadTime.setAlreadyNumber(bizLoadTime.getAlreadyNumber() + 1);
                bizLoadTimeService.updateById(bizLoadTime);
            }
        }

        //跟新起卸订单预约次数
        BizLoadAppoint appoint = bizLoadAppointService.getById(bizAppointmentRecordAddParam.getOrderId());
        if(ObjectUtil.isNotNull(appoint)){
            //修改起卸已约次数
            appoint.setAlreadyAppointNumber(appoint.getAlreadyAppointNumber()+1);
            bizLoadAppointService.updateById(appoint);
        }

    }


    public void checkLoadParam(BizAppointmentRecordAddParam bizAppointmentRecordAddParam) {
        //校验车牌号
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordAddParam.getLicenseNumber())) {
            bizAppointmentRecordAddParam.setLicenseNumber(bizAppointmentRecordAddParam.getLicenseNumber().toUpperCase().trim());
            //校验车牌号是否添加过预约，排除11：已签收、 13:销售已审核  、 14：已取消
            long count = this.count(new QueryWrapper<BizAppointmentRecord>().lambda().
                    eq(BizAppointmentRecord::getLicenseNumber, bizAppointmentRecordAddParam.getLicenseNumber()).
                    notIn(BizAppointmentRecord::getStatus, "10", "11", "12", "13", "14", "15","18","19"));
            if (count > 0) {
                throw new CommonException("车牌号：{}已经添加过预约！", bizAppointmentRecordAddParam.getLicenseNumber());
            }

            //查询是否存在没有回签的记录
            QueryWrapper<BizAppointmentRecord> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("bar.delete_flag", "NOT_DELETE");
            queryWrapper.isNull("br.unload_weight");
            queryWrapper.eq("bla.order_type", "1");
            queryWrapper.eq("bar.`status`", "10");
            queryWrapper.eq("bar.license_number", bizAppointmentRecordAddParam.getLicenseNumber());
            List<BizAppointmentRecord> recordList = this.getBaseMapper().getLoadList(queryWrapper);
            if (ObjectUtil.isNotEmpty(recordList)) {
                throw new CommonException("请先填写回签信息，再进行预约！");
            }
        }
        //校验手机号
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordAddParam.getDriverMobile())) {
            if (!PhoneUtil.isMobile(bizAppointmentRecordAddParam.getDriverMobile())) {
                throw new CommonException("手机号码：{}格式错误", bizAppointmentRecordAddParam.getDriverMobile());
            }
        }
        //校验订单
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordAddParam.getOrderId())) {
            BizLoadAppoint loadAppoint = bizLoadAppointService.getById(bizAppointmentRecordAddParam.getOrderId());
            if (ObjectUtil.isNotNull(loadAppoint)) {
                if (!StringUtils.equals(loadAppoint.getStatus(), "5") && !StringUtils.equals(loadAppoint.getStatus(), "6")) {
                    throw new CommonException("当前订单不可预约！");
                }

                //查询订单下的供应商
                List<BizLoadAppointSupplier> supplierList = bizLoadAppointSupplierService.list(new QueryWrapper<BizLoadAppointSupplier>().lambda().
                        eq(BizLoadAppointSupplier::getAppointId, bizAppointmentRecordAddParam.getOrderId()));
                List<String> supplierIdList = Lists.newArrayList();
                supplierList.forEach(supplier -> supplierIdList.add(supplier.getSupplierId()));
                //查询车辆是否在供应商名下
                BizSupplierTransport transport = bizSupplierTransportService.getOne(new QueryWrapper<BizSupplierTransport>().lambda().
                        in(BizSupplierTransport::getSupplierId, supplierIdList).
                        eq(BizSupplierTransport::getTransportNo, bizAppointmentRecordAddParam.getLicenseNumber()).
                        eq(BizSupplierTransport::getAuditStatus, "2").
                        last("limit 1"));
                if (ObjectUtil.isNull(transport)) {
                    throw new CommonException("该车辆没有绑定在供应商下，不可预约！");
                }
            }
        }
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordAddParam.getLoadTimeId())) {
            //查询预约时间段内可预约次数
            getLoadTimeCount(bizAppointmentRecordAddParam);
        }
    }

    public void getLoadTimeCount(BizAppointmentRecordAddParam bizAppointmentRecordAddParam) {
        lock.lock();
        try {
            //判断装卸预约次数是否满足
            if (ObjectUtil.isNotEmpty(bizAppointmentRecordAddParam.getLoadTimeId())) {
                BizLoadTime bizLoadTime = bizLoadTimeService.queryEntity(bizAppointmentRecordAddParam.getLoadTimeId());
                if (bizLoadTime.getAvailableNumber() - bizLoadTime.getAlreadyNumber() <= 0) {
                    throw new CommonException("当前装卸时段预约已满，不可预约！");
                }
                if (new Date().getTime() > bizLoadTime.getEndTime().getTime()) {
                    throw new CommonException("装卸时间段已过，不可预约！");
                }
            }

            //判断起卸订单预约次数是否满足
            BizLoadAppoint loadAppoint = bizLoadAppointService.getById(bizAppointmentRecordAddParam.getOrderId());
            if(ObjectUtil.isNotNull(loadAppoint)){
                //获取剩余可约次数
                int number = loadAppoint.getAppointNumber() - loadAppoint.getAlreadyAppointNumber();
                if(number <= 0){
                    throw new CommonException("起卸订单已预约满！");
                }
            }

        } finally {
            lock.unlock(); // 释放锁
        }

    }


    @Transactional
    @Override
    public void editLoad(BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        BizAppointmentRecord bizAppointmentRecord = this.queryEntity(bizAppointmentRecordEditParam.getId());
        checkLoadParam(bizAppointmentRecordEditParam, bizAppointmentRecord);
        if (!StringUtils.equals(bizAppointmentRecord.getLoadTimeId(), bizAppointmentRecordEditParam.getLoadTimeId())) {
            //调整了装卸时段，释放之前的已约次数，更新新的时段已约次数
            if (ObjectUtil.isNotEmpty(bizAppointmentRecordEditParam.getLoadTimeId())) {
                BizLoadTime bizLoadTime = bizLoadTimeService.getById(bizAppointmentRecordEditParam.getLoadTimeId());
                if (ObjectUtil.isNotNull(bizLoadTime)) {
                    bizLoadTime.setAlreadyNumber(bizLoadTime.getAlreadyNumber() + 1);
                    bizLoadTimeService.updateById(bizLoadTime);
                }
            }

            if (ObjectUtil.isNotEmpty(bizAppointmentRecord.getLoadTimeId())) {
                BizLoadTime bizLoadTime = bizLoadTimeService.getById(bizAppointmentRecord.getLoadTimeId());
                if (ObjectUtil.isNotNull(bizLoadTime)) {
                    bizLoadTime.setAlreadyNumber(bizLoadTime.getAlreadyNumber() - 1);
                    bizLoadTimeService.updateById(bizLoadTime);
                }
            }
        }
        if(!StringUtils.equals(bizAppointmentRecord.getOrderId(),bizAppointmentRecordEditParam.getOrderId())){
            //获取旧的起卸订单
            BizLoadAppoint oldOrder = bizLoadAppointService.getById(bizAppointmentRecord.getOrderId());
            if(ObjectUtil.isNotNull(oldOrder)){
                oldOrder.setAlreadyAppointNumber(oldOrder.getAlreadyAppointNumber() - 1);
                bizLoadAppointService.updateById(oldOrder);
            }

            //获取新的起卸订单
            BizLoadAppoint newOrder = bizLoadAppointService.getById(bizAppointmentRecordEditParam.getOrderId());
            if(ObjectUtil.isNotNull(newOrder)){
                newOrder.setAlreadyAppointNumber(newOrder.getAlreadyAppointNumber() + 1);
                bizLoadAppointService.updateById(newOrder);
            }
        }
        BeanUtil.copyProperties(bizAppointmentRecordEditParam, bizAppointmentRecord);
        if (StringUtils.equals(bizAppointmentRecord.getStatus(), "2")) {
            //如果当前状态是审核不通过的状态，修改后重新提交审核
            bizAppointmentRecord.setStatus("1");
        }
        this.updateById(bizAppointmentRecord);
    }

    @Override
    public void endLoadAppoint(BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        BizAppointmentRecord bizAppointmentRecord = this.queryEntity(bizAppointmentRecordEditParam.getId());
        bizAppointmentRecord.setStatus("10");
        this.updateById(bizAppointmentRecord);
    }

    public void checkLoadParam(BizAppointmentRecordEditParam bizAppointmentRecordEditParam, BizAppointmentRecord bizAppointmentRecord) {
        //校验车牌号
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordEditParam.getLicenseNumber())) {
            bizAppointmentRecordEditParam.setLicenseNumber(bizAppointmentRecordEditParam.getLicenseNumber().toUpperCase().trim());
            if (!StringUtils.equals(bizAppointmentRecord.getLicenseNumber(), bizAppointmentRecordEditParam.getLicenseNumber())) {
                //校验车牌号是否添加过预约，排除11：已签收、 13:销售已审核  、 14：已取消
                long count = this.count(new QueryWrapper<BizAppointmentRecord>().lambda().
                        eq(BizAppointmentRecord::getLicenseNumber, bizAppointmentRecordEditParam.getLicenseNumber()).
                        notIn(BizAppointmentRecord::getStatus, "10", "11", "12", "13", "14", "15","19"));
                if (count > 0) {
                    throw new CommonException("车牌号：{}已经添加过预约！", bizAppointmentRecordEditParam.getLicenseNumber());
                }

                //查询是否存在没有回签的记录
                QueryWrapper<BizAppointmentRecord> queryWrapper = new QueryWrapper<>();
                queryWrapper.eq("bar.delete_flag", "NOT_DELETE");
                queryWrapper.isNull("br.unload_weight");
                queryWrapper.eq("bo.order_type", "1");
                queryWrapper.eq("bar.`status`", "10");
                queryWrapper.eq("bar.license_number", bizAppointmentRecordEditParam.getLicenseNumber());
                List<BizAppointmentRecord> recordList = this.getBaseMapper().getRecordList(queryWrapper);
                if (ObjectUtil.isNotEmpty(recordList)) {
                    throw new CommonException("请先填写回签信息，再进行预约！");
                }
            }
        }
        //校验手机号
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordEditParam.getDriverMobile())) {
            if (!PhoneUtil.isMobile(bizAppointmentRecordEditParam.getDriverMobile())) {
                throw new CommonException("手机号码：{}格式错误", bizAppointmentRecordEditParam.getDriverMobile());
            }
        }
        //校验订单
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordEditParam.getOrderId())) {
            BizLoadAppoint loadAppoint = bizLoadAppointService.getById(bizAppointmentRecordEditParam.getOrderId());
            if (ObjectUtil.isNotNull(loadAppoint)) {
                if (!StringUtils.equals(loadAppoint.getStatus(), "5") && !StringUtils.equals(loadAppoint.getStatus(), "6")) {
                    throw new CommonException("当前订单不可预约！");
                }

                //查询订单下的供应商
                List<BizLoadAppointSupplier> supplierList = bizLoadAppointSupplierService.list(new QueryWrapper<BizLoadAppointSupplier>().lambda().
                        eq(BizLoadAppointSupplier::getAppointId, bizAppointmentRecordEditParam.getOrderId()));
                List<String> supplierIdList = Lists.newArrayList();
                supplierList.forEach(supplier -> supplierIdList.add(supplier.getSupplierId()));
                //查询车辆是否在供应商名下
                BizSupplierTransport transport = bizSupplierTransportService.getOne(new QueryWrapper<BizSupplierTransport>().lambda().
                        in(BizSupplierTransport::getSupplierId, supplierIdList).
                        eq(BizSupplierTransport::getTransportNo, bizAppointmentRecordEditParam.getLicenseNumber()).
                        eq(BizSupplierTransport::getAuditStatus, "2").
                        last("limit 1"));
                if (ObjectUtil.isNull(transport)) {
                    throw new CommonException("该车辆没有绑定在供应商下，不可预约！");
                }
            }

        }
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordEditParam.getLoadTimeId())) {
            //查询预约时间段内可预约次数
            getLoadTimeCount(bizAppointmentRecordEditParam, bizAppointmentRecord);
        }
    }


    public void getLoadTimeCount(BizAppointmentRecordEditParam bizAppointmentRecordEditParam, BizAppointmentRecord bizAppointmentRecord) {
        lock.lock();
        try {
            //判断装卸预约次数是否满足
            if (ObjectUtil.isNotEmpty(bizAppointmentRecordEditParam.getLoadTimeId())) {
                if (!StringUtils.equals(bizAppointmentRecord.getLoadTimeId(), bizAppointmentRecordEditParam.getLoadTimeId())) {
                    BizLoadTime bizLoadTime = bizLoadTimeService.queryEntity(bizAppointmentRecordEditParam.getLoadTimeId());
                    if (bizLoadTime.getAvailableNumber() - bizLoadTime.getAlreadyNumber() <= 0) {
                        throw new CommonException("当前装卸时段预约已满，不可预约！");
                    }
                    if (new Date().getTime() > bizLoadTime.getEndTime().getTime()) {
                        throw new CommonException("装卸时间段已过，不可预约！");
                    }
                }

            }

            //判断是否更换过起卸订单
            if(!StringUtils.equals(bizAppointmentRecord.getOrderId(),bizAppointmentRecordEditParam.getOrderId())){
                BizLoadAppoint loadAppoint = bizLoadAppointService.getById(bizAppointmentRecordEditParam.getOrderId());
                if(ObjectUtil.isNotNull(loadAppoint)){
                    //获取起卸订单剩余可约次数
                    int number = loadAppoint.getAppointNumber() - loadAppoint.getAlreadyAppointNumber();
                    if(number <= 0){
                        throw new CommonException("起卸订单已经预约满！");
                    }
                }
            }
        } finally {
            lock.unlock(); // 释放锁
        }

    }


    @Override
    public void exportLoadRecord(BizAppointmentRecordPageParam bizAppointmentRecordPageParam, HttpServletResponse response) throws IOException {
        QueryWrapper<BizAppointmentRecord> queryWrapper = getQueryWrapper(bizAppointmentRecordPageParam);
        List<BizAppointmentRecord> recordList = this.getBaseMapper().getLoadPage(queryWrapper);
        String fileName = "起卸预约报表.xlsx";
        List<BizLoadAppointmentExportResult> list = Lists.newArrayList();
        transService.transBatch(recordList);
        for (BizAppointmentRecord bizAppointmentRecord : recordList) {
            BizLoadAppointmentExportResult bizAppointmentExportResult = new BizLoadAppointmentExportResult();
            BeanUtil.copyProperties(bizAppointmentRecord, bizAppointmentExportResult);
            bizAppointmentExportResult.setStatusName((String) bizAppointmentRecord.getTransMap().get("statusName"));
            bizAppointmentExportResult.setAxleNumber(bizAppointmentRecord.getAxleNumber() + "轴");
            list.add(bizAppointmentExportResult);
        }
        CommonExportUtil.export(fileName, BizLoadAppointmentExportResult.class, list, response, "起卸预约报表");
    }

    @Transactional
    @Override
    public void addPipeAppoint(BizAppointmentRecordAddParam bizAppointmentRecordAddParam) {
        checkPipeParam(bizAppointmentRecordAddParam);
        //获取流程配置判断预约是否需要审核
        BizConfig bizConfig = bizConfigService.getOne(new QueryWrapper<BizConfig>().lambda().last("limit 1"));
        BizAppointmentRecord bizAppointmentRecord = BeanUtil.toBean(bizAppointmentRecordAddParam, BizAppointmentRecord.class);
        if (ObjectUtil.isNotNull(bizConfig)) {
            if (StringUtils.equals(bizConfig.getTemporaryAuditSwitch(), "1")) {
                //开启审核，设置待审核状态
                bizAppointmentRecord.setStatus("1");
            } else {
                //未开启审核，设置待入场状态
                bizAppointmentRecord.setStatus("4");
            }
        }
        if(ObjectUtil.isNotEmpty(bizAppointmentRecordAddParam.getDriverId())){
            BizUser bizUser = bizUserService.getById(bizAppointmentRecordAddParam.getDriverId());
            if(ObjectUtil.isEmpty(bizAppointmentRecord.getDriverName())){
                bizAppointmentRecord.setDriverName(bizUser.getName());
            }
            if(ObjectUtil.isEmpty(bizAppointmentRecord.getDriverMobile())){
                bizAppointmentRecord.setDriverMobile(bizUser.getPhone());
            }
        }
        bizAppointmentRecord.setAppointmentType("5");
        this.save(bizAppointmentRecord);

        //修改管桩计划状态
        BizPipePlan pipePlan = bizPipePlanService.getById(bizAppointmentRecordAddParam.getOrderId());
        if (ObjectUtil.isNotNull(pipePlan)) {
            pipePlan.setStatus("2");
            pipePlan.setPlanAlreadyCount(pipePlan.getPlanAlreadyCount() + 1);
            bizPipePlanService.updateById(pipePlan);
        }
    }

    public void checkPipeParam(BizAppointmentRecordAddParam bizAppointmentRecordAddParam) {
        //校验车牌号
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordAddParam.getLicenseNumber())) {
            bizAppointmentRecordAddParam.setLicenseNumber(bizAppointmentRecordAddParam.getLicenseNumber().toUpperCase().trim());
            //校验车牌号是否添加过预约，排除11：已签收、 13:销售已审核  、 14：已取消
            long count = this.count(new QueryWrapper<BizAppointmentRecord>().lambda().
                    eq(BizAppointmentRecord::getLicenseNumber, bizAppointmentRecordAddParam.getLicenseNumber()).
                    notIn(BizAppointmentRecord::getStatus, "10", "11", "12", "13", "14", "15","19"));
            if (count > 0) {
                throw new CommonException("车牌号：{}已经添加过预约！", bizAppointmentRecordAddParam.getLicenseNumber());
            }
        }
        //校验手机号
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordAddParam.getDriverMobile())) {
            if (!PhoneUtil.isMobile(bizAppointmentRecordAddParam.getDriverMobile())) {
                throw new CommonException("手机号码：{}格式错误", bizAppointmentRecordAddParam.getDriverMobile());
            }
        }
        //校验订单
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordAddParam.getOrderId())) {
            BizPipePlan pipePlan = bizPipePlanService.getById(bizAppointmentRecordAddParam.getOrderId());
            if (ObjectUtil.isNotNull(pipePlan)) {
                if (!StringUtils.equals(pipePlan.getStatus(), "1") && !StringUtils.equals(pipePlan.getStatus(), "2")) {
                    throw new CommonException("当前订单不可预约！");
                }
            }
        }

        //查询预约时间段内可预约次数
        getPipeTimeCount(bizAppointmentRecordAddParam);
    }

    public void getPipeTimeCount(BizAppointmentRecordAddParam bizAppointmentRecordAddParam) {
        lock.lock();
        try {
            //判断管桩计划次数是否满足
            if (ObjectUtil.isNotEmpty(bizAppointmentRecordAddParam.getOrderId())) {
                BizPipePlan pipePlan = bizPipePlanService.getById(bizAppointmentRecordAddParam.getOrderId());
                if (ObjectUtil.isNotNull(pipePlan)) {
                    if (pipePlan.getPlanCount() - pipePlan.getPlanAlreadyCount() <= 0) {
                        throw new CommonException("当前管桩计划单预约次数已满");
                    }
                }
            }
        } finally {
            lock.unlock(); // 释放锁
        }

    }

    @Transactional
    @Override
    public void editPipeAppoint(BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        BizAppointmentRecord bizAppointmentRecord = this.queryEntity(bizAppointmentRecordEditParam.getId());
        checkPipeParam(bizAppointmentRecordEditParam, bizAppointmentRecord);
        if (!StringUtils.equals(bizAppointmentRecord.getLoadTimeId(), bizAppointmentRecordEditParam.getLoadTimeId())) {
            //调整了装卸时段，释放之前的已约次数，更新新的时段已约次数
            if (ObjectUtil.isNotEmpty(bizAppointmentRecordEditParam.getLoadTimeId())) {
                BizLoadTime bizLoadTime = bizLoadTimeService.getById(bizAppointmentRecordEditParam.getLoadTimeId());
                if (ObjectUtil.isNotNull(bizLoadTime)) {
                    bizLoadTime.setAlreadyNumber(bizLoadTime.getAlreadyNumber() + 1);
                    bizLoadTimeService.updateById(bizLoadTime);
                }
            }

            if (ObjectUtil.isNotEmpty(bizAppointmentRecord.getLoadTimeId())) {
                BizLoadTime bizLoadTime = bizLoadTimeService.getById(bizAppointmentRecord.getLoadTimeId());
                if (ObjectUtil.isNotNull(bizLoadTime)) {
                    bizLoadTime.setAlreadyNumber(bizLoadTime.getAlreadyNumber() - 1);
                    bizLoadTimeService.updateById(bizLoadTime);
                }
            }
        }
        if(!StringUtils.equals(bizAppointmentRecord.getDriverId(),bizAppointmentRecordEditParam.getDriverId())){
            BizUser bizUser = bizUserService.getById(bizAppointmentRecordEditParam.getDriverId());
            bizAppointmentRecordEditParam.setDriverName(bizUser.getName());
            bizAppointmentRecordEditParam.setDriverMobile(bizUser.getPhone());
        }
        BeanUtil.copyProperties(bizAppointmentRecordEditParam, bizAppointmentRecord);
        if (StringUtils.equals(bizAppointmentRecord.getStatus(), "2")) {
            //如果当前状态是审核不通过的状态，修改后重新提交审核
            bizAppointmentRecord.setStatus("1");
        }
        this.updateById(bizAppointmentRecord);
    }

    public void checkPipeParam(BizAppointmentRecordEditParam bizAppointmentRecordEditParam, BizAppointmentRecord bizAppointmentRecord) {
        //校验车牌号
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordEditParam.getLicenseNumber())) {
            bizAppointmentRecordEditParam.setLicenseNumber(bizAppointmentRecordEditParam.getLicenseNumber().toUpperCase().trim());
            if (!StringUtils.equals(bizAppointmentRecord.getLicenseNumber(), bizAppointmentRecordEditParam.getLicenseNumber())) {
                //校验车牌号是否添加过预约，排除11：已签收、 13:销售已审核  、 14：已取消
                long count = this.count(new QueryWrapper<BizAppointmentRecord>().lambda().
                        eq(BizAppointmentRecord::getLicenseNumber, bizAppointmentRecordEditParam.getLicenseNumber()).
                        notIn(BizAppointmentRecord::getStatus, "10", "11", "12", "13", "14", "15","19"));
                if (count > 0) {
                    throw new CommonException("车牌号：{}已经添加过预约！", bizAppointmentRecordEditParam.getLicenseNumber());
                }
            }
        }
        //校验手机号
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordEditParam.getDriverMobile())) {
            if (!PhoneUtil.isMobile(bizAppointmentRecordEditParam.getDriverMobile())) {
                throw new CommonException("手机号码：{}格式错误", bizAppointmentRecordEditParam.getDriverMobile());
            }
        }
        //校验订单
        if (ObjectUtil.isNotEmpty(bizAppointmentRecordEditParam.getOrderId())) {
            BizPipePlan pipePlan = bizPipePlanService.getById(bizAppointmentRecordEditParam.getOrderId());
            if (ObjectUtil.isNotNull(pipePlan)) {
                if (!StringUtils.equals(pipePlan.getStatus(), "1") && !StringUtils.equals(pipePlan.getStatus(), "2")) {
                    throw new CommonException("当前订单不可预约！");
                }
            }

        }

        //查询预约时间段内可预约次数
        getPipeTimeCount(bizAppointmentRecordEditParam, bizAppointmentRecord);

    }

    public void getPipeTimeCount(BizAppointmentRecordEditParam bizAppointmentRecordEditParam, BizAppointmentRecord bizAppointmentRecord) {
        lock.lock();
        try {
            //判断管桩计划次数是否满足
            if (ObjectUtil.isNotEmpty(bizAppointmentRecordEditParam.getOrderId())) {
                if (!StringUtils.equals(bizAppointmentRecordEditParam.getOrderId(), bizAppointmentRecord.getOrderId())) {
                    BizPipePlan pipePlan = bizPipePlanService.getById(bizAppointmentRecordEditParam.getOrderId());
                    if (ObjectUtil.isNotNull(pipePlan)) {
                        if (pipePlan.getPlanCount() - pipePlan.getPlanAlreadyCount() <= 0) {
                            throw new CommonException("当前管桩计划单预约次数已满");
                        }
                    }
                }
            }
        } finally {
            lock.unlock(); // 释放锁
        }

    }


    @Override
    public Page<BizAppointmentRecord> getPipePage(BizAppointmentRecordPageParam bizAppointmentRecordPageParam) {
        QueryWrapper<BizAppointmentRecord> queryWrapper = getQueryWrapper(bizAppointmentRecordPageParam);
        Page<BizAppointmentRecord> loadPage = this.getBaseMapper().getPipePage(CommonPageRequest.defaultPage(), queryWrapper);
        return loadPage;
    }

    @Override
    public void replacePipeAppoint(BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        //修改预约已取消状态
        BizAppointmentRecord bizAppointmentRecord = this.queryEntity(bizAppointmentRecordEditParam.getId());
        bizAppointmentRecord.setStatus("14");
        this.updateById(bizAppointmentRecord);

        //修改管桩计划单已约数量
        BizPipePlan pipePlan = bizPipePlanService.getById(bizAppointmentRecord.getOrderId());
        if (ObjectUtil.isNotNull(pipePlan)) {
            pipePlan.setPlanAlreadyCount(pipePlan.getPlanAlreadyCount() - 1);
            bizPipePlanService.updateById(pipePlan);
        }

    }

    @Override
    public void completePipeAppoint(BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        BizAppointmentRecord bizAppointmentRecord = this.queryEntity(bizAppointmentRecordEditParam.getId());
        bizAppointmentRecord.setStatus("9");
        this.updateById(bizAppointmentRecord);
    }

    @Override
    public void endPipeAppoint(BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        BizAppointmentRecord bizAppointmentRecord = this.queryEntity(bizAppointmentRecordEditParam.getId());
        bizAppointmentRecord.setStatus("10");
        this.updateById(bizAppointmentRecord);
    }


    @Override
    public void addOtherAppointment(BizOtherAppointmentAddParam bizOtherAppointmentAddParam) {
        checkParam(bizOtherAppointmentAddParam.getLicenseNumber());
        //获取流程配置判断预约是否需要审核
        BizAppointmentRecord bizAppointmentRecord = BeanUtil.toBean(bizOtherAppointmentAddParam, BizAppointmentRecord.class);
        BizUser bizUser = bizUserService.getById(bizOtherAppointmentAddParam.getDriverId());
        if (bizUser != null) {
            bizAppointmentRecord.setDriverName(bizUser.getName());
            bizAppointmentRecord.setDriverMobile(bizUser.getPhone());
        }
        bizAppointmentRecord.setOtherNumber(getNumber("QT", "6"));
        //默认赋值待入场状态
        bizAppointmentRecord.setStatus("4");
        bizAppointmentRecord.setAppointmentType("6");
        this.save(bizAppointmentRecord);
    }

    @Override
    public void editOtherAppointment(BizOtherAppointmentEditParam bizOtherAppointmentEditParam) {
        BizAppointmentRecord bizAppointmentRecord = this.queryEntity(bizOtherAppointmentEditParam.getId());
        if (!bizAppointmentRecord.getLicenseNumber().equals(bizOtherAppointmentEditParam.getLicenseNumber())) {
            checkParam(bizOtherAppointmentEditParam.getLicenseNumber());
        }
        BizAppointmentRecord bizAppointmentRecordUp = BeanUtil.toBean(bizOtherAppointmentEditParam, BizAppointmentRecord.class);
        BizUser bizUser = bizUserService.getById(bizOtherAppointmentEditParam.getDriverId());
        if (bizUser != null) {
            bizAppointmentRecordUp.setDriverName(bizUser.getName());
            bizAppointmentRecordUp.setDriverMobile(bizUser.getPhone());
        }
        this.updateById(bizAppointmentRecordUp);
    }


    //预约校验
    public void checkParam(String licenseNumber) {
        //校验车牌号
        if (ObjectUtil.isNotEmpty(licenseNumber)) {
            licenseNumber = licenseNumber.toUpperCase().trim();
            //校验车牌号是否添加过预约，排除11：已签收、 13:销售已审核  、 14：已取消
            BizAppointmentRecord bizAppointmentRecord = this.getOne(new QueryWrapper<BizAppointmentRecord>().lambda().
                    eq(BizAppointmentRecord::getLicenseNumber, licenseNumber).
                    notIn(BizAppointmentRecord::getStatus, "10", "11", "12", "13", "14", "15", "19")
                    .last("limit 1"));
            if (bizAppointmentRecord != null) {
                transService.transOne(bizAppointmentRecord);
                throw new CommonException("车牌号：{}已经存在【" + (String) bizAppointmentRecord.getTransMap().get("appointmentTypeName") + "】类型的有效预约记录！", licenseNumber);
            }
        }
    }

    @Override
    public void exportPipeRecord(BizAppointmentRecordPageParam bizAppointmentRecordPageParam, HttpServletResponse response) throws IOException {
        QueryWrapper<BizAppointmentRecord> queryWrapper = getQueryWrapper(bizAppointmentRecordPageParam);
        List<BizAppointmentRecord> recordList = this.getBaseMapper().getPipePage(queryWrapper);
        String fileName = "管桩预约报表.xlsx";
        List<BizPipeAppointmentExportResult> list = Lists.newArrayList();
        transService.transBatch(recordList);
        for (BizAppointmentRecord bizAppointmentRecord : recordList) {
            BizPipeAppointmentExportResult bizAppointmentExportResult = new BizPipeAppointmentExportResult();
            BeanUtil.copyProperties(bizAppointmentRecord, bizAppointmentExportResult);
            bizAppointmentExportResult.setStatusName((String) bizAppointmentRecord.getTransMap().get("statusName"));
            list.add(bizAppointmentExportResult);
        }
        CommonExportUtil.export(fileName, BizPipeAppointmentExportResult.class, list, response, "管桩预约报表");
    }


    @Override
    public void bizOtherAppointmentExit(BizAppointmentRecordIdParam bizAppointmentRecordIdParam) {
        BizAppointmentRecord bizAppointmentRecord = this.queryEntity(bizAppointmentRecordIdParam.getId());
        if ("10".equals(bizAppointmentRecord.getStatus())) {
            throw new CommonException("当前流程已经强制结束,不可重复操作！");
        }
        //强制结束，将状态改成已出场，同时记录操作人以及操作时间
        SaBaseLoginUser loginUser = StpLoginUserUtil.getLoginUser();
        bizAppointmentRecord.setExitOperator(loginUser.getName());
        bizAppointmentRecord.setExitTime(DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss")
                .format(LocalDateTime.now()));
        bizAppointmentRecord.setStatus("10");
        this.updateById(bizAppointmentRecord);
    }

    @Override
    public void bizOtherAppointmentAuthorize(BizAppointmentRecordIdParam bizAppointmentRecordIdParam) {
        BizAppointmentRecord bizAppointmentRecord = this.queryEntity(bizAppointmentRecordIdParam.getId());
        if ("9".equals(bizAppointmentRecord.getStatus())) {
            throw new CommonException("当前流程已经授权离场,不可重复操作！");
        }
        //强制结束，将状态改成已出场，同时记录操作人以及操作时间
        SaBaseLoginUser loginUser = StpLoginUserUtil.getLoginUser();
        bizAppointmentRecord.setAuthorizeOperator(loginUser.getName());
        bizAppointmentRecord.setAuthorizeTime(DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss")
                .format(LocalDateTime.now()));
        bizAppointmentRecord.setStatus("9");
        this.updateById(bizAppointmentRecord);
    }

    @Override
    public void bizOtherAppointmentComplete(BizAppointmentRecordIdParam bizAppointmentRecordIdParam) {
        BizAppointmentRecord bizAppointmentRecord = this.queryEntity(bizAppointmentRecordIdParam.getId());
        if(StringUtils.equals(bizAppointmentRecord.getIsWeigh(),"1")){
            bizAppointmentRecord.setStatus("7");
        }else{
            bizAppointmentRecord.setStatus("9");
        }

        this.updateById(bizAppointmentRecord);
    }


    @Override
    public void bizOtherAppointmentExport(BizAppointmentRecordPageParam bizAppointmentRecordPageParam, HttpServletResponse response) throws IOException {
        QueryWrapper<BizAppointmentRecord> queryWrapper = getQueryWrapper(bizAppointmentRecordPageParam);
        List<BizAppointmentRecord> recordList = this.getBaseMapper().getPage(queryWrapper);
        String fileName = "其他预约报表.xlsx";
        List<BizOtherAppointmentExportResult> list = Lists.newArrayList();
        transService.transBatch(recordList);
        for (BizAppointmentRecord bizAppointmentRecord : recordList) {
            BizOtherAppointmentExportResult bizOtherAppointmentExportResult = new BizOtherAppointmentExportResult();
            BeanUtil.copyProperties(bizAppointmentRecord, bizOtherAppointmentExportResult);
            bizOtherAppointmentExportResult.setStatusName((String) bizAppointmentRecord.getTransMap().get("statusName"));
            bizOtherAppointmentExportResult.setIsWeigh((String) bizAppointmentRecord.getTransMap().get("isWeightName"));
            list.add(bizOtherAppointmentExportResult);
        }
        CommonExportUtil.export(fileName, BizOtherAppointmentExportResult.class, list, response, "其他预约报表");
    }


    public String getNumber(String startPrefix, String appointmentType) {
        lock.lock();
        try {
            String format = new SimpleDateFormat("yyyyMMdd").format(new Date());
            String time = new SimpleDateFormat("yyyy-MM-dd").format(new Date());
            long count = this.count(new QueryWrapper<BizAppointmentRecord>().lambda()
                    .eq(BizAppointmentRecord::getAppointmentType, appointmentType)
                    .between(BizAppointmentRecord::getCreateTime,
                            time + " 00:00:00", time + " 23:59:59"));
            String settleNo = startPrefix + format + generateCode((int) count);
            return settleNo;
        } finally {
            lock.unlock(); // 释放锁
        }

    }

    public static String generateCode(Integer counter) {
        counter++;
        return String.format("%03d", counter);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void addChargeStationReservation(BizChargeStationReservationAddParam bizChargeStationReservationAddParam) {
        //校验是否存在有效得预约信息
        checkParam(bizChargeStationReservationAddParam.getLicenseNumber());
        lock.lock();
        try {
            //校验一下充电桩剩余数量是否够扣减
            //查询充电桩配置信息
            BizChargeStation bizChargeStation = bizChargeStationService.getOne(new QueryWrapper<BizChargeStation>()
                    .lambda().eq(BizChargeStation::getDeleteFlag, 0).last("limit 1"));
            if (bizChargeStation != null && (bizChargeStation.getChargeStationTotalNumber() - bizChargeStation.getChargeStationUsedNumber()) < 1) {
                throw new CommonException("充电桩已无剩余充电桩数量");
            }

            //获取流程配置判断预约是否需要审核
            BizAppointmentRecord bizAppointmentRecord = BeanUtil.toBean(bizChargeStationReservationAddParam, BizAppointmentRecord.class);
            BizUser bizUser = bizUserService.getById(bizChargeStationReservationAddParam.getDriverId());
            if (bizUser != null) {
                bizAppointmentRecord.setDriverName(bizUser.getName());
                bizAppointmentRecord.setDriverMobile(bizUser.getPhone());
            }
            bizAppointmentRecord.setOtherNumber(getNumber("CD", "4"));
            //默认赋值待入场状态
            bizAppointmentRecord.setStatus("4");
            bizAppointmentRecord.setAppointmentType("4");
            //新增成功，并将充电桩已使用数量进行扣减
            if (this.save(bizAppointmentRecord)) {
                bizChargeStation.setChargeStationUsedNumber(bizChargeStation.getChargeStationUsedNumber() + 1);
                bizChargeStationService.updateById(bizChargeStation);
            }
        } finally {
            lock.unlock();
        }


    }

    @Override
    public void editChargeStationReservation(BizChargeStationReservationEditParam bizChargeStationReservationEditParam) {
        BizAppointmentRecord bizAppointmentRecord = this.queryEntity(bizChargeStationReservationEditParam.getId());
        if (!bizAppointmentRecord.getLicenseNumber().equals(bizChargeStationReservationEditParam.getLicenseNumber())) {
            //校验是否存在有效得预约信息
            checkParam(bizChargeStationReservationEditParam.getLicenseNumber());
        }
        BizAppointmentRecord bizAppointmentRecordUp = BeanUtil.toBean(bizChargeStationReservationEditParam, BizAppointmentRecord.class);
        BizUser bizUser = bizUserService.getById(bizChargeStationReservationEditParam.getDriverId());
        if (bizUser != null) {
            bizAppointmentRecordUp.setDriverName(bizUser.getName());
            bizAppointmentRecordUp.setDriverMobile(bizUser.getPhone());
        }
        this.updateById(bizAppointmentRecordUp);
    }


    @Transactional(rollbackFor = Exception.class)
    @Override
    public void deleteChargeStationReservation(List<BizAppointmentRecordIdParam> bizAppointmentRecordIdParamList) {
        lock.lock();
        try {
            //释放充电数量
            //查询充电桩配置信息
            BizChargeStation bizChargeStation = bizChargeStationService.getOne(new QueryWrapper<BizChargeStation>()
                    .lambda().eq(BizChargeStation::getDeleteFlag, 0).last("limit 1"));
            if (ObjectUtil.isNotNull(bizChargeStation)) {
                bizChargeStation.setChargeStationUsedNumber(bizChargeStation.getChargeStationUsedNumber() - 1);
                bizChargeStationService.updateById(bizChargeStation);
            }
            // 执行删除
            this.removeByIds(CollStreamUtil.toList(bizAppointmentRecordIdParamList, BizAppointmentRecordIdParam::getId));
        } finally {
            lock.unlock();
        }

    }
    @Transactional(rollbackFor = Exception.class)
    @Override
    public void bizChargeStationReservationExit(BizAppointmentRecordIdParam bizAppointmentRecordIdParam) {
        lock.lock();
        try {
            //充电结束
            BizAppointmentRecord bizAppointmentRecord = this.queryEntity(bizAppointmentRecordIdParam.getId());
            bizAppointmentRecord.setStatus("18");
            if(this.updateById(bizAppointmentRecord)){
                //释放充电数量
                //查询充电桩配置信息
                BizChargeStation bizChargeStation = bizChargeStationService.getOne(new QueryWrapper<BizChargeStation>()
                        .lambda().eq(BizChargeStation::getDeleteFlag, 0).last("limit 1"));
                if (ObjectUtil.isNotNull(bizChargeStation)) {
                    bizChargeStation.setChargeStationUsedNumber(bizChargeStation.getChargeStationUsedNumber() - 1);
                    bizChargeStationService.updateById(bizChargeStation);
                }
            }

        } finally {
            lock.unlock();
        }

    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void bizChargeStationEnd(BizAppointmentRecordIdParam bizAppointmentRecordIdParam) {
        lock.lock();
        try {
            BizAppointmentRecord bizAppointmentRecord = this.queryEntity(bizAppointmentRecordIdParam.getId());
            if ("10".equals(bizAppointmentRecord.getStatus())) {
                throw new CommonException("当前流程已经强制结束,不可重复操作！");
            }
            //强制结束，将状态改成已出场，同时记录操作人以及操作时间
            SaBaseLoginUser loginUser = StpLoginUserUtil.getLoginUser();
            bizAppointmentRecord.setExitOperator(loginUser.getName());
            bizAppointmentRecord.setExitTime(DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss")
                    .format(LocalDateTime.now()));
            bizAppointmentRecord.setStatus("10");
            if(this.updateById(bizAppointmentRecord)){
                //释放充电数量
                //查询充电桩配置信息
                BizChargeStation bizChargeStation = bizChargeStationService.getOne(new QueryWrapper<BizChargeStation>()
                        .lambda().eq(BizChargeStation::getDeleteFlag, 0).last("limit 1"));
                if (ObjectUtil.isNotNull(bizChargeStation)) {
                    bizChargeStation.setChargeStationUsedNumber(bizChargeStation.getChargeStationUsedNumber() - 1);
                    bizChargeStationService.updateById(bizChargeStation);
                }
            }

        } finally {
            lock.unlock();
        }
    }

    @Override
    public void localConfirm(BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        BizAppointmentRecord bizAppointmentRecord = this.queryEntity(bizAppointmentRecordEditParam.getId());
        log.info("地磅端司机确认开始---车牌号："+bizAppointmentRecord.getLicenseNumber()+",预约id："+bizAppointmentRecord.getId());
        bizAppointmentRecord.setStatus("9");
        this.updateById(bizAppointmentRecord);
        log.info("地磅端司机确认结束");
    }

    @Override
    public void localCancel(BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        BizAppointmentRecord bizAppointmentRecord = this.queryEntity(bizAppointmentRecordEditParam.getId());
        log.info("地磅端司机取消开始---车牌号："+bizAppointmentRecord.getLicenseNumber()+",预约id："+bizAppointmentRecord.getId());
        bizAppointmentRecord.setStatus("6");
        this.updateById(bizAppointmentRecord);

        //查询过磅记录
        BizRecord bizRecord = bizRecordService.getOne(new QueryWrapper<BizRecord>().lambda().
                eq(BizRecord::getAppointmentId, bizAppointmentRecord.getId()).
                last("limit 1"));
        if(ObjectUtil.isNotNull(bizRecord)){
            bizRecord.setConfirmUser(null);
            LambdaUpdateWrapper<BizRecord> updateWrapper = new LambdaUpdateWrapper<>();
            updateWrapper.eq(BizRecord::getId,bizRecord.getId()).set(BizRecord::getConfirmUser,null);
            bizRecordService.update(updateWrapper);
        }
        log.info("地磅端司机取消结束");
    }

    @Override
    public void cloudCancel(BizAppointmentRecordEditParam bizAppointmentRecordEditParam) {
        BizAppointmentRecord bizAppointmentRecord = this.queryEntity(bizAppointmentRecordEditParam.getId());
        //查询过磅记录
        BizRecord bizRecord = bizRecordService.getOne(new QueryWrapper<BizRecord>().lambda().
                eq(BizRecord::getAppointmentId, bizAppointmentRecord.getId()).
                last("limit 1"));

        if(ObjectUtil.isNotNull(bizRecord)){
            //司机取消，下发mqtt
            Map<String, Object> map = Maps.newHashMap();
            map.put("id", bizRecord.getRelationId());
            map.put("type", "21");
            //mqtt发送过磅记录id给地磅端，告诉地磅端可打印磅单，抬道闸
            mqttSubscribeClient.publishMessage(commonProperties.getMqttTopic(), JSONObject.toJSONString(map));
            log.info("司机取消下发车牌号：" + bizRecord.getLicensePlate());
        }

    }


}
