/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizappointreplace.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.bizappointreplace.entity.BizAppointReplace;
import vip.xiaonuo.biz.modular.bizappointreplace.param.BizAppointReplaceAddParam;
import vip.xiaonuo.biz.modular.bizappointreplace.param.BizAppointReplaceEditParam;
import vip.xiaonuo.biz.modular.bizappointreplace.param.BizAppointReplaceIdParam;
import vip.xiaonuo.biz.modular.bizappointreplace.param.BizAppointReplacePageParam;
import vip.xiaonuo.biz.modular.bizappointreplace.service.BizAppointReplaceService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 沙石预约调度控制器
 *
 * @author fanzherong
 * @date  2025/07/11 14:22
 */
@Tag(name = "沙石预约调度控制器")
@RestController
@Validated
public class BizAppointReplaceController {

    @Resource
    private BizAppointReplaceService bizAppointReplaceService;

    /**
     * 获取沙石预约调度分页
     *
     * @author fanzherong
     * @date  2025/07/11 14:22
     */
    @Operation(summary = "获取沙石预约调度分页")
    @SaCheckPermission("/biz/bizappointreplace/page")
    @GetMapping("/biz/bizappointreplace/page")
    public CommonResult<Page<BizAppointReplace>> page(BizAppointReplacePageParam bizAppointReplacePageParam) {
        return CommonResult.data(bizAppointReplaceService.page(bizAppointReplacePageParam));
    }

    /**
     * 添加沙石预约调度
     *
     * @author fanzherong
     * @date  2025/07/11 14:22
     */
    @Operation(summary = "添加沙石预约调度")
    @CommonLog("添加沙石预约调度")
    @PostMapping("/biz/bizappointreplace/add")
    public CommonResult<String> add(@RequestBody @Valid BizAppointReplaceAddParam bizAppointReplaceAddParam) {
        bizAppointReplaceService.add(bizAppointReplaceAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑沙石预约调度
     *
     * @author fanzherong
     * @date  2025/07/11 14:22
     */
    @Operation(summary = "编辑沙石预约调度")
    @CommonLog("编辑沙石预约调度")
    @PostMapping("/biz/bizappointreplace/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizAppointReplaceEditParam bizAppointReplaceEditParam) {
        bizAppointReplaceService.edit(bizAppointReplaceEditParam);
        return CommonResult.ok();
    }

    /**
     * 审核沙石预约调度
     *
     * @author fanzherong
     * @date  2025/07/11 14:22
     */
    @Operation(summary = "审核沙石预约调度")
    @CommonLog("审核沙石预约调度")
    @PostMapping("/biz/bizappointreplace/audit")
    public CommonResult<String> audit(@RequestBody @Valid BizAppointReplaceEditParam bizAppointReplaceEditParam) {
        bizAppointReplaceService.audit(bizAppointReplaceEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除沙石预约调度
     *
     * @author fanzherong
     * @date  2025/07/11 14:22
     */
    @Operation(summary = "删除沙石预约调度")
    @CommonLog("删除沙石预约调度")
    @PostMapping("/biz/bizappointreplace/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizAppointReplaceIdParam> bizAppointReplaceIdParamList) {
        bizAppointReplaceService.delete(bizAppointReplaceIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取沙石预约调度详情
     *
     * @author fanzherong
     * @date  2025/07/11 14:22
     */
    @Operation(summary = "获取沙石预约调度详情")
    @GetMapping("/biz/bizappointreplace/detail")
    public CommonResult<BizAppointReplace> detail(@Valid BizAppointReplaceIdParam bizAppointReplaceIdParam) {
        return CommonResult.data(bizAppointReplaceService.detail(bizAppointReplaceIdParam));
    }
}
