/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizappointreplace.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import jakarta.annotation.Resource;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.biz.modular.bizappointmentrecord.entity.BizAppointmentRecord;
import vip.xiaonuo.biz.modular.bizappointmentrecord.service.BizAppointmentRecordService;
import vip.xiaonuo.biz.modular.bizauditlog.entity.BizAuditLog;
import vip.xiaonuo.biz.modular.bizauditlog.service.BizAuditLogService;
import vip.xiaonuo.biz.modular.bizloadtime.entity.BizLoadTime;
import vip.xiaonuo.biz.modular.bizloadtime.service.BizLoadTimeService;
import vip.xiaonuo.biz.modular.bizorderconfig.entity.BizOrderConfig;
import vip.xiaonuo.biz.modular.bizorderconfig.service.BizOrderConfigService;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizappointreplace.entity.BizAppointReplace;
import vip.xiaonuo.biz.modular.bizappointreplace.mapper.BizAppointReplaceMapper;
import vip.xiaonuo.biz.modular.bizappointreplace.param.BizAppointReplaceAddParam;
import vip.xiaonuo.biz.modular.bizappointreplace.param.BizAppointReplaceEditParam;
import vip.xiaonuo.biz.modular.bizappointreplace.param.BizAppointReplaceIdParam;
import vip.xiaonuo.biz.modular.bizappointreplace.param.BizAppointReplacePageParam;
import vip.xiaonuo.biz.modular.bizappointreplace.service.BizAppointReplaceService;

import java.util.List;

/**
 * 沙石预约调度Service接口实现类
 *
 * @author fanzherong
 * @date  2025/07/11 14:22
 **/
@Service
public class BizAppointReplaceServiceImpl extends ServiceImpl<BizAppointReplaceMapper, BizAppointReplace> implements BizAppointReplaceService {

    @Resource
    private BizAppointmentRecordService bizAppointmentRecordService;

    @Resource
    private BizOrderConfigService bizOrderConfigService;

    @Resource
    private BizLoadTimeService bizLoadTimeService;

    @Resource
    private BizAuditLogService bizAuditLogService;

    @Override
    public Page<BizAppointReplace> page(BizAppointReplacePageParam bizAppointReplacePageParam) {
        QueryWrapper<BizAppointReplace> queryWrapper = new QueryWrapper<BizAppointReplace>().checkSqlInjection();
        //车牌号查询
        if(ObjectUtil.isNotEmpty(bizAppointReplacePageParam.getLicenseNumber())){
            queryWrapper.like("ba.license_number",bizAppointReplacePageParam.getLicenseNumber());
        }
        //司机姓名查询
        if(ObjectUtil.isNotEmpty(bizAppointReplacePageParam.getDriverName())){
            queryWrapper.like("ba.driver_name",bizAppointReplacePageParam.getDriverName());
        }
        //司机电话查询
        if(ObjectUtil.isNotEmpty(bizAppointReplacePageParam.getDriverMobile())){
            queryWrapper.like("ba.driver_mobile",bizAppointReplacePageParam.getDriverMobile());
        }
        queryWrapper.eq("br.delete_flag","NOT_DELETE");
        queryWrapper.orderByDesc("br.create_time");
        return this.getBaseMapper().getPage(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizAppointReplaceAddParam bizAppointReplaceAddParam) {
        BizAppointReplace bizAppointReplace = BeanUtil.toBean(bizAppointReplaceAddParam, BizAppointReplace.class);
        this.save(bizAppointReplace);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizAppointReplaceEditParam bizAppointReplaceEditParam) {
        BizAppointReplace bizAppointReplace = this.queryEntity(bizAppointReplaceEditParam.getId());
        BeanUtil.copyProperties(bizAppointReplaceEditParam, bizAppointReplace);
        this.updateById(bizAppointReplace);
    }

    @Transactional
    @Override
    public void audit(BizAppointReplaceEditParam bizAppointReplaceEditParam) {
        BizAppointReplace bizAppointReplace = this.queryEntity(bizAppointReplaceEditParam.getId());
        String status = "";
        if(StringUtils.equals(bizAppointReplaceEditParam.getAuditFlag(),"true")){
            //审核通过
            bizAppointReplace.setStatus("2");

            //查询旧订单预约配置
            BizOrderConfig oldOrderConfig = bizOrderConfigService.getOne(new QueryWrapper<BizOrderConfig>().lambda().
                    eq(BizOrderConfig::getOrderId, bizAppointReplace.getOldOrderId()).
                    last("limit 1"));
            if(ObjectUtil.isNotNull(oldOrderConfig)){
                //释放旧订单预约次数
                oldOrderConfig.setApplyNumberAlready(oldOrderConfig.getApplyNumberAlready()-1);
                bizOrderConfigService.updateById(oldOrderConfig);
            }

            //查询新订单预约配置
            BizOrderConfig newOrderConfig = bizOrderConfigService.getOne(new QueryWrapper<BizOrderConfig>().lambda().
                    eq(BizOrderConfig::getOrderId, bizAppointReplace.getNewOrderId()).
                    last("limit 1"));
            if(ObjectUtil.isNotNull(newOrderConfig)){
                newOrderConfig.setApplyNumberAlready(newOrderConfig.getApplyNumberAlready()+1);
                bizOrderConfigService.updateById(newOrderConfig);
            }

            //判断装卸时间是否一致
            if(!StringUtils.equals(bizAppointReplace.getOldLoadTimeId(),bizAppointReplace.getNewLoadTimeId())){
                //装卸时间段修改
                //查询旧时间段预约次数
                BizLoadTime oldTime = bizLoadTimeService.getById(bizAppointReplace.getOldLoadTimeId());
                if(ObjectUtil.isNotNull(oldTime)){
                    //释放旧时段预约次数
                    oldTime.setAlreadyNumber(oldTime.getAlreadyNumber()-1);
                    bizLoadTimeService.updateById(oldTime);
                }

                //查询新时段的预约次数
                BizLoadTime newTime = bizLoadTimeService.getById(bizAppointReplace.getNewLoadTimeId());
                if(ObjectUtil.isNotNull(newTime)){
                    //添加新时段预约次数
                    newTime.setAlreadyNumber(newTime.getAlreadyNumber()+1);
                    bizLoadTimeService.updateById(newTime);
                }
            }

            BizAppointmentRecord bizAppointmentRecord = bizAppointmentRecordService.getById(bizAppointReplace.getAppointId());
            if(ObjectUtil.isNotNull(bizAppointmentRecord)){
                //订单修改
                bizAppointmentRecord.setOrderId(bizAppointReplace.getNewOrderId());
                //装卸点位
                bizAppointmentRecord.setLoadPointId(bizAppointReplace.getNewLoadPointId());
                //装卸时间
                bizAppointmentRecord.setLoadTimeId(bizAppointReplace.getNewLoadTimeId());
                bizAppointmentRecord.setStatus(bizAppointReplace.getAppointStatus());

                bizAppointmentRecordService.updateById(bizAppointmentRecord);
            }

            status= "1";

        }else{
            //审核驳回
            bizAppointReplace.setStatus("3");

            BizAppointmentRecord bizAppointmentRecord = bizAppointmentRecordService.getById(bizAppointReplace.getAppointId());
            if(ObjectUtil.isNotNull(bizAppointmentRecord)){
                bizAppointmentRecord.setStatus(bizAppointReplace.getAppointStatus());

                bizAppointmentRecordService.updateById(bizAppointmentRecord);
            }
            status = "2";
        }
        this.updateById(bizAppointReplace);


        //插入审核记录
        BizAuditLog bizAuditLog = new BizAuditLog();
        bizAuditLog.setType("DDSP");
        bizAuditLog.setDataId(bizAppointReplace.getAppointId());
        bizAuditLog.setStatus(status);
        bizAuditLog.setRemark(bizAppointReplaceEditParam.getAuditRemark());
        bizAuditLogService.save(bizAuditLog);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizAppointReplaceIdParam> bizAppointReplaceIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizAppointReplaceIdParamList, BizAppointReplaceIdParam::getId));
    }

    @Override
    public BizAppointReplace detail(BizAppointReplaceIdParam bizAppointReplaceIdParam) {
        QueryWrapper<BizAppointReplace> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("br.id",bizAppointReplaceIdParam.getId());
        if(StringUtils.equals(bizAppointReplaceIdParam.getFlag(),"old")){
            BizAppointReplace oldDetail = this.getBaseMapper().getOldDetail(queryWrapper);
            return oldDetail;
        }else{
            BizAppointReplace newDetail = this.getBaseMapper().getNewDetail(queryWrapper);
            return newDetail;
        }
    }

    @Override
    public BizAppointReplace queryEntity(String id) {
        BizAppointReplace bizAppointReplace = this.getById(id);
        if(ObjectUtil.isEmpty(bizAppointReplace)) {
            throw new CommonException("沙石预约调度不存在，id值为：{}", id);
        }
        return bizAppointReplace;
    }
}
