/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizauditlog.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.bizauditlog.entity.BizAuditLog;
import vip.xiaonuo.biz.modular.bizauditlog.param.BizAuditLogAddParam;
import vip.xiaonuo.biz.modular.bizauditlog.param.BizAuditLogEditParam;
import vip.xiaonuo.biz.modular.bizauditlog.param.BizAuditLogIdParam;
import vip.xiaonuo.biz.modular.bizauditlog.param.BizAuditLogPageParam;
import vip.xiaonuo.biz.modular.bizauditlog.service.BizAuditLogService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 审核记录表控制器
 *
 * @author fanzherong
 * @date  2025/06/16 14:57
 */
@Tag(name = "审核记录表控制器")
@RestController
@Validated
public class BizAuditLogController {

    @Resource
    private BizAuditLogService bizAuditLogService;

    /**
     * 获取审核记录表分页
     *
     * @author fanzherong
     * @date  2025/06/16 14:57
     */
    @Operation(summary = "获取审核记录表分页")
    @SaCheckPermission("/biz/bizauditlog/page")
    @GetMapping("/biz/bizauditlog/page")
    public CommonResult<Page<BizAuditLog>> page(BizAuditLogPageParam bizAuditLogPageParam) {
        return CommonResult.data(bizAuditLogService.page(bizAuditLogPageParam));
    }

    /**
     * 添加审核记录表
     *
     * @author fanzherong
     * @date  2025/06/16 14:57
     */
    @Operation(summary = "添加审核记录表")
    @CommonLog("添加审核记录表")
    @PostMapping("/biz/bizauditlog/add")
    public CommonResult<String> add(@RequestBody @Valid BizAuditLogAddParam bizAuditLogAddParam) {
        bizAuditLogService.add(bizAuditLogAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑审核记录表
     *
     * @author fanzherong
     * @date  2025/06/16 14:57
     */
    @Operation(summary = "编辑审核记录表")
    @CommonLog("编辑审核记录表")
    @PostMapping("/biz/bizauditlog/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizAuditLogEditParam bizAuditLogEditParam) {
        bizAuditLogService.edit(bizAuditLogEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除审核记录表
     *
     * @author fanzherong
     * @date  2025/06/16 14:57
     */
    @Operation(summary = "删除审核记录表")
    @CommonLog("删除审核记录表")
    @PostMapping("/biz/bizauditlog/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizAuditLogIdParam> bizAuditLogIdParamList) {
        bizAuditLogService.delete(bizAuditLogIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取审核记录表详情
     *
     * @author fanzherong
     * @date  2025/06/16 14:57
     */
    @Operation(summary = "获取审核记录表详情")
    @GetMapping("/biz/bizauditlog/detail")
    public CommonResult<BizAuditLog> detail(@Valid BizAuditLogIdParam bizAuditLogIdParam) {
        return CommonResult.data(bizAuditLogService.detail(bizAuditLogIdParam));
    }

    /**
     * 获取审核记录表列表
     *
     * @author fanzherong
     * @date  2025/06/16 14:57
     */
    @Operation(summary = "获取审核记录表列表")
    @GetMapping("/biz/bizauditlog/getList")
    public CommonResult<List<BizAuditLog>> getList(BizAuditLogPageParam bizAuditLogPageParam) {
        return CommonResult.data(bizAuditLogService.getList(bizAuditLogPageParam));
    }
}
