/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizauditlog.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizauditlog.entity.BizAuditLog;
import vip.xiaonuo.biz.modular.bizauditlog.mapper.BizAuditLogMapper;
import vip.xiaonuo.biz.modular.bizauditlog.param.BizAuditLogAddParam;
import vip.xiaonuo.biz.modular.bizauditlog.param.BizAuditLogEditParam;
import vip.xiaonuo.biz.modular.bizauditlog.param.BizAuditLogIdParam;
import vip.xiaonuo.biz.modular.bizauditlog.param.BizAuditLogPageParam;
import vip.xiaonuo.biz.modular.bizauditlog.service.BizAuditLogService;

import java.util.List;

/**
 * 审核记录表Service接口实现类
 *
 * @author fanzherong
 * @date  2025/06/16 14:57
 **/
@Service
public class BizAuditLogServiceImpl extends ServiceImpl<BizAuditLogMapper, BizAuditLog> implements BizAuditLogService {

    @Override
    public Page<BizAuditLog> page(BizAuditLogPageParam bizAuditLogPageParam) {
        QueryWrapper<BizAuditLog> queryWrapper = new QueryWrapper<BizAuditLog>().checkSqlInjection();
        if(ObjectUtil.isAllNotEmpty(bizAuditLogPageParam.getSortField(), bizAuditLogPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizAuditLogPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizAuditLogPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizAuditLogPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizAuditLog::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizAuditLogAddParam bizAuditLogAddParam) {
        BizAuditLog bizAuditLog = BeanUtil.toBean(bizAuditLogAddParam, BizAuditLog.class);
        this.save(bizAuditLog);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizAuditLogEditParam bizAuditLogEditParam) {
        BizAuditLog bizAuditLog = this.queryEntity(bizAuditLogEditParam.getId());
        BeanUtil.copyProperties(bizAuditLogEditParam, bizAuditLog);
        this.updateById(bizAuditLog);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizAuditLogIdParam> bizAuditLogIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizAuditLogIdParamList, BizAuditLogIdParam::getId));
    }

    @Override
    public BizAuditLog detail(BizAuditLogIdParam bizAuditLogIdParam) {
        return this.queryEntity(bizAuditLogIdParam.getId());
    }

    @Override
    public BizAuditLog queryEntity(String id) {
        BizAuditLog bizAuditLog = this.getById(id);
        if(ObjectUtil.isEmpty(bizAuditLog)) {
            throw new CommonException("审核记录表不存在，id值为：{}", id);
        }
        return bizAuditLog;
    }

    @Override
    public List<BizAuditLog> getList(BizAuditLogPageParam bizAuditLogPageParam) {
        QueryWrapper<BizAuditLog> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizAuditLogPageParam.getType())){
            queryWrapper.lambda().eq(BizAuditLog::getType,bizAuditLogPageParam.getType());
        }
        if(ObjectUtil.isNotEmpty(bizAuditLogPageParam.getDataId())){
            queryWrapper.lambda().eq(BizAuditLog::getDataId,bizAuditLogPageParam.getDataId());
        }
        queryWrapper.lambda().orderByDesc(BizAuditLog::getCreateTime);
        List<BizAuditLog> list = this.list(queryWrapper);
        return list;
    }
}
