/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizchargestation.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.bizchargestation.entity.BizChargeStation;
import vip.xiaonuo.biz.modular.bizchargestation.param.BizChargeStationAddParam;
import vip.xiaonuo.biz.modular.bizchargestation.param.BizChargeStationEditParam;
import vip.xiaonuo.biz.modular.bizchargestation.param.BizChargeStationIdParam;
import vip.xiaonuo.biz.modular.bizchargestation.param.BizChargeStationPageParam;
import vip.xiaonuo.biz.modular.bizchargestation.service.BizChargeStationService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 充电桩配置表控制器
 *
 * @author 河南优纳特传动科技有限公司
 * @date  2025/07/04 08:47
 */
@Tag(name = "充电桩配置表控制器")
@RestController
@Validated
public class BizChargeStationController {

    @Resource
    private BizChargeStationService bizChargeStationService;

    /**
     * 获取充电桩配置表分页
     *
     * @author 河南优纳特传动科技有限公司
     * @date  2025/07/04 08:47
     */
    @Operation(summary = "获取充电桩配置表分页")
    @SaCheckPermission("/biz/bizchargestation/page")
    @GetMapping("/biz/bizchargestation/page")
    public CommonResult<Page<BizChargeStation>> page(BizChargeStationPageParam bizChargeStationPageParam) {
        return CommonResult.data(bizChargeStationService.page(bizChargeStationPageParam));
    }

    /**
     * 添加充电桩配置表
     *
     * @author 河南优纳特传动科技有限公司
     * @date  2025/07/04 08:47
     */
    @Operation(summary = "添加充电桩配置表")
    @CommonLog("添加充电桩配置表")
    @SaCheckPermission("/biz/bizchargestation/add")
    @PostMapping("/biz/bizchargestation/add")
    public CommonResult<String> add(@RequestBody @Valid BizChargeStationAddParam bizChargeStationAddParam) {
        bizChargeStationService.add(bizChargeStationAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑充电桩配置表
     *
     * @author 河南优纳特传动科技有限公司
     * @date  2025/07/04 08:47
     */
    @Operation(summary = "编辑充电桩配置表")
    @CommonLog("编辑充电桩配置表")
    @SaCheckPermission("/biz/bizchargestation/edit")
    @PostMapping("/biz/bizchargestation/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizChargeStationEditParam bizChargeStationEditParam) {
        bizChargeStationService.edit(bizChargeStationEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除充电桩配置表
     *
     * @author 河南优纳特传动科技有限公司
     * @date  2025/07/04 08:47
     */
    @Operation(summary = "删除充电桩配置表")
    @CommonLog("删除充电桩配置表")
    @SaCheckPermission("/biz/bizchargestation/delete")
    @PostMapping("/biz/bizchargestation/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizChargeStationIdParam> bizChargeStationIdParamList) {
        bizChargeStationService.delete(bizChargeStationIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取充电桩配置表详情
     *
     * @author 河南优纳特传动科技有限公司
     * @date  2025/07/04 08:47
     */
    @Operation(summary = "获取充电桩配置表详情")
    @SaCheckPermission("/biz/bizchargestation/detail")
    @GetMapping("/biz/bizchargestation/detail")
    public CommonResult<BizChargeStation> detail(@Valid BizChargeStationIdParam bizChargeStationIdParam) {
        return CommonResult.data(bizChargeStationService.detail(bizChargeStationIdParam));
    }
}
