/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizchargestation.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizchargestation.entity.BizChargeStation;
import vip.xiaonuo.biz.modular.bizchargestation.mapper.BizChargeStationMapper;
import vip.xiaonuo.biz.modular.bizchargestation.param.BizChargeStationAddParam;
import vip.xiaonuo.biz.modular.bizchargestation.param.BizChargeStationEditParam;
import vip.xiaonuo.biz.modular.bizchargestation.param.BizChargeStationIdParam;
import vip.xiaonuo.biz.modular.bizchargestation.param.BizChargeStationPageParam;
import vip.xiaonuo.biz.modular.bizchargestation.service.BizChargeStationService;

import java.util.List;

/**
 * 充电桩配置表Service接口实现类
 *
 * @author 河南优纳特传动科技有限公司
 * @date 2025/07/04 08:47
 **/
@Service
public class BizChargeStationServiceImpl extends ServiceImpl<BizChargeStationMapper, BizChargeStation> implements BizChargeStationService {

    @Override
    public Page<BizChargeStation> page(BizChargeStationPageParam bizChargeStationPageParam) {
        QueryWrapper<BizChargeStation> queryWrapper = new QueryWrapper<BizChargeStation>().checkSqlInjection();
        if (ObjectUtil.isAllNotEmpty(bizChargeStationPageParam.getSortField(), bizChargeStationPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizChargeStationPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizChargeStationPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizChargeStationPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizChargeStation::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizChargeStationAddParam bizChargeStationAddParam) {
        QueryWrapper<BizChargeStation> queryWrapper = new QueryWrapper<BizChargeStation>();
        queryWrapper.lambda().eq(BizChargeStation::getDeleteFlag, 0).last("limit 1");
        BizChargeStation one = this.getOne(queryWrapper);
        if (one != null) {
            throw new CommonException("充电桩配置信息已存在");
        }
        BizChargeStation bizChargeStation = BeanUtil.toBean(bizChargeStationAddParam, BizChargeStation.class);
        bizChargeStation.setChargeStationUsedNumber(0);
        this.save(bizChargeStation);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizChargeStationEditParam bizChargeStationEditParam) {
        BizChargeStation bizChargeStation = this.queryEntity(bizChargeStationEditParam.getId());
        //判断一下修改后的总数量是否小于已使用数量
        if(bizChargeStationEditParam.getChargeStationTotalNumber() <= bizChargeStation.getChargeStationUsedNumber()){
            //抛出异常提示
            throw new CommonException("充电桩总数量不能小于已使用数量");
        }
        BeanUtil.copyProperties(bizChargeStationEditParam, bizChargeStation);
        this.updateById(bizChargeStation);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizChargeStationIdParam> bizChargeStationIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizChargeStationIdParamList, BizChargeStationIdParam::getId));
    }

    @Override
    public BizChargeStation detail(BizChargeStationIdParam bizChargeStationIdParam) {
        return this.queryEntity(bizChargeStationIdParam.getId());
    }

    @Override
    public BizChargeStation queryEntity(String id) {
        BizChargeStation bizChargeStation = this.getById(id);
        if (ObjectUtil.isEmpty(bizChargeStation)) {
            throw new CommonException("充电桩配置表不存在，id值为：{}", id);
        }
        return bizChargeStation;
    }
}
