/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizloadappoint.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.http.MediaType;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.biz.modular.bizorder.param.BizOrderPageParam;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.annotation.CommonNoRepeat;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.bizloadappoint.entity.BizLoadAppoint;
import vip.xiaonuo.biz.modular.bizloadappoint.param.BizLoadAppointAddParam;
import vip.xiaonuo.biz.modular.bizloadappoint.param.BizLoadAppointEditParam;
import vip.xiaonuo.biz.modular.bizloadappoint.param.BizLoadAppointIdParam;
import vip.xiaonuo.biz.modular.bizloadappoint.param.BizLoadAppointPageParam;
import vip.xiaonuo.biz.modular.bizloadappoint.service.BizLoadAppointService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;

import java.io.IOException;
import java.util.List;

/**
 * 起卸预约控制器
 *
 * @author fanzherong
 * @date  2025/06/25 14:51
 */
@Tag(name = "起卸预约控制器")
@RestController
@Validated
public class BizLoadAppointController {

    @Resource
    private BizLoadAppointService bizLoadAppointService;

    /**
     * 获取起卸预约分页
     *
     * @author fanzherong
     * @date  2025/06/25 14:51
     */
    @Operation(summary = "获取起卸预约分页")
    @SaCheckPermission("/biz/bizloadappoint/page")
    @GetMapping("/biz/bizloadappoint/page")
    public CommonResult<Page<BizLoadAppoint>> page(BizLoadAppointPageParam bizLoadAppointPageParam) {
        return CommonResult.data(bizLoadAppointService.page(bizLoadAppointPageParam));
    }

    /**
     * 添加起卸预约
     *
     * @author fanzherong
     * @date  2025/06/25 14:51
     */
    @Operation(summary = "添加起卸预约")
    @CommonLog("添加起卸预约")
    @PostMapping("/biz/bizloadappoint/add")
    @CommonNoRepeat
    public CommonResult<String> add(@RequestBody @Valid BizLoadAppointAddParam bizLoadAppointAddParam) {
        bizLoadAppointService.add(bizLoadAppointAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑起卸预约
     *
     * @author fanzherong
     * @date  2025/06/25 14:51
     */
    @Operation(summary = "编辑起卸预约")
    @CommonLog("编辑起卸预约")
    @PostMapping("/biz/bizloadappoint/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizLoadAppointEditParam bizLoadAppointEditParam) {
        bizLoadAppointService.edit(bizLoadAppointEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除起卸预约
     *
     * @author fanzherong
     * @date  2025/06/25 14:51
     */
    @Operation(summary = "删除起卸预约")
    @CommonLog("删除起卸预约")
    @PostMapping("/biz/bizloadappoint/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizLoadAppointIdParam> bizLoadAppointIdParamList) {
        bizLoadAppointService.delete(bizLoadAppointIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取起卸预约详情
     *
     * @author fanzherong
     * @date  2025/06/25 14:51
     */
    @Operation(summary = "获取起卸预约详情")
    @GetMapping("/biz/bizloadappoint/detail")
    public CommonResult<BizLoadAppoint> detail(@Valid BizLoadAppointIdParam bizLoadAppointIdParam) {
        return CommonResult.data(bizLoadAppointService.detail(bizLoadAppointIdParam));
    }

    /**
     * 提交起卸预约
     *
     * @author fanzherong
     * @date  2025/06/25 14:51
     */
    @Operation(summary = "提交起卸预约")
    @CommonLog("提交起卸预约")
    @PostMapping("/biz/bizloadappoint/submit")
    public CommonResult<String> submit(@RequestBody @Valid BizLoadAppointEditParam bizLoadAppointEditParam) {
        bizLoadAppointService.submit(bizLoadAppointEditParam);
        return CommonResult.ok();
    }

    /**
     * 客户签名
     *
     * @author fanzherong
     * @date  2025/06/25 14:51
     */
    @Operation(summary = "客户签名")
    @CommonLog("客户签名")
    @PostMapping("/biz/bizloadappoint/updateCustomerSign")
    public CommonResult<String> updateCustomerSign(@RequestBody @Valid BizLoadAppointEditParam bizLoadAppointEditParam) {
        bizLoadAppointService.updateCustomerSign(bizLoadAppointEditParam);
        return CommonResult.ok();
    }

    /**
     * 客户结束签名
     *
     * @author fanzherong
     * @date  2025/06/25 14:51
     */
    @Operation(summary = "客户结束签名")
    @CommonLog("客户结束签名")
    @PostMapping("/biz/bizloadappoint/endCustomerSign")
    public CommonResult<String> endCustomerSign(@RequestBody @Valid BizLoadAppointEditParam bizLoadAppointEditParam) {
        bizLoadAppointService.endCustomerSign(bizLoadAppointEditParam);
        return CommonResult.ok();
    }

    /**
     * 客户驳回
     *
     * @author fanzherong
     * @date  2025/06/25 14:51
     */
    @Operation(summary = "客户驳回")
    @CommonLog("客户驳回")
    @PostMapping("/biz/bizloadappoint/rejectOrder")
    public CommonResult<String> rejectOrder(@RequestBody @Valid BizLoadAppointEditParam bizLoadAppointEditParam) {
        bizLoadAppointService.rejectOrder(bizLoadAppointEditParam);
        return CommonResult.ok();
    }

    /**
     * 发货确认
     *
     * @author fanzherong
     * @date  2025/06/25 14:51
     */
    @Operation(summary = "发货确认")
    @CommonLog("发货确认")
    @PostMapping("/biz/bizloadappoint/sendConfirmLoad")
    public CommonResult<String> sendConfirmLoad(@RequestBody @Valid BizLoadAppointEditParam bizLoadAppointEditParam) {
        bizLoadAppointService.sendConfirmLoad(bizLoadAppointEditParam);
        return CommonResult.ok();
    }

    /**
     * 导出起卸预约报表
     */
    @Operation(summary = "导出起卸预约报表")
    @SaCheckPermission("/biz/bizloadappoint/exportRecord")
    @GetMapping(value = "/biz/bizloadappoint/exportRecord", produces = MediaType.APPLICATION_OCTET_STREAM_VALUE)
    public void exportRecord(BizLoadAppointPageParam bizLoadAppointPageParam, HttpServletResponse response) throws IOException {
        bizLoadAppointService.exportRecord(bizLoadAppointPageParam,response);
    }

    /**
     * 获取起卸预约待报港列表
     *
     * @author fanzherong
     * @date  2025/06/25 14:51
     */
    @Operation(summary = "获取起卸预约待报港列表")
    @GetMapping("/biz/bizloadappoint/getList")
    public CommonResult<List<BizLoadAppoint>> getList(BizLoadAppointPageParam bizLoadAppointPageParam) {
        return CommonResult.data(bizLoadAppointService.getList(bizLoadAppointPageParam));
    }

    /**
     * 结束起卸预约
     *
     * @author fanzherong
     * @date  2025/06/25 14:51
     */
    @Operation(summary = "结束起卸预约")
    @CommonLog("结束起卸预约")
    @PostMapping("/biz/bizloadappoint/endLoad")
    public CommonResult<String> endLoad(@RequestBody @Valid BizLoadAppointEditParam bizLoadAppointEditParam) {
        bizLoadAppointService.endLoad(bizLoadAppointEditParam);
        return CommonResult.ok();
    }

    /**
     * 填报起卸订单
     *
     * @author fanzherong
     * @date  2025/06/25 14:51
     */
    @Operation(summary = "填报起卸订单")
    @CommonLog("填报起卸订单")
    @PostMapping("/biz/bizloadappoint/fillLoad")
    public CommonResult<String> fillLoad(@RequestBody @Valid BizLoadAppointEditParam bizLoadAppointEditParam) {
        bizLoadAppointService.fillLoad(bizLoadAppointEditParam);
        return CommonResult.ok();
    }


    /**
     * 修改扫码次数
     *
     * @author fanzherong
     * @date  2025/06/25 14:51
     */
    @Operation(summary = "修改扫码次数")
    @CommonLog("修改扫码次数")
    @PostMapping("/biz/bizloadappoint/updateAppointNumber")
    public CommonResult<String> updateAppointNumber(@RequestBody @Valid BizLoadAppointEditParam bizLoadAppointEditParam) {
        bizLoadAppointService.updateAppointNumber(bizLoadAppointEditParam);
        return CommonResult.ok();
    }
}
