/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizloadappoint.entity;

import com.baomidou.mybatisplus.annotation.*;
import com.fhs.core.trans.anno.Trans;
import com.fhs.core.trans.constant.TransType;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Getter;
import lombok.Setter;
import vip.xiaonuo.common.pojo.CommonEntity;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 起卸预约实体
 *
 * @author fanzherong
 * @date  2025/06/25 14:51
 **/
@Getter
@Setter
@TableName("biz_load_appoint")
public class BizLoadAppoint extends CommonEntity {

    /** 主键ID */
    @TableId
    @Schema(description = "主键ID")
    private String id;

    /**起卸预约单号*/
    @Schema(description = "起卸预约单号")
    private String loadNumber;

    /** 服务客户id */
    @Schema(description = "服务客户id")
    private String customerId;

    /** 货物id */
    @Schema(description = "货物id")
    private String goodsId;

    /** 订单数量 */
    @Schema(description = "订单数量")
    private BigDecimal orderWeight;

    /** 单价 */
    @Schema(description = "单价")
    private BigDecimal orderPrice;

    /** 订单总额 */
    @Schema(description = "订单总额")
    private BigDecimal orderAmount;

    /** 船运供应商 */
    @Schema(description = "船运供应商")
    private String supplierId;

    /**汽运供应商*/
    @TableField(exist = false)
    private List<String> supplierIdList;

    /** 运费单价 */
    @Schema(description = "运费单价")
    private BigDecimal freightPrice;

    /** 支付方式  1：预付（先付后执行）  2：授信 （先执行后付） */
    @Schema(description = "支付方式  1：预付（先付后执行）  2：授信 （先执行后付）")
    private String payType;

    /** 订单类型  1：配送   2：自提 */
    @Schema(description = "订单类型  1：配送   2：自提")
    private String orderType;

    /** 状态   1：待提交  2：客户确认 */
    @Schema(description = "状态   1：待提交  2：客户确认")
    @Trans(type = TransType.DICTIONARY, key = "load_appoint_status")
    private String status;


    /**服务客户名称*/
    @TableField(exist = false)
    private String customerName;

    /**货品名称*/
    @TableField(exist = false)
    private String goodsName;

    /**供应商名称*/
    @TableField(exist = false)
    private String supplierName;

    /**客户联系人*/
    @TableField(exist = false)
    private String customerContact;

    /**客户电话**/
    @TableField(exist = false)
    private String customerPhone;

    /**客户地址*/
    @TableField(exist = false)
    private String customerAddress;

    /***货品编码*/
    @TableField(exist = false)
    private String goodsCode;

    /**客户签名*/
    private String customerSign;
    /**签名时间*/
    private Date signTime;

    /**报港预约状态**/
    @TableField(exist = false)
    private String arriveStatus;

    /**结束说明*/
    private String endReason;

    /**起卸重量*/
    private BigDecimal fillWeight;

    /**填报时间*/
    private Date fillTime;

    /**起卸单价*/
    private BigDecimal loadPrice;

    /**陆运运费单价**/
    private BigDecimal landFreightPrice;

    /**可约次数**/
    private Integer appointNumber;

    /**已约次数*/
    private Integer alreadyAppointNumber;

    /**场地类型  1:内场   2：外场*/
    private String loadType;

    /**订单结束客户签名*/
    private String endSign;

    /**订单结束客户签名时间*/
    private Date endSignTime;

    /**净重*/
    private BigDecimal netWeight;

    /**卸货重量**/
    private BigDecimal loadWeight;

    /**起卸费结算**/
    private String loadCostSettle;

    /**起卸路运结算**/
    private String loadRoadSettle;
}
