/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizloadappoint.param;

import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Getter;
import lombok.Setter;

import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 起卸预约编辑参数
 *
 * @author fanzherong
 * @date  2025/06/25 14:51
 **/
@Getter
@Setter
public class BizLoadAppointEditParam {

    /** 主键ID */
    @Schema(description = "主键ID", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotBlank(message = "id不能为空")
    private String id;

    /** 服务客户id */
    @Schema(description = "服务客户id")
    private String customerId;

    /** 货物id */
    @Schema(description = "货物id")
    private String goodsId;

    /** 订单数量 */
    @Schema(description = "订单数量")
    private BigDecimal orderWeight;

    /** 单价 */
    @Schema(description = "单价")
    private BigDecimal orderPrice;

    /** 订单总额 */
    @Schema(description = "订单总额")
    private BigDecimal orderAmount;

    /** 船运供应商 */
    @Schema(description = "船运供应商")
    private String supplierId;

    /** 运费单价 */
    @Schema(description = "运费单价")
    private BigDecimal freightPrice;

    /** 支付方式  1：预付（先付后执行）  2：授信 （先执行后付） */
    @Schema(description = "支付方式  1：预付（先付后执行）  2：授信 （先执行后付）")
    private String payType;

    /** 订单类型  1：配送   2：自提 */
    @Schema(description = "订单类型  1：配送   2：自提")
    private String orderType;

    /** 状态   1：待提交  2：客户确认 */
    @Schema(description = "状态   1：待提交  2：客户确认")
    private String status;

    /**汽运供应商*/
    private List<String> supplierIdList;

    /**客户签名*/
    private String customerSign;

    /**结束说明*/
    private String endReason;

    /**起卸重量*/
    private BigDecimal fillWeight;

    /**填报时间*/
    private Date fillTime;


    /**起卸单价*/
    private BigDecimal loadPrice;

    /**陆运运费单价**/
    private BigDecimal landFreightPrice;

    private Integer appointNumber;

    /**操作类型*/
    private String loadType;

    /**订单结束客户签名*/
    private String endSign;

    /**订单结束客户签名时间*/
    private String endSignTime;

    /**客户驳回说明*/
    private String rejectRemark;
}
