/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizloadappoint.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import jakarta.servlet.http.HttpServletResponse;
import vip.xiaonuo.biz.modular.bizloadappoint.entity.BizLoadAppoint;
import vip.xiaonuo.biz.modular.bizloadappoint.param.BizLoadAppointAddParam;
import vip.xiaonuo.biz.modular.bizloadappoint.param.BizLoadAppointEditParam;
import vip.xiaonuo.biz.modular.bizloadappoint.param.BizLoadAppointIdParam;
import vip.xiaonuo.biz.modular.bizloadappoint.param.BizLoadAppointPageParam;

import java.util.List;

/**
 * 起卸预约Service接口
 *
 * @author fanzherong
 * @date  2025/06/25 14:51
 **/
public interface BizLoadAppointService extends IService<BizLoadAppoint> {

    /**
     * 获取起卸预约分页
     *
     * @author fanzherong
     * @date  2025/06/25 14:51
     */
    Page<BizLoadAppoint> page(BizLoadAppointPageParam bizLoadAppointPageParam);

    /**
     * 添加起卸预约
     *
     * @author fanzherong
     * @date  2025/06/25 14:51
     */
    void add(BizLoadAppointAddParam bizLoadAppointAddParam);

    /**
     * 编辑起卸预约
     *
     * @author fanzherong
     * @date  2025/06/25 14:51
     */
    void edit(BizLoadAppointEditParam bizLoadAppointEditParam);

    /**
     * 删除起卸预约
     *
     * @author fanzherong
     * @date  2025/06/25 14:51
     */
    void delete(List<BizLoadAppointIdParam> bizLoadAppointIdParamList);

    /**
     * 获取起卸预约详情
     *
     * @author fanzherong
     * @date  2025/06/25 14:51
     */
    BizLoadAppoint detail(BizLoadAppointIdParam bizLoadAppointIdParam);

    /**
     * 获取起卸预约详情
     *
     * @author fanzherong
     * @date  2025/06/25 14:51
     **/
    BizLoadAppoint queryEntity(String id);

    /**
     * 提交
     * @param bizLoadAppointEditParam
     */
    void submit(BizLoadAppointEditParam bizLoadAppointEditParam);

    /**
     * 客户签名
     */
    void updateCustomerSign(BizLoadAppointEditParam bizLoadAppointEditParam);

    /**
     * 客户结束签名
     */
    void endCustomerSign(BizLoadAppointEditParam bizLoadAppointEditParam);

    /**
     * 导出
     */
    void exportRecord(BizLoadAppointPageParam bizLoadAppointPageParam,HttpServletResponse response);

    /**
     * 获取起卸预约待报港列表
     */
    List<BizLoadAppoint> getList(BizLoadAppointPageParam bizLoadAppointPageParam);

    /**
     * 结束起卸订单
     * @param bizLoadAppointEditParam
     */
    void endLoad(BizLoadAppointEditParam bizLoadAppointEditParam);

    /**
     * 填报起卸数量
     */
    void fillLoad(BizLoadAppointEditParam bizLoadAppointEditParam);

    /**
     * 客户驳回
     */
    void rejectOrder(BizLoadAppointEditParam bizLoadAppointEditParam);

    /**
     * 发货确认
     */
    void sendConfirmLoad(BizLoadAppointEditParam bizLoadAppointEditParam);

    /**
     * 修改预约次数
     */
    void updateAppointNumber(BizLoadAppointEditParam bizLoadAppointEditParam);
}
