/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizloadappointsupplier.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.bizloadappointsupplier.entity.BizLoadAppointSupplier;
import vip.xiaonuo.biz.modular.bizloadappointsupplier.param.BizLoadAppointSupplierAddParam;
import vip.xiaonuo.biz.modular.bizloadappointsupplier.param.BizLoadAppointSupplierEditParam;
import vip.xiaonuo.biz.modular.bizloadappointsupplier.param.BizLoadAppointSupplierIdParam;
import vip.xiaonuo.biz.modular.bizloadappointsupplier.param.BizLoadAppointSupplierPageParam;
import vip.xiaonuo.biz.modular.bizloadappointsupplier.service.BizLoadAppointSupplierService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 起卸汽运供应商控制器
 *
 * @author fanzherong
 * @date  2025/06/25 16:25
 */
@Tag(name = "起卸汽运供应商控制器")
@RestController
@Validated
public class BizLoadAppointSupplierController {

    @Resource
    private BizLoadAppointSupplierService bizLoadAppointSupplierService;

    /**
     * 获取起卸汽运供应商分页
     *
     * @author fanzherong
     * @date  2025/06/25 16:25
     */
    @Operation(summary = "获取起卸汽运供应商分页")
    @SaCheckPermission("/biz/bizloadappointsupplier/page")
    @GetMapping("/biz/bizloadappointsupplier/page")
    public CommonResult<Page<BizLoadAppointSupplier>> page(BizLoadAppointSupplierPageParam bizLoadAppointSupplierPageParam) {
        return CommonResult.data(bizLoadAppointSupplierService.page(bizLoadAppointSupplierPageParam));
    }

    /**
     * 添加起卸汽运供应商
     *
     * @author fanzherong
     * @date  2025/06/25 16:25
     */
    @Operation(summary = "添加起卸汽运供应商")
    @CommonLog("添加起卸汽运供应商")
    @PostMapping("/biz/bizloadappointsupplier/add")
    public CommonResult<String> add(@RequestBody @Valid BizLoadAppointSupplierAddParam bizLoadAppointSupplierAddParam) {
        bizLoadAppointSupplierService.add(bizLoadAppointSupplierAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑起卸汽运供应商
     *
     * @author fanzherong
     * @date  2025/06/25 16:25
     */
    @Operation(summary = "编辑起卸汽运供应商")
    @CommonLog("编辑起卸汽运供应商")
    @PostMapping("/biz/bizloadappointsupplier/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizLoadAppointSupplierEditParam bizLoadAppointSupplierEditParam) {
        bizLoadAppointSupplierService.edit(bizLoadAppointSupplierEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除起卸汽运供应商
     *
     * @author fanzherong
     * @date  2025/06/25 16:25
     */
    @Operation(summary = "删除起卸汽运供应商")
    @CommonLog("删除起卸汽运供应商")
    @PostMapping("/biz/bizloadappointsupplier/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizLoadAppointSupplierIdParam> bizLoadAppointSupplierIdParamList) {
        bizLoadAppointSupplierService.delete(bizLoadAppointSupplierIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取起卸汽运供应商详情
     *
     * @author fanzherong
     * @date  2025/06/25 16:25
     */
    @Operation(summary = "获取起卸汽运供应商详情")
    @GetMapping("/biz/bizloadappointsupplier/detail")
    public CommonResult<BizLoadAppointSupplier> detail(@Valid BizLoadAppointSupplierIdParam bizLoadAppointSupplierIdParam) {
        return CommonResult.data(bizLoadAppointSupplierService.detail(bizLoadAppointSupplierIdParam));
    }

    /**
     * 获取起卸汽运供应商列表
     *
     * @author fanzherong
     * @date  2025/06/25 16:25
     */
    @Operation(summary = "获取起卸汽运供应商列表")
    @GetMapping("/biz/bizloadappointsupplier/getList")
    public CommonResult<List<BizLoadAppointSupplier>> getList(BizLoadAppointSupplierPageParam bizLoadAppointSupplierPageParam) {
        return CommonResult.data(bizLoadAppointSupplierService.getList(bizLoadAppointSupplierPageParam));
    }
}
