/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizloadappointsupplier.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizloadappointsupplier.entity.BizLoadAppointSupplier;
import vip.xiaonuo.biz.modular.bizloadappointsupplier.mapper.BizLoadAppointSupplierMapper;
import vip.xiaonuo.biz.modular.bizloadappointsupplier.param.BizLoadAppointSupplierAddParam;
import vip.xiaonuo.biz.modular.bizloadappointsupplier.param.BizLoadAppointSupplierEditParam;
import vip.xiaonuo.biz.modular.bizloadappointsupplier.param.BizLoadAppointSupplierIdParam;
import vip.xiaonuo.biz.modular.bizloadappointsupplier.param.BizLoadAppointSupplierPageParam;
import vip.xiaonuo.biz.modular.bizloadappointsupplier.service.BizLoadAppointSupplierService;

import java.util.List;

/**
 * 起卸汽运供应商Service接口实现类
 *
 * @author fanzherong
 * @date  2025/06/25 16:25
 **/
@Service
public class BizLoadAppointSupplierServiceImpl extends ServiceImpl<BizLoadAppointSupplierMapper, BizLoadAppointSupplier> implements BizLoadAppointSupplierService {

    @Override
    public Page<BizLoadAppointSupplier> page(BizLoadAppointSupplierPageParam bizLoadAppointSupplierPageParam) {
        QueryWrapper<BizLoadAppointSupplier> queryWrapper = new QueryWrapper<BizLoadAppointSupplier>().checkSqlInjection();
        if(ObjectUtil.isAllNotEmpty(bizLoadAppointSupplierPageParam.getSortField(), bizLoadAppointSupplierPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizLoadAppointSupplierPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizLoadAppointSupplierPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizLoadAppointSupplierPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizLoadAppointSupplier::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizLoadAppointSupplierAddParam bizLoadAppointSupplierAddParam) {
        BizLoadAppointSupplier bizLoadAppointSupplier = BeanUtil.toBean(bizLoadAppointSupplierAddParam, BizLoadAppointSupplier.class);
        this.save(bizLoadAppointSupplier);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizLoadAppointSupplierEditParam bizLoadAppointSupplierEditParam) {
        BizLoadAppointSupplier bizLoadAppointSupplier = this.queryEntity(bizLoadAppointSupplierEditParam.getId());
        BeanUtil.copyProperties(bizLoadAppointSupplierEditParam, bizLoadAppointSupplier);
        this.updateById(bizLoadAppointSupplier);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizLoadAppointSupplierIdParam> bizLoadAppointSupplierIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizLoadAppointSupplierIdParamList, BizLoadAppointSupplierIdParam::getId));
    }

    @Override
    public BizLoadAppointSupplier detail(BizLoadAppointSupplierIdParam bizLoadAppointSupplierIdParam) {
        return this.queryEntity(bizLoadAppointSupplierIdParam.getId());
    }

    @Override
    public BizLoadAppointSupplier queryEntity(String id) {
        BizLoadAppointSupplier bizLoadAppointSupplier = this.getById(id);
        if(ObjectUtil.isEmpty(bizLoadAppointSupplier)) {
            throw new CommonException("起卸汽运供应商不存在，id值为：{}", id);
        }
        return bizLoadAppointSupplier;
    }

    @Override
    public List<BizLoadAppointSupplier> getList(BizLoadAppointSupplierPageParam bizLoadAppointSupplierPageParam) {
        QueryWrapper<BizLoadAppointSupplier> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizLoadAppointSupplierPageParam.getAppointId())){
            queryWrapper.eq("blas.appoint_id",bizLoadAppointSupplierPageParam.getAppointId());
        }
        queryWrapper.eq("blas.delete_flag","NOT_DELETE");
        List<BizLoadAppointSupplier> list = this.getBaseMapper().getList(queryWrapper);
        return list;
    }
}
