/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizloadarrive.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.http.MediaType;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.biz.modular.bizloadappoint.param.BizLoadAppointPageParam;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.bizloadarrive.entity.BizLoadArrive;
import vip.xiaonuo.biz.modular.bizloadarrive.param.BizLoadArriveAddParam;
import vip.xiaonuo.biz.modular.bizloadarrive.param.BizLoadArriveEditParam;
import vip.xiaonuo.biz.modular.bizloadarrive.param.BizLoadArriveIdParam;
import vip.xiaonuo.biz.modular.bizloadarrive.param.BizLoadArrivePageParam;
import vip.xiaonuo.biz.modular.bizloadarrive.service.BizLoadArriveService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;

import java.io.IOException;
import java.util.List;

/**
 * 报港预约控制器
 *
 * @author fanzherong
 * @date  2025/06/26 14:12
 */
@Tag(name = "报港预约控制器")
@RestController
@Validated
public class BizLoadArriveController {

    @Resource
    private BizLoadArriveService bizLoadArriveService;

    /**
     * 获取报港预约分页
     *
     * @author fanzherong
     * @date  2025/06/26 14:12
     */
    @Operation(summary = "获取报港预约分页")
    @SaCheckPermission("/biz/bizloadarrive/page")
    @GetMapping("/biz/bizloadarrive/page")
    public CommonResult<Page<BizLoadArrive>> page(BizLoadArrivePageParam bizLoadArrivePageParam) {
        return CommonResult.data(bizLoadArriveService.page(bizLoadArrivePageParam));
    }

    /**
     * 添加报港预约
     *
     * @author fanzherong
     * @date  2025/06/26 14:12
     */
    @Operation(summary = "添加报港预约")
    @CommonLog("添加报港预约")
    @PostMapping("/biz/bizloadarrive/add")
    public CommonResult<String> add(@RequestBody @Valid BizLoadArriveAddParam bizLoadArriveAddParam) {
        bizLoadArriveService.add(bizLoadArriveAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑报港预约
     *
     * @author fanzherong
     * @date  2025/06/26 14:12
     */
    @Operation(summary = "编辑报港预约")
    @CommonLog("编辑报港预约")
    @PostMapping("/biz/bizloadarrive/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizLoadArriveEditParam bizLoadArriveEditParam) {
        bizLoadArriveService.edit(bizLoadArriveEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除报港预约
     *
     * @author fanzherong
     * @date  2025/06/26 14:12
     */
    @Operation(summary = "删除报港预约")
    @CommonLog("删除报港预约")
    @PostMapping("/biz/bizloadarrive/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizLoadArriveIdParam> bizLoadArriveIdParamList) {
        bizLoadArriveService.delete(bizLoadArriveIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取报港预约详情
     *
     * @author fanzherong
     * @date  2025/06/26 14:12
     */
    @Operation(summary = "获取报港预约详情")
    @GetMapping("/biz/bizloadarrive/detail")
    public CommonResult<BizLoadArrive> detail(@Valid BizLoadArriveIdParam bizLoadArriveIdParam) {
        return CommonResult.data(bizLoadArriveService.detail(bizLoadArriveIdParam));
    }

    /**
     * 报港预约审核
     */
    @Operation(summary = "报港预约审核")
    @CommonLog("报港预约审核")
    @PostMapping("/biz/bizloadarrive/auditArrive")
    public CommonResult<String> auditArrive(@RequestBody @Valid BizLoadArriveEditParam bizLoadArriveEditParam) {
        bizLoadArriveService.auditArrive(bizLoadArriveEditParam);
        return CommonResult.ok();
    }


    /**
     * 导出报港预约报表
     */
    @Operation(summary = "导出报港预约报表")
    @SaCheckPermission("/biz/bizloadarrive/exportRecord")
    @GetMapping(value = "/biz/bizloadarrive/exportRecord", produces = MediaType.APPLICATION_OCTET_STREAM_VALUE)
    public void exportRecord(BizLoadArrivePageParam bizLoadArrivePageParam, HttpServletResponse response) throws IOException {
        bizLoadArriveService.exportRecord(bizLoadArrivePageParam,response);
    }

    /**
     * 船主确认
     *
     * @author fanzherong
     * @date  2025/06/26 14:12
     */
    @Operation(summary = "船主确认")
    @CommonLog("船主确认")
    @PostMapping("/biz/bizloadarrive/arriveConfirm")
    public CommonResult<String> arriveConfirm(@RequestBody @Valid BizLoadArriveEditParam bizLoadArriveEditParam) {
        bizLoadArriveService.arriveConfirm(bizLoadArriveEditParam);
        return CommonResult.ok();
    }

    /**
     * 船主确认
     *
     * @author fanzherong
     * @date  2025/06/26 14:12
     */
    @Operation(summary = "船主确认")
    @CommonLog("船主确认")
    @PostMapping("/biz/bizloadarrive/arriveSign")
    public CommonResult<String> arriveSign(@RequestBody @Valid BizLoadArriveEditParam bizLoadArriveEditParam) {
        bizLoadArriveService.arriveSign(bizLoadArriveEditParam);
        return CommonResult.ok();
    }
}
