/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizloaddispatch.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.bizloaddispatch.entity.BizLoadDispatch;
import vip.xiaonuo.biz.modular.bizloaddispatch.param.BizLoadDispatchAddParam;
import vip.xiaonuo.biz.modular.bizloaddispatch.param.BizLoadDispatchEditParam;
import vip.xiaonuo.biz.modular.bizloaddispatch.param.BizLoadDispatchIdParam;
import vip.xiaonuo.biz.modular.bizloaddispatch.param.BizLoadDispatchPageParam;
import vip.xiaonuo.biz.modular.bizloaddispatch.service.BizLoadDispatchService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 起卸预约分配控制器
 *
 * @author fanzherong
 * @date  2025/07/01 09:47
 */
@Tag(name = "起卸预约分配控制器")
@RestController
@Validated
public class BizLoadDispatchController {

    @Resource
    private BizLoadDispatchService bizLoadDispatchService;

    /**
     * 获取起卸预约分配分页
     *
     * @author fanzherong
     * @date  2025/07/01 09:47
     */
    @Operation(summary = "获取起卸预约分配分页")
    @SaCheckPermission("/biz/bizloaddispatch/page")
    @GetMapping("/biz/bizloaddispatch/page")
    public CommonResult<Page<BizLoadDispatch>> page(BizLoadDispatchPageParam bizLoadDispatchPageParam) {
        return CommonResult.data(bizLoadDispatchService.page(bizLoadDispatchPageParam));
    }

    /**
     * 添加起卸预约分配
     *
     * @author fanzherong
     * @date  2025/07/01 09:47
     */
    @Operation(summary = "添加起卸预约分配")
    @CommonLog("添加起卸预约分配")
    @PostMapping("/biz/bizloaddispatch/add")
    public CommonResult<String> add(@RequestBody @Valid BizLoadDispatchAddParam bizLoadDispatchAddParam) {
        bizLoadDispatchService.add(bizLoadDispatchAddParam);
        return CommonResult.ok();
    }

    /**
     * 添加装货调度分配
     *
     * @author fanzherong
     * @date  2025/07/01 09:47
     */
    @Operation(summary = "添加装货调度分配")
    @CommonLog("添加装货调度分配")
    @PostMapping("/biz/bizloaddispatch/addDispatch")
    public CommonResult<String> addDispatch(@RequestBody @Valid BizLoadDispatchAddParam bizLoadDispatchAddParam) {
        bizLoadDispatchService.addDispatch(bizLoadDispatchAddParam);
        return CommonResult.ok();
    }

    /**
     * 添加起卸调度分配
     *
     * @author fanzherong
     * @date  2025/07/01 09:47
     */
    @Operation(summary = "添加起卸调度分配")
    @CommonLog("添加起卸调度分配")
    @PostMapping("/biz/bizloaddispatch/addLoad")
    public CommonResult<String> addLoad(@RequestBody @Valid BizLoadDispatchAddParam bizLoadDispatchAddParam) {
        bizLoadDispatchService.addLoad(bizLoadDispatchAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑起卸预约分配
     *
     * @author fanzherong
     * @date  2025/07/01 09:47
     */
    @Operation(summary = "编辑起卸预约分配")
    @CommonLog("编辑起卸预约分配")
    @PostMapping("/biz/bizloaddispatch/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizLoadDispatchEditParam bizLoadDispatchEditParam) {
        bizLoadDispatchService.edit(bizLoadDispatchEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除起卸预约分配
     *
     * @author fanzherong
     * @date  2025/07/01 09:47
     */
    @Operation(summary = "删除起卸预约分配")
    @CommonLog("删除起卸预约分配")
    @PostMapping("/biz/bizloaddispatch/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizLoadDispatchIdParam> bizLoadDispatchIdParamList) {
        bizLoadDispatchService.delete(bizLoadDispatchIdParamList);
        return CommonResult.ok();
    }

    /**
     * 删除装货分配
     *
     * @author fanzherong
     * @date  2025/07/01 09:47
     */
    @Operation(summary = "删除装货分配")
    @CommonLog("删除装货分配")
    @PostMapping("/biz/bizloaddispatch/deleteDispatch")
    public CommonResult<String> deleteDispatch(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                       List<BizLoadDispatchIdParam> bizLoadDispatchIdParamList) {
        bizLoadDispatchService.deleteDispatch(bizLoadDispatchIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取起卸预约分配详情
     *
     * @author fanzherong
     * @date  2025/07/01 09:47
     */
    @Operation(summary = "获取起卸预约分配详情")
    @GetMapping("/biz/bizloaddispatch/detail")
    public CommonResult<BizLoadDispatch> detail(@Valid BizLoadDispatchIdParam bizLoadDispatchIdParam) {
        return CommonResult.data(bizLoadDispatchService.detail(bizLoadDispatchIdParam));
    }

    /**
     * 获取起卸预约分配分页
     *
     * @author fanzherong
     * @date  2025/07/01 09:47
     */
    @Operation(summary = "获取起卸预约分配分页")
    @GetMapping("/biz/bizloaddispatch/getPageList")
    public CommonResult<Page<BizLoadDispatch>> getPageList(BizLoadDispatchPageParam bizLoadDispatchPageParam) {
        return CommonResult.data(bizLoadDispatchService.getPageList(bizLoadDispatchPageParam));
    }

    /**
     * 获取装货点位列表
     *
     * @author fanzherong
     * @date  2025/07/01 09:47
     */
    @Operation(summary = "获取装货点位列表")
    @GetMapping("/biz/bizloaddispatch/getList")
    public CommonResult<List<BizLoadDispatch>> getList(BizLoadDispatchPageParam bizLoadDispatchPageParam) {
        return CommonResult.data(bizLoadDispatchService.getList(bizLoadDispatchPageParam));
    }

    /**
     * 获取装货时间列表
     *
     * @author fanzherong
     * @date  2025/07/01 09:47
     */
    @Operation(summary = "获取装货时间列表")
    @GetMapping("/biz/bizloaddispatch/getListTime")
    public CommonResult<List<BizLoadDispatch>> getListTime(BizLoadDispatchPageParam bizLoadDispatchPageParam) {
        return CommonResult.data(bizLoadDispatchService.getListTime(bizLoadDispatchPageParam));
    }

    /**
     * 起卸分配替换
     *
     * @author fanzherong
     * @date  2025/07/01 09:47
     */
    @Operation(summary = "起卸分配替换")
    @CommonLog("起卸分配替换")
    @PostMapping("/biz/bizloaddispatch/replaceLoad")
    public CommonResult<String> replaceLoad(@RequestBody @Valid BizLoadDispatchEditParam bizLoadDispatchEditParam) {
        bizLoadDispatchService.replaceLoad(bizLoadDispatchEditParam);
        return CommonResult.ok();
    }

    /**
     * 装卸分配替换
     *
     * @author fanzherong
     * @date  2025/07/01 09:47
     */
    @Operation(summary = "装卸分配替换")
    @CommonLog("装卸分配替换")
    @PostMapping("/biz/bizloaddispatch/replaceDispatch")
    public CommonResult<String> replaceDispatch(@RequestBody @Valid BizLoadDispatchEditParam bizLoadDispatchEditParam) {
        bizLoadDispatchService.replaceDispatch(bizLoadDispatchEditParam);
        return CommonResult.ok();
    }
}
