/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizloaddispatch.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import vip.xiaonuo.biz.modular.bizloaddispatch.entity.BizLoadDispatch;
import vip.xiaonuo.biz.modular.bizloaddispatch.param.BizLoadDispatchAddParam;
import vip.xiaonuo.biz.modular.bizloaddispatch.param.BizLoadDispatchEditParam;
import vip.xiaonuo.biz.modular.bizloaddispatch.param.BizLoadDispatchIdParam;
import vip.xiaonuo.biz.modular.bizloaddispatch.param.BizLoadDispatchPageParam;

import java.util.List;

/**
 * 起卸预约分配Service接口
 *
 * @author fanzherong
 * @date  2025/07/01 09:47
 **/
public interface BizLoadDispatchService extends IService<BizLoadDispatch> {

    /**
     * 获取起卸预约分配分页
     *
     * @author fanzherong
     * @date  2025/07/01 09:47
     */
    Page<BizLoadDispatch> page(BizLoadDispatchPageParam bizLoadDispatchPageParam);

    /**
     * 添加起卸预约分配
     *
     * @author fanzherong
     * @date  2025/07/01 09:47
     */
    void add(BizLoadDispatchAddParam bizLoadDispatchAddParam);

    /**
     * 添加装货调度
     * @param bizLoadDispatchAddParam
     */
    void addDispatch(BizLoadDispatchAddParam bizLoadDispatchAddParam);

    /**
     * 添加起卸调度
     */
    void addLoad(BizLoadDispatchAddParam bizLoadDispatchAddParam);

    /**
     * 编辑起卸预约分配
     *
     * @author fanzherong
     * @date  2025/07/01 09:47
     */
    void edit(BizLoadDispatchEditParam bizLoadDispatchEditParam);

    /**
     * 删除起卸预约分配
     *
     * @author fanzherong
     * @date  2025/07/01 09:47
     */
    void delete(List<BizLoadDispatchIdParam> bizLoadDispatchIdParamList);

    void deleteDispatch(List<BizLoadDispatchIdParam> bizLoadDispatchIdParamList);

    /**
     * 获取起卸预约分配详情
     *
     * @author fanzherong
     * @date  2025/07/01 09:47
     */
    BizLoadDispatch detail(BizLoadDispatchIdParam bizLoadDispatchIdParam);

    /**
     * 获取起卸预约分配详情
     *
     * @author fanzherong
     * @date  2025/07/01 09:47
     **/
    BizLoadDispatch queryEntity(String id);

    /**
     * 获取起卸预约调度分配列表
     * @param bizLoadDispatchPageParam
     * @return
     */
    Page<BizLoadDispatch> getPageList(BizLoadDispatchPageParam bizLoadDispatchPageParam);

    /**
     * 起卸分配替换
     * @param bizLoadDispatchEditParam
     */
    void replaceLoad(BizLoadDispatchEditParam bizLoadDispatchEditParam);

    /**
     * 装货分配替换
     * @param bizLoadDispatchEditParam
     */
    void replaceDispatch(BizLoadDispatchEditParam bizLoadDispatchEditParam);

    /**
     * 查询装货点位列表
     */
    List<BizLoadDispatch> getList(BizLoadDispatchPageParam bizLoadDispatchPageParam);

    /**
     * 查询装卸时间列表
     */
    List<BizLoadDispatch> getListTime(BizLoadDispatchPageParam bizLoadDispatchPageParam);
}
