/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizloadpoint.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.biz.modular.customer.entity.BizCustomer;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizloadpoint.entity.BizLoadPoint;
import vip.xiaonuo.biz.modular.bizloadpoint.mapper.BizLoadPointMapper;
import vip.xiaonuo.biz.modular.bizloadpoint.param.BizLoadPointAddParam;
import vip.xiaonuo.biz.modular.bizloadpoint.param.BizLoadPointEditParam;
import vip.xiaonuo.biz.modular.bizloadpoint.param.BizLoadPointIdParam;
import vip.xiaonuo.biz.modular.bizloadpoint.param.BizLoadPointPageParam;
import vip.xiaonuo.biz.modular.bizloadpoint.service.BizLoadPointService;

import java.util.List;

/**
 * 装货点位信息Service接口实现类
 *
 * @author fanzherong
 * @date  2025/05/29 14:54
 **/
@Service
public class BizLoadPointServiceImpl extends ServiceImpl<BizLoadPointMapper, BizLoadPoint> implements BizLoadPointService {

    @Override
    public Page<BizLoadPoint> page(BizLoadPointPageParam bizLoadPointPageParam) {
        QueryWrapper<BizLoadPoint> queryWrapper = new QueryWrapper<BizLoadPoint>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizLoadPointPageParam.getLoadPoint())) {
            queryWrapper.lambda().like(BizLoadPoint::getLoadPoint, bizLoadPointPageParam.getLoadPoint());
        }
        if(ObjectUtil.isNotEmpty(bizLoadPointPageParam.getLoadType())){
            queryWrapper.lambda().eq(BizLoadPoint::getLoadType,bizLoadPointPageParam.getLoadType());
        }
        queryWrapper.lambda().eq(BizLoadPoint::getDeleteFlag, "NOT_DELETE");
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizLoadPointAddParam bizLoadPointAddParam) {
        BizLoadPoint bizLoadPoint = BeanUtil.toBean(bizLoadPointAddParam, BizLoadPoint.class);
        this.save(bizLoadPoint);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizLoadPointEditParam bizLoadPointEditParam) {
        BizLoadPoint bizLoadPoint = this.queryEntity(bizLoadPointEditParam.getId());
        BeanUtil.copyProperties(bizLoadPointEditParam, bizLoadPoint);
        this.updateById(bizLoadPoint);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizLoadPointIdParam> bizLoadPointIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizLoadPointIdParamList, BizLoadPointIdParam::getId));
    }

    @Override
    public BizLoadPoint detail(BizLoadPointIdParam bizLoadPointIdParam) {
        return this.queryEntity(bizLoadPointIdParam.getId());
    }

    @Override
    public BizLoadPoint queryEntity(String id) {
        BizLoadPoint bizLoadPoint = this.getById(id);
        if(ObjectUtil.isEmpty(bizLoadPoint)) {
            throw new CommonException("装货点位信息不存在，id值为：{}", id);
        }
        return bizLoadPoint;
    }

    @Override
    public List<BizLoadPoint> getList(BizLoadPointPageParam bizLoadPointPageParam) {
        QueryWrapper<BizLoadPoint> queryWrapper = new QueryWrapper<BizLoadPoint>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizLoadPointPageParam.getLoadPoint())) {
            queryWrapper.lambda().like(BizLoadPoint::getLoadPoint, bizLoadPointPageParam.getLoadPoint());
        }
        if(ObjectUtil.isNotEmpty(bizLoadPointPageParam.getAppointType())){
            queryWrapper.lambda().eq(BizLoadPoint::getLoadType,bizLoadPointPageParam.getAppointType());
        }
        queryWrapper.lambda().eq(BizLoadPoint::getDeleteFlag, "NOT_DELETE");
        queryWrapper.lambda().orderByDesc(BizLoadPoint::getCreateTime);
        return this.list(queryWrapper);
    }
}
