/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizloadtime.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.bizloadtime.entity.BizLoadTime;
import vip.xiaonuo.biz.modular.bizloadtime.param.BizLoadTimeAddParam;
import vip.xiaonuo.biz.modular.bizloadtime.param.BizLoadTimeEditParam;
import vip.xiaonuo.biz.modular.bizloadtime.param.BizLoadTimeIdParam;
import vip.xiaonuo.biz.modular.bizloadtime.param.BizLoadTimePageParam;
import vip.xiaonuo.biz.modular.bizloadtime.service.BizLoadTimeService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 装货时间配置控制器
 *
 * @author fanzherong
 * @date  2025/05/29 14:55
 */
@Tag(name = "装货时间配置控制器")
@RestController
@Validated
public class BizLoadTimeController {

    @Resource
    private BizLoadTimeService bizLoadTimeService;

    /**
     * 获取装货时间配置分页
     *
     * @author fanzherong
     * @date  2025/05/29 14:55
     */
    @Operation(summary = "获取装货时间配置分页")
    @GetMapping("/biz/bizloadtime/page")
    public CommonResult<Page<BizLoadTime>> page(BizLoadTimePageParam bizLoadTimePageParam) {
        return CommonResult.data(bizLoadTimeService.page(bizLoadTimePageParam));
    }

    /**
     * 添加装货时间配置
     *
     * @author fanzherong
     * @date  2025/05/29 14:55
     */
    @Operation(summary = "添加装货时间配置")
    @CommonLog("添加装货时间配置")
    @SaCheckPermission("/biz/bizloadtime/add")
    @PostMapping("/biz/bizloadtime/add")
    public CommonResult<String> add(@RequestBody @Valid BizLoadTimeAddParam bizLoadTimeAddParam) {
        bizLoadTimeService.add(bizLoadTimeAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑装货时间配置
     *
     * @author fanzherong
     * @date  2025/05/29 14:55
     */
    @Operation(summary = "编辑装货时间配置")
    @CommonLog("编辑装货时间配置")
    @SaCheckPermission("/biz/bizloadtime/edit")
    @PostMapping("/biz/bizloadtime/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizLoadTimeEditParam bizLoadTimeEditParam) {
        bizLoadTimeService.edit(bizLoadTimeEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除装货时间配置
     *
     * @author fanzherong
     * @date  2025/05/29 14:55
     */
    @Operation(summary = "删除装货时间配置")
    @CommonLog("删除装货时间配置")
    @SaCheckPermission("/biz/bizloadtime/delete")
    @PostMapping("/biz/bizloadtime/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizLoadTimeIdParam> bizLoadTimeIdParamList) {
        bizLoadTimeService.delete(bizLoadTimeIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取装货时间配置详情
     *
     * @author fanzherong
     * @date  2025/05/29 14:55
     */
    @Operation(summary = "获取装货时间配置详情")
    @GetMapping("/biz/bizloadtime/detail")
    public CommonResult<BizLoadTime> detail(@Valid BizLoadTimeIdParam bizLoadTimeIdParam) {
        return CommonResult.data(bizLoadTimeService.detail(bizLoadTimeIdParam));
    }

    /**
     * 根据提货时间配置ID和装货点位ID获取装货时间配置
     *
     * @author sandy
     * @date  2025/05/30 14:20
     */
    @Operation(summary = "根据提货时间配置ID和装货点位ID获取装货时间配置")
    @GetMapping("/biz/bizloadtime/search")
    public CommonResult<List<BizLoadTime>> search(@Valid BizLoadTimePageParam bizLoadTimePageParam) {
        return CommonResult.data(bizLoadTimeService.search(bizLoadTimePageParam));
    }

    /**
     * 根据装货点位ID获取装货时间配置
     *
     * @author sandy
     * @date  2025/05/30 14:20
     */
    @Operation(summary = "根据装货点位ID获取装货时间配置")
    @GetMapping("/biz/bizloadtime/searchNow")
    public CommonResult<List<BizLoadTime>> searchNow(@Valid BizLoadTimePageParam bizLoadTimePageParam) {
        return CommonResult.data(bizLoadTimeService.searchNow(bizLoadTimePageParam));
    }

}
