/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizloaduser.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.bizloaduser.entity.BizLoadUser;
import vip.xiaonuo.biz.modular.bizloaduser.param.BizLoadUserAddParam;
import vip.xiaonuo.biz.modular.bizloaduser.param.BizLoadUserEditParam;
import vip.xiaonuo.biz.modular.bizloaduser.param.BizLoadUserIdParam;
import vip.xiaonuo.biz.modular.bizloaduser.param.BizLoadUserPageParam;
import vip.xiaonuo.biz.modular.bizloaduser.service.BizLoadUserService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 装货点人员信息控制器
 *
 * @author fanzherong
 * @date  2025/05/29 14:56
 */
@Tag(name = "装货点人员信息控制器")
@RestController
@Validated
public class BizLoadUserController {

    @Resource
    private BizLoadUserService bizLoadUserService;

    /**
     * 获取装货点人员信息分页
     *
     * @author fanzherong
     * @date  2025/05/29 14:56
     */
    @Operation(summary = "获取装货点人员信息分页")
    @GetMapping("/biz/bizloaduser/page")
    public CommonResult<Page<BizLoadUser>> page(BizLoadUserPageParam bizLoadUserPageParam) {
        return CommonResult.data(bizLoadUserService.page(bizLoadUserPageParam));
    }

    /**
     * 添加装货点人员信息
     *
     * @author fanzherong
     * @date  2025/05/29 14:56
     */
    @Operation(summary = "添加装货点人员信息")
    @CommonLog("添加装货点人员信息")
    @SaCheckPermission("/biz/bizloaduser/add")
    @PostMapping("/biz/bizloaduser/add")
    public CommonResult<String> add(@RequestBody @Valid BizLoadUserAddParam bizLoadUserAddParam) {
        bizLoadUserService.add(bizLoadUserAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑装货点人员信息
     *
     * @author fanzherong
     * @date  2025/05/29 14:56
     */
    @Operation(summary = "编辑装货点人员信息")
    @CommonLog("编辑装货点人员信息")
    @SaCheckPermission("/biz/bizloaduser/edit")
    @PostMapping("/biz/bizloaduser/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizLoadUserEditParam bizLoadUserEditParam) {
        bizLoadUserService.edit(bizLoadUserEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除装货点人员信息
     *
     * @author fanzherong
     * @date  2025/05/29 14:56
     */
    @Operation(summary = "删除装货点人员信息")
    @CommonLog("删除装货点人员信息")
    @SaCheckPermission("/biz/bizloaduser/delete")
    @PostMapping("/biz/bizloaduser/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizLoadUserIdParam> bizLoadUserIdParamList) {
        bizLoadUserService.delete(bizLoadUserIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取装货点人员信息详情
     *
     * @author fanzherong
     * @date  2025/05/29 14:56
     */
    @Operation(summary = "获取装货点人员信息详情")
    @GetMapping("/biz/bizloaduser/detail")
    public CommonResult<BizLoadUser> detail(@Valid BizLoadUserIdParam bizLoadUserIdParam) {
        return CommonResult.data(bizLoadUserService.detail(bizLoadUserIdParam));
    }
}
