/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizorder.service.impl;

import cn.dev33.satoken.stp.StpUtil;
import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.img.ImgUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpException;
import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fhs.trans.service.impl.TransService;
import com.google.common.collect.Maps;
import jakarta.annotation.Resource;
import jakarta.servlet.http.HttpServletResponse;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.compress.utils.Lists;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.auth.api.SaBaseLoginUserApi;
import vip.xiaonuo.auth.core.util.StpLoginUserUtil;
import vip.xiaonuo.biz.core.sign.utils.MD5;
import vip.xiaonuo.biz.modular.bizappointmentrecord.entity.BizAppointmentRecord;
import vip.xiaonuo.biz.modular.bizappointmentrecord.mapper.BizAppointmentRecordMapper;
import vip.xiaonuo.biz.modular.bizappointmentrecord.param.BizAppointmentExportResult;
import vip.xiaonuo.biz.modular.bizappointmentrecord.service.BizAppointmentRecordService;
import vip.xiaonuo.biz.modular.bizauditlog.entity.BizAuditLog;
import vip.xiaonuo.biz.modular.bizauditlog.service.BizAuditLogService;
import vip.xiaonuo.biz.modular.bizconfig.entity.BizConfig;
import vip.xiaonuo.biz.modular.bizconfig.service.BizConfigService;
import vip.xiaonuo.biz.modular.bizorderconfig.entity.BizOrderConfig;
import vip.xiaonuo.biz.modular.bizorderconfig.service.BizOrderConfigService;
import vip.xiaonuo.biz.modular.bizordersupplier.entity.BizOrderSupplier;
import vip.xiaonuo.biz.modular.bizordersupplier.service.BizOrderSupplierService;
import vip.xiaonuo.biz.modular.bizsaleorder.entity.BizSaleOrder;
import vip.xiaonuo.biz.modular.bizsaleorder.service.BizSaleOrderService;
import vip.xiaonuo.biz.modular.customer.entity.BizCustomer;
import vip.xiaonuo.biz.modular.customer.service.BizCustomerService;
import vip.xiaonuo.biz.modular.bizorder.param.*;
import vip.xiaonuo.biz.modular.goodsConf.entity.BizGoodsConf;
import vip.xiaonuo.biz.modular.goodsConf.service.BizGoodsConfService;
import vip.xiaonuo.biz.modular.record.entity.BizRecord;
import vip.xiaonuo.biz.modular.user.entity.BizUser;
import vip.xiaonuo.biz.modular.user.service.BizUserService;
import vip.xiaonuo.biz.modular.utils.CommonExportUtil;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizorder.entity.BizOrder;
import vip.xiaonuo.biz.modular.bizorder.mapper.BizOrderMapper;
import vip.xiaonuo.biz.modular.bizorder.service.BizOrderService;

import java.io.*;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.net.URL;
import java.net.URLConnection;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 订单管理Service接口实现类
 *
 * @author fanzherong
 * @date  2025/03/21 17:16
 **/
@Service
@Slf4j
public class BizOrderServiceImpl extends ServiceImpl<BizOrderMapper, BizOrder> implements BizOrderService {

    @Resource
    private BizCustomerService bizCustomerService;

    @Resource
    private TransService transService;

    @Resource
    private BizGoodsConfService bizGoodsConfService;

    @Resource
    private BizOrderConfigService orderConfigService;

    @Resource
    private BizConfigService bizConfigService;

    @Resource
    private BizSaleOrderService bizSaleOrderService;

    @Resource
    private BizAppointmentRecordMapper bizAppointmentRecordMapper;

    @Resource
    private BizUserService bizUserService;

    @Resource
    private BizOrderSupplierService bizOrderSupplierService;

    @Resource
    private BizAuditLogService bizAuditLogService;

    @Resource(name = "loginUserApi")
    private SaBaseLoginUserApi loginUserApi;

    @Override
    public Page<BizOrder> page(BizOrderPageParam bizOrderPageParam) {
        QueryWrapper<BizOrder> queryWrapper = getQueryWrapper(bizOrderPageParam);
        Page<BizOrder> page = this.getBaseMapper().getPage(CommonPageRequest.defaultPage(), queryWrapper);
        for(BizOrder bizOrder : page.getRecords()){
            List<BizOrderSupplier> supplierList = bizOrderSupplierService.list(new QueryWrapper<BizOrderSupplier>().lambda().
                    eq(BizOrderSupplier::getOrderId, bizOrder.getId()));
            List<String> idList = Lists.newArrayList();
            supplierList.forEach(supplier->idList.add(supplier.getSupplierId()));
            bizOrder.setSupplierIdList(idList);
        }
        return page;
    }

    @Override
    public Page<BizOrder> pageSupplier(BizOrderPageParam bizOrderPageParam) {
        QueryWrapper<BizOrder> queryWrapper = geSuppliertQueryWrapper(bizOrderPageParam);
        Page<BizOrder> page = this.getBaseMapper().getSupplierPage(CommonPageRequest.defaultPage(), queryWrapper);
        return page;
    }


    public QueryWrapper<BizOrder> geSuppliertQueryWrapper(BizOrderPageParam bizOrderPageParam){
        QueryWrapper<BizOrder> queryWrapper = new QueryWrapper<BizOrder>().checkSqlInjection();
        //订单编号查询
        if(ObjectUtil.isNotEmpty(bizOrderPageParam.getOrderNumber())){
            queryWrapper.like("bo.order_number",bizOrderPageParam.getOrderNumber());
        }
        //客户名称查询
        if(ObjectUtil.isNotEmpty(bizOrderPageParam.getCustomerName())){
            queryWrapper.like("bc.name",bizOrderPageParam.getCustomerName());
        }
        //货品名称查询
        if(ObjectUtil.isNotEmpty(bizOrderPageParam.getGoodsName())){
            queryWrapper.like("bg.`GOODS_NAME`",bizOrderPageParam.getGoodsName());
        }
        //状态查询
        if(ObjectUtil.isNotEmpty(bizOrderPageParam.getOrderStatus())){
            queryWrapper.eq("bo.order_status",bizOrderPageParam.getOrderStatus());
            queryWrapper.eq("bos.status","0");
        }
        //订单类型
        if(ObjectUtil.isNotEmpty(bizOrderPageParam.getOrderType())){
            queryWrapper.eq("bo.order_type",bizOrderPageParam.getOrderType());
        }
        // 供应商角色，查询是自己的
        if(StpLoginUserUtil.getLoginUser().getRoleCodeList().contains("supplier")){
            queryWrapper.eq("bos.supplier_id",StpLoginUserUtil.getLoginUser().getCustomerId());
        }
        queryWrapper.eq("bo.delete_flag","NOT_DELETE");
        queryWrapper.orderByDesc("bo.create_time");
        return queryWrapper;
    }

    public QueryWrapper<BizOrder> getQueryWrapper(BizOrderPageParam bizOrderPageParam){
        QueryWrapper<BizOrder> queryWrapper = new QueryWrapper<BizOrder>().checkSqlInjection();
        //订单名称查询
        if(ObjectUtil.isNotEmpty(bizOrderPageParam.getOrderName())){
            queryWrapper.like("bo.order_name",bizOrderPageParam.getOrderName());
        }
        //订单编号查询
        if(ObjectUtil.isNotEmpty(bizOrderPageParam.getOrderNumber())){
            queryWrapper.like("bo.order_number",bizOrderPageParam.getOrderNumber());
        }
        //客户名称查询
        if(ObjectUtil.isNotEmpty(bizOrderPageParam.getCustomerName())){
            queryWrapper.like("bc.name",bizOrderPageParam.getCustomerName());
        }
        //货品名称查询
        if(ObjectUtil.isNotEmpty(bizOrderPageParam.getGoodsName())){
            queryWrapper.like("bg.`GOODS_NAME`",bizOrderPageParam.getGoodsName());
        }
        //状态查询
        if(ObjectUtil.isNotEmpty(bizOrderPageParam.getOrderStatus())){
            queryWrapper.eq("bo.order_status",bizOrderPageParam.getOrderStatus());
        }
        //订单来源
        if(ObjectUtil.isNotEmpty(bizOrderPageParam.getOrderSource())){
            queryWrapper.eq("bo.order_source",bizOrderPageParam.getOrderSource());
        }
        //订单类型
        if(ObjectUtil.isNotEmpty(bizOrderPageParam.getOrderType())){
            queryWrapper.eq("bo.order_type",bizOrderPageParam.getOrderType());
        }
        //关键字
        if(ObjectUtil.isNotEmpty(bizOrderPageParam.getSearchKey())){
            queryWrapper.and(wrapper->wrapper.like("bo.order_number",bizOrderPageParam.getSearchKey()).or().
                    like("bc.name",bizOrderPageParam.getSearchKey()).or().
                    like("bg.`GOODS_NAME`",bizOrderPageParam.getSearchKey()));
        }
        //默认当日
        if(ObjectUtil.isEmpty(bizOrderPageParam.getOrderNumber()) && ObjectUtil.isEmpty(bizOrderPageParam.getCustomerName())
            && ObjectUtil.isEmpty(bizOrderPageParam.getGoodsName()) && ObjectUtil.isEmpty(bizOrderPageParam.getOrderStatus())
                && ObjectUtil.isEmpty(bizOrderPageParam.getSearchKey())){
            String format = DateUtil.format(DateUtil.date(), "yyyy-MM-dd");
            queryWrapper.between("bo.create_time",format+" 00:00:00",format+" 23:59:59");
        }
        // 校验数据范围
        List<String> loginUserDataScope = StpLoginUserUtil.getLoginUserDataScope();
        if(ObjectUtil.isEmpty(loginUserDataScope)) {
            if(StpLoginUserUtil.getLoginUser().getRoleCodeList().contains("customer")){
                //用友客户查询自己签名的物流订单
                queryWrapper.eq("bo.customer_id", StpLoginUserUtil.getLoginUser().getCustomerId());
            }
        }
        // 供应商角色，查询是自己的
        if(StpLoginUserUtil.getLoginUser().getRoleCodeList().contains("supplier")){
            queryWrapper.eq("bo.supplier_id",StpLoginUserUtil.getLoginUser().getCustomerId());
        }
        queryWrapper.eq("bo.delete_flag","NOT_DELETE");
        queryWrapper.orderByDesc("bo.create_time");
        return queryWrapper;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizOrderAddParam bizOrderAddParam) {
        //查询时间段内货品重量
        BizGoodsConf bizGoodsConf = bizGoodsConfService.getById(bizOrderAddParam.getDeliveryTimeId());
        if(ObjectUtil.isNull(bizGoodsConf)){
            throw new CommonException("未查询到时间段信息！");
        }
        if(bizOrderAddParam.getOrderWeight().multiply(new BigDecimal(1000)).compareTo(bizGoodsConf.getLastWeight()) > 0 ){
            throw new CommonException("当前时间段货品余量不足！");
        }
        BizOrder bizOrder = BeanUtil.toBean(bizOrderAddParam, BizOrder.class);
        bizOrder.setGoodId(bizGoodsConf.getGoodsId());
        //数据库默认存KG，页面展示用吨
        bizOrder.setOrderWeight(bizOrder.getOrderWeight().multiply(new BigDecimal(1000)));
        //来源，手动新增
        bizOrder.setOrderSource("2");
        bizOrder.setOrderStatus("0");
        this.save(bizOrder);

        //存供应商表
        if(ObjectUtil.isNotEmpty(bizOrderAddParam.getSupplierIdList())){
            for(String supplierId : bizOrderAddParam.getSupplierIdList()){
                BizOrderSupplier bizOrderSupplier = new BizOrderSupplier();
                bizOrderSupplier.setOrderId(bizOrder.getId());
                bizOrderSupplier.setSupplierId(supplierId);
                bizOrderSupplierService.save(bizOrderSupplier);
            }
        }

        //修改时段配置内物品重量
        bizGoodsConfService.editUsedWeight(bizGoodsConf.getId(),bizOrderAddParam.getOrderWeight().multiply(new BigDecimal(1000)));

        //修改销售订单状态
        log.info("销售订单id:"+bizOrderAddParam.getSaleOrderInfo());
        if(ObjectUtil.isNotEmpty(bizOrderAddParam.getSaleOrderInfo())){
            BizSaleOrder bizSaleOrder = bizSaleOrderService.getById(bizOrderAddParam.getSaleOrderInfo());
            if(ObjectUtil.isNotNull(bizSaleOrder)){
                bizSaleOrder.setSaleStatus("2");
                bizSaleOrderService.updateById(bizSaleOrder);
            }
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizOrderEditParam bizOrderEditParam) {
        //查询时间段内货品重量
        BizGoodsConf bizGoodsConf = bizGoodsConfService.getById(bizOrderEditParam.getDeliveryTimeId());
        if(ObjectUtil.isNull(bizGoodsConf)){
            throw new CommonException("未查询到时间段信息！");
        }
        BizOrder bizOrder = this.queryEntity(bizOrderEditParam.getId());
        if(bizOrder.getOrderWeight().compareTo(bizOrderEditParam.getOrderWeight().multiply(new BigDecimal(1000))) != 0 ){
            if(bizOrderEditParam.getOrderWeight().multiply(new BigDecimal(1000)).
                    compareTo(bizGoodsConf.getLastWeight().add(bizOrder.getOrderWeight())) > 0 ){
                throw new CommonException("当前时间段货品余量不足！");
            }

            //修改了提货时段，原来时段的货物重量还原，新的提货时段货物扣减
            //旧的提货时段
            BizGoodsConf goodsConf = bizGoodsConfService.getById(bizOrder.getDeliveryTimeId());
            //修改时段配置内物品重量
            bizGoodsConfService.editUsedWeight(goodsConf.getId(),bizOrder.getOrderWeight().negate());

            //修改新时段
            bizGoodsConfService.editUsedWeight(bizGoodsConf.getId(),bizOrderEditParam.getOrderWeight().multiply(new BigDecimal(1000)));

        }else{
            if(!StringUtils.equals(bizOrderEditParam.getDeliveryTimeId(),bizOrder.getDeliveryTimeId())){
                //修改了提货时段，原来时段的货物重量还原，新的提货时段货物扣减
                //旧的提货时段
                BizGoodsConf goodsConf = bizGoodsConfService.getById(bizOrder.getDeliveryTimeId());
                //修改时段配置内物品重量
                bizGoodsConfService.editUsedWeight(goodsConf.getId(),bizOrder.getOrderWeight().negate());

                //修改新时段
                bizGoodsConfService.editUsedWeight(bizGoodsConf.getId(),bizOrderEditParam.getOrderWeight().multiply(new BigDecimal(1000)));
            }
        }
        //判断是否修改订单
        if(!StringUtils.equals(bizOrder.getSaleOrderInfo(),bizOrderEditParam.getSaleOrderInfo())){
            long count = this.count(new QueryWrapper<BizOrder>().lambda().eq(BizOrder::getSaleOrderInfo, bizOrderEditParam.getSaleOrderInfo()));
            if(count>0){
                throw new CommonException("销售订单已经添加过！");
            }
            //修改之前订单状态
            BizSaleOrder bizSaleOrder = bizSaleOrderService.getById(bizOrder.getSaleOrderInfo());
            if(ObjectUtil.isNotNull(bizSaleOrder)){
                bizSaleOrder.setSaleStatus("1");
                bizSaleOrderService.updateById(bizSaleOrder);
            }

            //修改现在订单状态
            BizSaleOrder saleOrder = bizSaleOrderService.getById(bizOrderEditParam.getSaleOrderInfo());
            if(ObjectUtil.isNotNull(saleOrder)){
                saleOrder.setSaleStatus("2");
                bizSaleOrderService.updateById(saleOrder);
            }
        }
        BeanUtil.copyProperties(bizOrderEditParam, bizOrder);
        bizOrder.setGoodId(bizGoodsConf.getGoodsId());
        //设置订单重量
        if(bizOrder.getOrderWeight().compareTo(bizOrderEditParam.getOrderWeight()) != 0){
            bizOrder.setOrderWeight(bizOrderEditParam.getOrderWeight().multiply(new BigDecimal(1000)));
        }else{
            bizOrder.setOrderWeight(bizOrder.getOrderWeight().multiply(new BigDecimal(1000)));
        }
        this.updateById(bizOrder);

        //删除供应商信息
        List<BizOrderSupplier> supplierList = bizOrderSupplierService.list(new QueryWrapper<BizOrderSupplier>().lambda().eq(BizOrderSupplier::getOrderId, bizOrder.getId()));
        bizOrderSupplierService.removeByIds(CollStreamUtil.toList(supplierList, BizOrderSupplier::getId));

        //新增供应商信息
        //存供应商表
        if(ObjectUtil.isNotEmpty(bizOrderEditParam.getSupplierIdList())){
            for(String supplierId : bizOrderEditParam.getSupplierIdList()){
                BizOrderSupplier bizOrderSupplier = new BizOrderSupplier();
                bizOrderSupplier.setOrderId(bizOrder.getId());
                bizOrderSupplier.setSupplierId(supplierId);
                bizOrderSupplierService.save(bizOrderSupplier);
            }
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizOrderIdParam> bizOrderIdParamList) {
        //执行删除操作前，将重量回写
        for(BizOrderIdParam bizOrderIdParam : bizOrderIdParamList){
            BizOrder bizOrder = this.queryEntity(bizOrderIdParam.getId());
            BizGoodsConf bizGoodsConf = bizGoodsConfService.getById(bizOrder.getDeliveryTimeId());
            if(ObjectUtil.isNotNull(bizGoodsConf)){
                //修改时段配置内物品重量
                bizGoodsConfService.editUsedWeight(bizGoodsConf.getId(),bizOrder.getOrderWeight().negate());
            }

            //查询销售订单信息
            BizSaleOrder bizSaleOrder = bizSaleOrderService.getById(bizOrder.getSaleOrderInfo());
            if(ObjectUtil.isNotNull(bizSaleOrder)){
                bizSaleOrder.setSaleStatus("1");
                bizSaleOrderService.updateById(bizSaleOrder);
            }
        }
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizOrderIdParamList, BizOrderIdParam::getId));
    }

    @Override
    public BizOrder detail(BizOrderIdParam bizOrderIdParam) {
        return this.queryEntity(bizOrderIdParam.getId());
    }

    @Override
    public BizOrder queryEntity(String id) {
        BizOrder bizOrder = this.getById(id);
        if(ObjectUtil.isEmpty(bizOrder)) {
            throw new CommonException("订单管理不存在，id值为：{}", id);
        }
        return bizOrder;
    }

    @Override
    public List<BizCustomer> getCustomerById(BizOrderIdParam bizOrderIdParam) {
        if(ObjectUtil.isNotEmpty(bizOrderIdParam.getId())){
            List<BizCustomer> customerList = bizCustomerService.list(new QueryWrapper<BizCustomer>().lambda().eq(BizCustomer::getId, bizOrderIdParam.getId()));
            return customerList;
        }
        return null;
    }

    @Override
    public void bindCustomerId(BizOrderEditParam bizOrderEditParam) {
        BizOrder bizOrder = this.queryEntity(bizOrderEditParam.getId());
        if(ObjectUtil.isNotEmpty(bizOrderEditParam.getCustomerIdList())){
            bizOrder.setCustomerId(bizOrderEditParam.getCustomerIdList().get(0));
        }
        this.updateById(bizOrder);
    }

    @Override
    public void exportRecord(BizOrderPageParam bizOrderPageParam, HttpServletResponse response) throws IOException {
        QueryWrapper<BizOrder> queryWrapper = getQueryWrapper(bizOrderPageParam);
        List<BizOrder> orderList = this.getBaseMapper().getPage(queryWrapper);
        String fileName = "订单报表.xlsx";
        List<BizOrderExportResult> list = Lists.newArrayList();
        transService.transBatch(orderList);
        for(BizOrder bizOrder : orderList){
            BizOrderExportResult bizOrderExportResult = new BizOrderExportResult();
            BeanUtil.copyProperties(bizOrder, bizOrderExportResult);
            //bizOrderExportResult.setOrderSourceName((String) bizOrder.getTransMap().get("orderSourceName"));
            bizOrderExportResult.setOrderStatusName((String) bizOrder.getTransMap().get("orderStatusName"));
            list.add(bizOrderExportResult);
        }
        CommonExportUtil.export(fileName, BizOrderExportResult.class,list,response,"订单报表");
    }

    @Override
    public void endOrder(BizOrderIdParam bizOrderIdParam) {
        BizOrder bizOrder = this.queryEntity(bizOrderIdParam.getId());
        bizOrder.setOrderStatus("2");
        this.updateById(bizOrder);
    }

    @Override
    public List<BizOrder> getList() {
        return this.list(new QueryWrapper<BizOrder>().lambda().in(BizOrder::getOrderStatus,"3","4"));
    }

    @Override
    public void updateOrderSign(BizOrderEditParam bizOrderEditParam) {
        BizOrder bizOrder = this.queryEntity(bizOrderEditParam.getId());
        if(ObjectUtil.isEmpty(bizOrderEditParam.getOrderSign())){
            throw new CommonException("签名不能为空！");
        }
        String orderSign = bizOrderEditParam.getOrderSign();
        if(bizOrderEditParam.getOrderSign().contains(StrUtil.COMMA)) {
            orderSign = StrUtil.split(orderSign, StrUtil.COMMA).get(1);
        }
        String base64 = ImgUtil.toBase64DataUri(ImgUtil.scale(ImgUtil.toImage(orderSign),
                100, 50, null), ImgUtil.IMAGE_TYPE_PNG);

        bizOrder.setOrderSign(base64);
        bizOrder.setOrderStatus("2");
        this.updateById(bizOrder);
    }

    @Transactional
    @Override
    public void endOrderSign(BizOrderEditParam bizOrderEditParam) {
        BizOrder bizOrder = this.queryEntity(bizOrderEditParam.getId());
        if(ObjectUtil.isEmpty(bizOrderEditParam.getEndSign())){
            throw new CommonException("签名不能为空！");
        }
        String endSign = bizOrderEditParam.getEndSign();
        if(bizOrderEditParam.getEndSign().contains(StrUtil.COMMA)) {
            endSign = StrUtil.split(endSign, StrUtil.COMMA).get(1);
        }
        String base64 = ImgUtil.toBase64DataUri(ImgUtil.scale(ImgUtil.toImage(endSign),
                100, 50, null), ImgUtil.IMAGE_TYPE_PNG);

        bizOrder.setEndSign(base64);
        bizOrder.setOrderStatus("7");
        bizOrder.setEndSignTime(new Date());
        this.updateById(bizOrder);

        //上传erp
        sendOrderForErp(bizOrder);
    }

    @Transactional
    @Override
    public void orderConfirm(BizOrderEditParam bizOrderEditParam) {
        BizOrder bizOrder = this.queryEntity(bizOrderEditParam.getId());
        bizOrder.setOrderStatus("8");
        this.updateById(bizOrder);

        //存取预约次数配置
        BizOrderConfig bizOrderConfig = new BizOrderConfig();
        bizOrderConfig.setOrderId(bizOrder.getId());
        BizConfig bizConfig = bizConfigService.getOne(new QueryWrapper<BizConfig>().lambda().last("limit 1"));
        if(ObjectUtil.isNotNull(bizConfig)){
            //采用配置的申请次数
            //bizOrderConfig.setApplyNumber(bizConfig.getApplyCount());

            //用订单重量除以配置的车辆装载量，向下取整，得出预约次数
            BigDecimal applyCount = bizOrder.getOrderWeight().divide(bizConfig.getLoadWeight(), RoundingMode.FLOOR);
            bizOrderConfig.setApplyNumber(applyCount.intValue());
        }
        orderConfigService.save(bizOrderConfig);
    }

    @Transactional
    @Override
    public void endOrder(BizOrderEditParam bizOrderEditParam) {
        BizOrder bizOrder = this.queryEntity(bizOrderEditParam.getId());
        //判断当前是否包运订单
        checkEndParam(bizOrder);
        if(bizOrder.getNetWeight().compareTo(BigDecimal.ZERO) != 0){
            BigDecimal orderBalance = bizOrder.getOrderWeight().subtract(bizOrder.getNetWeight());
            BigDecimal result = orderBalance.divide(bizOrder.getOrderWeight(),2, BigDecimal.ROUND_HALF_UP).multiply(new BigDecimal(100));
            if(result.compareTo(new BigDecimal(20)) <= 0){
                //大于80%不需要审核
                bizOrder.setOrderStatus("10");

                //销售订单结束
                BizSaleOrder bizSaleOrder = bizSaleOrderService.getById(bizOrder.getSaleOrderInfo());
                if(ObjectUtil.isNotNull(bizSaleOrder)){
                    bizSaleOrder.setSaleStatus("3");
                    bizSaleOrderService.updateById(bizSaleOrder);
                }

                //上传订单给erp
                //sendOrderForErp(bizOrder);
            }else{
                bizOrder.setOrderStatus("5");
            }
        }else{
            bizOrder.setOrderStatus("5");
        }
        bizOrder.setEndReason(bizOrderEditParam.getEndReason());
        this.updateById(bizOrder);
    }

    @Override
    public void rejectOrder(BizOrderEditParam bizOrderEditParam) {
        BizOrder bizOrder = this.queryEntity(bizOrderEditParam.getId());
        //设置客户驳回状态
        bizOrder.setOrderStatus("11");
        this.updateById(bizOrder);

        //插入审核记录
        BizAuditLog bizAuditLog = new BizAuditLog();
        bizAuditLog.setType("WLDD");
        bizAuditLog.setDataId(bizOrder.getId());
        bizAuditLog.setStatus("2");
        bizAuditLog.setRemark(bizOrderEditParam.getEndRemark());
        bizAuditLogService.save(bizAuditLog);
    }

    @Override
    public void sendConfirm(BizOrderEditParam bizOrderEditParam) {
        BizOrder bizOrder = this.queryEntity(bizOrderEditParam.getId());
        bizOrder.setOrderStatus("4");
        this.updateById(bizOrder);
    }

    public void sendOrderForErp(BizOrder bizOrder){
        String code = null;
        String msg = null;
        BigDecimal weight=new BigDecimal(0);
        try {
            String appId = "0ol2749zps9xhid1";
            String appSecret = "e4w9ylwk7grdsdzpbcq8kcedg7ailh1c";
            String nonce = "21459479202627653";
            long timestamp = System.currentTimeMillis() / 1000;
            String sign = getSign(appId, appSecret, nonce, timestamp + "");
            Map<String,String> map = new HashMap<>();
            map.put("appId",appId);
            map.put("appSecret",appSecret);
            map.put("nonce",nonce);
            map.put("timestamp",timestamp+"");
            map.put("signature",sign);


            //根据订单查询销售订单信息
            BizSaleOrder bizSaleOrder = bizSaleOrderService.queryEntity(bizOrder.getSaleOrderInfo());
            Map<String,Object> paramMap = Maps.newHashMap();
            paramMap.put("cCode",bizOrder.getId());
            BizUser bizUser = bizUserService.queryEntity(bizOrder.getCreateUser());
            paramMap.put("cMaker",bizUser.getName());
            JSONObject object = new JSONObject();
            object.put("iorderdid",bizSaleOrder.getRelationId());
            object.put("cInvCode",bizSaleOrder.getSaleGoodsCode());
            if(StringUtils.equals(bizOrder.getOrderType(),"1")){
                //包运订单
                weight = bizOrder.getShippingWeight();
                //object.put("iQuantity",bizOrder.getShippingWeight());
            }else{
                //自提订单
                weight = bizOrder.getNetWeight();
                //object.put("iQuantity",bizOrder.getNetWeight());
            }
            weight = weight.divide(new BigDecimal(1000),2,BigDecimal.ROUND_HALF_UP);
            object.put("iQuantity",weight);
            JSONArray array = new JSONArray();
            array.add(object);
            paramMap.put("details",array);

            String result = HttpUtil.createPost("https://1072el542wi61.vicp.fun/api/erp/u8data/savesalefh")
                    .addHeaders(map).body(JSONObject.toJSONString(paramMap)).execute().body();
            JSONObject jsonObject = JSONObject.parseObject(result);
            code = jsonObject.getString("code");
            msg = jsonObject.getString("msg");
        } catch (HttpException e) {
            //throw new RuntimeException(e);
            code = "1";
            msg = "erp网络异常！";
        }
        log.info("订单结束上传erp，code:"+code+",msg:"+msg+",重量："+weight);
        if(!StringUtils.equals(code,"0")){
            throw new CommonException(msg);
        }
    }

    public static String getSign(String appId,String appSecret,String nonce,String timestamp){
        StringBuffer buffer = new StringBuffer();
        buffer.append("appId=").append(appId).append("&");
        buffer.append("appSecret=").append(appSecret).append("&");
        buffer.append("nonce=").append(nonce).append("&");
        buffer.append("timestamp=").append(timestamp).append("&");
        String sign = MD5.md5(buffer.toString());
        return sign;
    }

    public void checkEndParam(BizOrder bizOrder){
        if(ObjectUtil.isNotNull(bizOrder)){
            //判断当前是否是包运订单 1：包运订单  2：自提订单
            if(StringUtils.equals(bizOrder.getOrderType(),"1")){
                //查询订单所有预约信息
                QueryWrapper<BizAppointmentRecord> queryWrapper = new QueryWrapper<>();
                queryWrapper.eq("bar.order_id",bizOrder.getId());
                queryWrapper.eq("bar.delete_flag","NOT_DELETE");
                queryWrapper.isNull("br.unload_weight");
                queryWrapper.notIn("bar.status","14","15");
                List<BizAppointmentRecord> recordList = bizAppointmentRecordMapper.getRecordList(queryWrapper);
                if(recordList.size()>0){
                    throw new CommonException("该订单下还有未完成回签的预约记录，不可以结束！");
                }

            }
        }
    }

    @Transactional
    @Override
    public void auditOrder(BizOrderEditParam bizOrderEditParam) {
        BizOrder bizOrder = this.queryEntity(bizOrderEditParam.getId());
        UpdateWrapper<BizOrder> updateWrapper = new UpdateWrapper<>();
        String status = null;
        if(ObjectUtil.isNotEmpty(bizOrderEditParam.getAuditFlag())){
            if(StringUtils.equals(bizOrderEditParam.getAuditFlag(),"true")){
                //驳回
                //bizOrder.setOrderStatus("4");
                status = "4";
            }else{
                status = "10";
                //bizOrder.setOrderStatus("7");

                //销售订单结束
                BizSaleOrder bizSaleOrder = bizSaleOrderService.getById(bizOrder.getSaleOrderInfo());
                if(ObjectUtil.isNotNull(bizSaleOrder)){
                    bizSaleOrder.setSaleStatus("3");
                    bizSaleOrderService.updateById(bizSaleOrder);
                }

                //上传订单给erp
                //sendOrderForErp(bizOrder);
            }
            updateWrapper.eq("id",bizOrder.getId()).
                    set("order_status",status).
                    set("order_reason",bizOrderEditParam.getOrderReason());
            //this.updateById(bizOrder);
            this.update(updateWrapper);
        }
    }

    @Override
    public void submit(BizOrderEditParam bizOrderEditParam) {
        BizOrder bizOrder = this.queryEntity(bizOrderEditParam.getId());
        bizOrder.setOrderStatus("1");
        this.updateById(bizOrder);
    }

    @Override
    public Page<BizOrder> getOrderTotal(BizOrderPageParam bizOrderPageParam) {
        QueryWrapper<BizOrder> queryWrapper = getTotalQueryWrapper(bizOrderPageParam);
        Page<BizOrder> orderTotal = this.getBaseMapper().getOrderTotal(CommonPageRequest.defaultPage(), queryWrapper);
        return orderTotal;
    }

    @Override
    public void exportRecordTotal(BizOrderPageParam bizOrderPageParam, HttpServletResponse response) throws IOException {
        QueryWrapper<BizOrder> queryWrapper = getTotalQueryWrapper(bizOrderPageParam);
        List<BizOrder> orderList = this.getBaseMapper().getOrderTotal(queryWrapper);
        String fileName = "订单计划统计.xlsx";
        List<BizOrderExportTotal> list = Lists.newArrayList();
        for(BizOrder bizOrder : orderList){
            BizOrderExportTotal bizOrderExportTotal = new BizOrderExportTotal();
            BeanUtil.copyProperties(bizOrder, bizOrderExportTotal);
            list.add(bizOrderExportTotal);
        }
        CommonExportUtil.export(fileName, BizOrderExportTotal.class,list,response,"订单计划统计");
    }

    @Override
    public BizOrder getDetailOrder(BizOrderPageParam bizOrderPageParam) {
        QueryWrapper<BizOrder> queryWrapper = new QueryWrapper<>();
        //订单id查询
        if(ObjectUtil.isNotEmpty(bizOrderPageParam.getOrderId())){
            queryWrapper.eq("bo.id",bizOrderPageParam.getOrderId());
        }
        // 供应商角色，查询是自己的
        if(StpLoginUserUtil.getLoginUser().getRoleCodeList().contains("supplier")){
            queryWrapper.eq("bos.supplier_id",StpLoginUserUtil.getLoginUser().getCustomerId());
        }else{
            if(ObjectUtil.isNotEmpty(bizOrderPageParam.getCreateUser())){
                BizUser bizUser = bizUserService.getById(bizOrderPageParam.getCreateUser());
                if(ObjectUtil.isNotNull(bizUser)){
                    queryWrapper.eq("bos.supplier_id",bizUser.getCustomerId());
                }
            }
        }
        BizOrder detailOrder = this.getBaseMapper().getDetailOrder(queryWrapper);
        return detailOrder;
    }

    public QueryWrapper<BizOrder> getTotalQueryWrapper(BizOrderPageParam bizOrderPageParam){
        QueryWrapper<BizOrder> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizOrderPageParam.getOrderName())){
            queryWrapper.like("bo.order_name",bizOrderPageParam.getOrderName());
        }
        if(ObjectUtil.isNotEmpty(bizOrderPageParam.getOrderNumber())){
            queryWrapper.like("bo.order_number",bizOrderPageParam.getOrderNumber());
        }
        if(ObjectUtil.isNotEmpty(bizOrderPageParam.getCustomerName())){
            queryWrapper.like("bc.name",bizOrderPageParam.getCustomerName());
        }
        queryWrapper.eq("bo.delete_flag","NOT_DELETE");
        //queryWrapper.orderByDesc("bo.create_time");
        return queryWrapper;
    }

    public static void main(String[] args) {
        String result = "";
        try {
            URL url = new URL("http://web.duanxinwang.cc/asmx/smsservice.aspx");
            StringBuilder params = new StringBuilder();
            params.append("name=").append("13375207977dxw");
            params.append("&pwd=").append("4AD0C7ED32CDD49C4CC2940B4095");
            params.append("&mobile=").append("15896183719");
            params.append("&content=").append("您的登陆密码为：14817030请尽快登录！");
            params.append("&sign=").append("淮安市保障房建设管理中心");
            params.append("&type=").append("pt");
            URLConnection connection = url.openConnection();
            connection.setDoOutput(true);
            OutputStreamWriter out = new OutputStreamWriter(connection.getOutputStream(), "utf-8");
            out.write(params.toString()); //post的关键所在！
            out.flush();
            out.close();
            String temp = "";
            InputStream is = connection.getInputStream();
            BufferedReader br = new BufferedReader(new InputStreamReader(is));

            while (( temp = br.readLine()) != null) {
                result += temp;
            }
        } catch (Exception e) {
            // TODO: handle exception
        }
        System.out.printf("result:"+result);
    }
}
