/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizorderload.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.bizorderload.entity.BizOrderLoad;
import vip.xiaonuo.biz.modular.bizorderload.param.BizOrderLoadAddParam;
import vip.xiaonuo.biz.modular.bizorderload.param.BizOrderLoadEditParam;
import vip.xiaonuo.biz.modular.bizorderload.param.BizOrderLoadIdParam;
import vip.xiaonuo.biz.modular.bizorderload.param.BizOrderLoadPageParam;
import vip.xiaonuo.biz.modular.bizorderload.service.BizOrderLoadService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 订单装卸点位控制器
 *
 * @author fanzherong
 * @date  2025/05/30 14:05
 */
@Tag(name = "订单装卸点位控制器")
@RestController
@Validated
public class BizOrderLoadController {

    @Resource
    private BizOrderLoadService bizOrderLoadService;

    /**
     * 获取订单装卸点位分页
     *
     * @author fanzherong
     * @date  2025/05/30 14:05
     */
    @Operation(summary = "获取订单装卸点位分页")
    @SaCheckPermission("/biz/bizorderload/page")
    @GetMapping("/biz/bizorderload/page")
    public CommonResult<Page<BizOrderLoad>> page(BizOrderLoadPageParam bizOrderLoadPageParam) {
        return CommonResult.data(bizOrderLoadService.page(bizOrderLoadPageParam));
    }

    /**
     * 添加订单装卸点位
     *
     * @author fanzherong
     * @date  2025/05/30 14:05
     */
    @Operation(summary = "添加订单装卸点位")
    @CommonLog("添加订单装卸点位")
    @PostMapping("/biz/bizorderload/add")
    public CommonResult<String> add(@RequestBody @Valid BizOrderLoadAddParam bizOrderLoadAddParam) {
        bizOrderLoadService.add(bizOrderLoadAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑订单装卸点位
     *
     * @author fanzherong
     * @date  2025/05/30 14:05
     */
    @Operation(summary = "编辑订单装卸点位")
    @CommonLog("编辑订单装卸点位")
    @PostMapping("/biz/bizorderload/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizOrderLoadEditParam bizOrderLoadEditParam) {
        bizOrderLoadService.edit(bizOrderLoadEditParam);
        return CommonResult.ok();
    }

    /**
     * 更换装卸点位
     *
     * @author fanzherong
     * @date  2025/05/30 14:05
     */
    @Operation(summary = "更换装卸点位")
    @CommonLog("更换装卸点位")
    @PostMapping("/biz/bizorderload/replace")
    public CommonResult<String> replace(@RequestBody @Valid BizOrderLoadEditParam bizOrderLoadEditParam) {
        bizOrderLoadService.replace(bizOrderLoadEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除订单装卸点位
     *
     * @author fanzherong
     * @date  2025/05/30 14:05
     */
    @Operation(summary = "删除订单装卸点位")
    @CommonLog("删除订单装卸点位")
    @PostMapping("/biz/bizorderload/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizOrderLoadIdParam> bizOrderLoadIdParamList) {
        bizOrderLoadService.delete(bizOrderLoadIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取订单装卸点位详情
     *
     * @author fanzherong
     * @date  2025/05/30 14:05
     */
    @Operation(summary = "获取订单装卸点位详情")
    @GetMapping("/biz/bizorderload/detail")
    public CommonResult<BizOrderLoad> detail(@Valid BizOrderLoadIdParam bizOrderLoadIdParam) {
        return CommonResult.data(bizOrderLoadService.detail(bizOrderLoadIdParam));
    }


    /**
     * 获取订单装卸时间列表
     *
     * @author fanzherong
     * @date  2025/05/30 14:05
     */
    @Operation(summary = "获取订单装卸时间列表")
    @GetMapping("/biz/bizorderload/getLoadTimeList")
    public CommonResult<List<BizOrderLoad>> getLoadTimeList(BizOrderLoadPageParam bizOrderLoadPageParam) {
        return CommonResult.data(bizOrderLoadService.getLoadTimeList(bizOrderLoadPageParam));
    }

    /**
     * 获取订单装卸点位列表
     *
     * @author fanzherong
     * @date  2025/05/30 14:05
     */
    @Operation(summary = "获取订单装卸点位列表")
    @GetMapping("/biz/bizorderload/getPointList")
    public CommonResult<List<BizOrderLoad>> getPointList(BizOrderLoadPageParam bizOrderLoadPageParam) {
        return CommonResult.data(bizOrderLoadService.getPointList(bizOrderLoadPageParam));
    }
}
