/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizordersupplier.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.bizordersupplier.entity.BizOrderSupplier;
import vip.xiaonuo.biz.modular.bizordersupplier.param.BizOrderSupplierAddParam;
import vip.xiaonuo.biz.modular.bizordersupplier.param.BizOrderSupplierEditParam;
import vip.xiaonuo.biz.modular.bizordersupplier.param.BizOrderSupplierIdParam;
import vip.xiaonuo.biz.modular.bizordersupplier.param.BizOrderSupplierPageParam;
import vip.xiaonuo.biz.modular.bizordersupplier.service.BizOrderSupplierService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 订单供应商控制器
 *
 * @author fanzherong
 * @date  2025/06/20 11:43
 */
@Tag(name = "订单供应商控制器")
@RestController
@Validated
public class BizOrderSupplierController {

    @Resource
    private BizOrderSupplierService bizOrderSupplierService;

    /**
     * 获取订单供应商分页
     *
     * @author fanzherong
     * @date  2025/06/20 11:43
     */
    @Operation(summary = "获取订单供应商分页")
    @SaCheckPermission("/biz/bizordersupplier/page")
    @GetMapping("/biz/bizordersupplier/page")
    public CommonResult<Page<BizOrderSupplier>> page(BizOrderSupplierPageParam bizOrderSupplierPageParam) {
        return CommonResult.data(bizOrderSupplierService.page(bizOrderSupplierPageParam));
    }

    /**
     * 添加订单供应商
     *
     * @author fanzherong
     * @date  2025/06/20 11:43
     */
    @Operation(summary = "添加订单供应商")
    @CommonLog("添加订单供应商")
    @PostMapping("/biz/bizordersupplier/add")
    public CommonResult<String> add(@RequestBody @Valid BizOrderSupplierAddParam bizOrderSupplierAddParam) {
        bizOrderSupplierService.add(bizOrderSupplierAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑订单供应商
     *
     * @author fanzherong
     * @date  2025/06/20 11:43
     */
    @Operation(summary = "编辑订单供应商")
    @CommonLog("编辑订单供应商")
    @PostMapping("/biz/bizordersupplier/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizOrderSupplierEditParam bizOrderSupplierEditParam) {
        bizOrderSupplierService.edit(bizOrderSupplierEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除订单供应商
     *
     * @author fanzherong
     * @date  2025/06/20 11:43
     */
    @Operation(summary = "删除订单供应商")
    @CommonLog("删除订单供应商")
    @PostMapping("/biz/bizordersupplier/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizOrderSupplierIdParam> bizOrderSupplierIdParamList) {
        bizOrderSupplierService.delete(bizOrderSupplierIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取订单供应商详情
     *
     * @author fanzherong
     * @date  2025/06/20 11:43
     */
    @Operation(summary = "获取订单供应商详情")
    @GetMapping("/biz/bizordersupplier/detail")
    public CommonResult<BizOrderSupplier> detail(@Valid BizOrderSupplierIdParam bizOrderSupplierIdParam) {
        return CommonResult.data(bizOrderSupplierService.detail(bizOrderSupplierIdParam));
    }

    /**
     * 获取订单供应商列表
     *
     * @author fanzherong
     * @date  2025/06/20 11:43
     */
    @Operation(summary = "获取订单供应商列表")
    @GetMapping("/biz/bizordersupplier/getSupplierList")
    public CommonResult<List<BizOrderSupplier>> getSupplierList(BizOrderSupplierPageParam bizOrderSupplierPageParam) {
        return CommonResult.data(bizOrderSupplierService.getSupplierList(bizOrderSupplierPageParam));
    }

    /**
     * 获取供应商在执行订单
     *
     * @author fanzherong
     * @date  2025/06/20 11:43
     */
    @Operation(summary = "获取供应商在执行订单")
    @GetMapping("/biz/bizordersupplier/getListBySupplier")
    public CommonResult<List<BizOrderSupplier>> getListBySupplier(BizOrderSupplierPageParam bizOrderSupplierPageParam) {
        return CommonResult.data(bizOrderSupplierService.getListBySupplier(bizOrderSupplierPageParam));
    }
}
