/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizordersupplier.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import jakarta.annotation.Resource;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.biz.modular.bizsupplier.entity.BizSupplierTransport;
import vip.xiaonuo.biz.modular.bizsupplier.service.BizSupplierTransportService;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizordersupplier.entity.BizOrderSupplier;
import vip.xiaonuo.biz.modular.bizordersupplier.mapper.BizOrderSupplierMapper;
import vip.xiaonuo.biz.modular.bizordersupplier.param.BizOrderSupplierAddParam;
import vip.xiaonuo.biz.modular.bizordersupplier.param.BizOrderSupplierEditParam;
import vip.xiaonuo.biz.modular.bizordersupplier.param.BizOrderSupplierIdParam;
import vip.xiaonuo.biz.modular.bizordersupplier.param.BizOrderSupplierPageParam;
import vip.xiaonuo.biz.modular.bizordersupplier.service.BizOrderSupplierService;

import java.util.List;

/**
 * 订单供应商Service接口实现类
 *
 * @author fanzherong
 * @date  2025/06/20 11:43
 **/
@Service
public class BizOrderSupplierServiceImpl extends ServiceImpl<BizOrderSupplierMapper, BizOrderSupplier> implements BizOrderSupplierService {

    @Resource
    private BizSupplierTransportService bizSupplierTransportService;

    @Override
    public Page<BizOrderSupplier> page(BizOrderSupplierPageParam bizOrderSupplierPageParam) {
        QueryWrapper<BizOrderSupplier> queryWrapper = new QueryWrapper<BizOrderSupplier>().checkSqlInjection();
        if(ObjectUtil.isAllNotEmpty(bizOrderSupplierPageParam.getSortField(), bizOrderSupplierPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizOrderSupplierPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizOrderSupplierPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizOrderSupplierPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizOrderSupplier::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizOrderSupplierAddParam bizOrderSupplierAddParam) {
        BizOrderSupplier bizOrderSupplier = BeanUtil.toBean(bizOrderSupplierAddParam, BizOrderSupplier.class);
        this.save(bizOrderSupplier);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizOrderSupplierEditParam bizOrderSupplierEditParam) {
        BizOrderSupplier bizOrderSupplier = this.queryEntity(bizOrderSupplierEditParam.getId());
        BeanUtil.copyProperties(bizOrderSupplierEditParam, bizOrderSupplier);
        this.updateById(bizOrderSupplier);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizOrderSupplierIdParam> bizOrderSupplierIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizOrderSupplierIdParamList, BizOrderSupplierIdParam::getId));
    }

    @Override
    public BizOrderSupplier detail(BizOrderSupplierIdParam bizOrderSupplierIdParam) {
        return this.queryEntity(bizOrderSupplierIdParam.getId());
    }

    @Override
    public BizOrderSupplier queryEntity(String id) {
        BizOrderSupplier bizOrderSupplier = this.getById(id);
        if(ObjectUtil.isEmpty(bizOrderSupplier)) {
            throw new CommonException("订单供应商不存在，id值为：{}", id);
        }
        return bizOrderSupplier;
    }

    @Override
    public List<BizOrderSupplier> getSupplierList(BizOrderSupplierPageParam bizOrderSupplierPageParam) {
        QueryWrapper<BizOrderSupplier> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizOrderSupplierPageParam.getOrderId())){
            queryWrapper.eq("bos.order_id",bizOrderSupplierPageParam.getOrderId());
        }
        queryWrapper.eq("bos.delete_flag","NOT_DELETE");
        List<BizOrderSupplier> list = this.getBaseMapper().getSupplierList(queryWrapper);
        return list;
    }

    @Override
    public List<BizOrderSupplier> getListBySupplier(BizOrderSupplierPageParam bizOrderSupplierPageParam) {
        //根据车牌号查询所属供应商
        BizSupplierTransport transport = bizSupplierTransportService.getOne(new QueryWrapper<BizSupplierTransport>().lambda().
                eq(BizSupplierTransport::getTransportNo, bizOrderSupplierPageParam.getLicenseNumber()).
                last("limit 1"));
        if(ObjectUtil.isNotNull(transport)){
            //根据供应商查询正在执行中的订单
            QueryWrapper<BizOrderSupplier> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("bos.supplier_id",transport.getSupplierId()).
                    eq("bo.delete_flag","NOT_DELETE").
                    eq("bos.delete_flag","NOT_DELETE").
                    in("bo.order_status","3","4");
            List<BizOrderSupplier> orderList = this.getBaseMapper().getOrderList(queryWrapper);
            return orderList;
        }
        return null;
    }
}
