/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizparkconfig.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.biz.modular.bizloadpoint.entity.BizLoadPoint;
import vip.xiaonuo.biz.modular.bizloadpoint.param.BizLoadPointPageParam;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.bizparkconfig.entity.BizParkConfig;
import vip.xiaonuo.biz.modular.bizparkconfig.param.BizParkConfigAddParam;
import vip.xiaonuo.biz.modular.bizparkconfig.param.BizParkConfigEditParam;
import vip.xiaonuo.biz.modular.bizparkconfig.param.BizParkConfigIdParam;
import vip.xiaonuo.biz.modular.bizparkconfig.param.BizParkConfigPageParam;
import vip.xiaonuo.biz.modular.bizparkconfig.service.BizParkConfigService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 停车费配置控制器
 *
 * @author fanzherong
 * @date  2025/05/29 15:14
 */
@Tag(name = "停车费配置控制器")
@RestController
@Validated
public class BizParkConfigController {

    @Resource
    private BizParkConfigService bizParkConfigService;

    /**
     * 获取停车费配置分页
     *
     * @author fanzherong
     * @date  2025/05/29 15:14
     */
    @Operation(summary = "获取停车费配置分页")
    @GetMapping("/biz/bizparkconfig/page")
    public CommonResult<Page<BizParkConfig>> page(BizParkConfigPageParam bizParkConfigPageParam) {
        return CommonResult.data(bizParkConfigService.page(bizParkConfigPageParam));
    }

    /**
     * 添加停车费配置
     *
     * @author fanzherong
     * @date  2025/05/29 15:14
     */
    @Operation(summary = "添加停车费配置")
    @CommonLog("添加停车费配置")
    @SaCheckPermission("/biz/bizparkconfig/add")
    @PostMapping("/biz/bizparkconfig/add")
    public CommonResult<String> add(@RequestBody @Valid BizParkConfigAddParam bizParkConfigAddParam) {
        bizParkConfigService.add(bizParkConfigAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑停车费配置
     *
     * @author fanzherong
     * @date  2025/05/29 15:14
     */
    @Operation(summary = "编辑停车费配置")
    @CommonLog("编辑停车费配置")
    @SaCheckPermission("/biz/bizparkconfig/edit")
    @PostMapping("/biz/bizparkconfig/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizParkConfigEditParam bizParkConfigEditParam) {
        bizParkConfigService.edit(bizParkConfigEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除停车费配置
     *
     * @author fanzherong
     * @date  2025/05/29 15:14
     */
    @Operation(summary = "删除停车费配置")
    @CommonLog("删除停车费配置")
    @SaCheckPermission("/biz/bizparkconfig/delete")
    @PostMapping("/biz/bizparkconfig/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizParkConfigIdParam> bizParkConfigIdParamList) {
        bizParkConfigService.delete(bizParkConfigIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取停车费配置详情
     *
     * @author fanzherong
     * @date  2025/05/29 15:14
     */
    @Operation(summary = "获取停车费配置详情")
    @GetMapping("/biz/bizparkconfig/detail")
    public CommonResult<BizParkConfig> detail(@Valid BizParkConfigIdParam bizParkConfigIdParam) {
        return CommonResult.data(bizParkConfigService.detail(bizParkConfigIdParam));
    }

    /**
     * 获取停车费配置列表
     *
     * @author sandy
     * @date  2025/06/03 15:11
     */
    @Operation(summary = "获取停车费配置列表")
    @GetMapping("/biz/bizparkconfig/getList")
    public CommonResult<List<BizParkConfig>> getList(BizParkConfigPageParam bizParkConfigPageParam) {
        return CommonResult.data(bizParkConfigService.getList(bizParkConfigPageParam));
    }
}
