/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizparkconfig.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.biz.modular.bizloadpoint.entity.BizLoadPoint;
import vip.xiaonuo.biz.modular.bizloadpoint.param.BizLoadPointPageParam;
import vip.xiaonuo.biz.modular.bizparkconfig.enums.BizParkConfigEnum;
import vip.xiaonuo.biz.modular.bizprocess.entity.BizProcess;
import vip.xiaonuo.biz.modular.bizprocess.enums.BizProcessEnum;
import vip.xiaonuo.biz.modular.bizsupplier.entity.BizSupplier;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizparkconfig.entity.BizParkConfig;
import vip.xiaonuo.biz.modular.bizparkconfig.mapper.BizParkConfigMapper;
import vip.xiaonuo.biz.modular.bizparkconfig.param.BizParkConfigAddParam;
import vip.xiaonuo.biz.modular.bizparkconfig.param.BizParkConfigEditParam;
import vip.xiaonuo.biz.modular.bizparkconfig.param.BizParkConfigIdParam;
import vip.xiaonuo.biz.modular.bizparkconfig.param.BizParkConfigPageParam;
import vip.xiaonuo.biz.modular.bizparkconfig.service.BizParkConfigService;

import java.util.List;

/**
 * 停车费配置Service接口实现类
 *
 * @author fanzherong
 * @date  2025/05/29 15:14
 **/
@Service
public class BizParkConfigServiceImpl extends ServiceImpl<BizParkConfigMapper, BizParkConfig> implements BizParkConfigService {

    @Override
    public Page<BizParkConfig> page(BizParkConfigPageParam bizParkConfigPageParam) {
        QueryWrapper<BizParkConfig> queryWrapper = new QueryWrapper<BizParkConfig>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizParkConfigPageParam.getAppointmentType())) {
            queryWrapper.lambda().eq(BizParkConfig::getAppointmentType, bizParkConfigPageParam.getAppointmentType());
        }
        queryWrapper.lambda().eq(BizParkConfig::getDeleteFlag, "NOT_DELETE");
        if(ObjectUtil.isAllNotEmpty(bizParkConfigPageParam.getSortField(), bizParkConfigPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizParkConfigPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizParkConfigPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizParkConfigPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(BizParkConfig::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizParkConfigAddParam bizParkConfigAddParam) {
        //查询是否添加过
        long count = this.count(new QueryWrapper<BizParkConfig>().lambda().eq(BizParkConfig::getAppointmentType, bizParkConfigAddParam.getAppointmentType())
                                                                    .eq(BizParkConfig::getDeleteFlag, BizParkConfigEnum.NOT_DELETE.getValue()));
        if(count>0){
            throw new CommonException("预约类型的停车费配置已存在！");
        }
        BizParkConfig bizParkConfig = BeanUtil.toBean(bizParkConfigAddParam, BizParkConfig.class);
        this.save(bizParkConfig);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizParkConfigEditParam bizParkConfigEditParam) {
        //查询是否添加过
        long count = this.count(new QueryWrapper<BizParkConfig>().lambda().eq(BizParkConfig::getAppointmentType, bizParkConfigEditParam.getAppointmentType())
                                                                        .ne(BizParkConfig::getId, bizParkConfigEditParam.getId())
                                                                        .eq(BizParkConfig::getDeleteFlag, BizParkConfigEnum.NOT_DELETE.getValue()));
        if(count>0){
            throw new CommonException("预约类型的停车费配置已存在！");
        }
        BizParkConfig bizParkConfig = this.queryEntity(bizParkConfigEditParam.getId());
        BeanUtil.copyProperties(bizParkConfigEditParam, bizParkConfig);
        this.updateById(bizParkConfig);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizParkConfigIdParam> bizParkConfigIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizParkConfigIdParamList, BizParkConfigIdParam::getId));
    }

    @Override
    public BizParkConfig detail(BizParkConfigIdParam bizParkConfigIdParam) {
        return this.queryEntity(bizParkConfigIdParam.getId());
    }

    @Override
    public BizParkConfig queryEntity(String id) {
        BizParkConfig bizParkConfig = this.getById(id);
        if(ObjectUtil.isEmpty(bizParkConfig)) {
            throw new CommonException("停车费配置不存在，id值为：{}", id);
        }
        return bizParkConfig;
    }

    @Override
    public List<BizParkConfig> getList(BizParkConfigPageParam bizParkConfigPageParam) {
        QueryWrapper<BizParkConfig> queryWrapper = new QueryWrapper<BizParkConfig>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizParkConfigPageParam.getAppointmentType())) {
            queryWrapper.lambda().like(BizParkConfig::getAppointmentType, bizParkConfigPageParam.getAppointmentType());
        }
        queryWrapper.lambda().eq(BizParkConfig::getDeleteFlag, "NOT_DELETE");
        queryWrapper.lambda().orderByAsc(BizParkConfig::getId);
        return this.list(queryWrapper);
    }
}
