/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizpipeappoint.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.bizpipeappoint.entity.BizPipeAppoint;
import vip.xiaonuo.biz.modular.bizpipeappoint.param.BizPipeAppointAddParam;
import vip.xiaonuo.biz.modular.bizpipeappoint.param.BizPipeAppointEditParam;
import vip.xiaonuo.biz.modular.bizpipeappoint.param.BizPipeAppointIdParam;
import vip.xiaonuo.biz.modular.bizpipeappoint.param.BizPipeAppointPageParam;
import vip.xiaonuo.biz.modular.bizpipeappoint.service.BizPipeAppointService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 管桩预约控制器
 *
 * @author fanzherong
 * @date  2025/06/30 15:49
 */
@Tag(name = "管桩预约控制器")
@RestController
@Validated
public class BizPipeAppointController {

    @Resource
    private BizPipeAppointService bizPipeAppointService;

    /**
     * 获取管桩预约分页
     *
     * @author fanzherong
     * @date  2025/06/30 15:49
     */
    @Operation(summary = "获取管桩预约分页")
    @SaCheckPermission("/biz/bizpipeappoint/page")
    @GetMapping("/biz/bizpipeappoint/page")
    public CommonResult<Page<BizPipeAppoint>> page(BizPipeAppointPageParam bizPipeAppointPageParam) {
        return CommonResult.data(bizPipeAppointService.page(bizPipeAppointPageParam));
    }

    /**
     * 添加管桩预约
     *
     * @author fanzherong
     * @date  2025/06/30 15:49
     */
    @Operation(summary = "添加管桩预约")
    @CommonLog("添加管桩预约")
    @PostMapping("/biz/bizpipeappoint/add")
    public CommonResult<String> add(@RequestBody @Valid BizPipeAppointAddParam bizPipeAppointAddParam) {
        bizPipeAppointService.add(bizPipeAppointAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑管桩预约
     *
     * @author fanzherong
     * @date  2025/06/30 15:49
     */
    @Operation(summary = "编辑管桩预约")
    @CommonLog("编辑管桩预约")
    @PostMapping("/biz/bizpipeappoint/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizPipeAppointEditParam bizPipeAppointEditParam) {
        bizPipeAppointService.edit(bizPipeAppointEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除管桩预约
     *
     * @author fanzherong
     * @date  2025/06/30 15:49
     */
    @Operation(summary = "删除管桩预约")
    @CommonLog("删除管桩预约")
    @PostMapping("/biz/bizpipeappoint/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizPipeAppointIdParam> bizPipeAppointIdParamList) {
        bizPipeAppointService.delete(bizPipeAppointIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取管桩预约详情
     *
     * @author fanzherong
     * @date  2025/06/30 15:49
     */
    @Operation(summary = "获取管桩预约详情")
    @GetMapping("/biz/bizpipeappoint/detail")
    public CommonResult<BizPipeAppoint> detail(@Valid BizPipeAppointIdParam bizPipeAppointIdParam) {
        return CommonResult.data(bizPipeAppointService.detail(bizPipeAppointIdParam));
    }
}
