/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizpipeplan.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.bizpipeplan.entity.BizPipePlan;
import vip.xiaonuo.biz.modular.bizpipeplan.param.BizPipePlanAddParam;
import vip.xiaonuo.biz.modular.bizpipeplan.param.BizPipePlanEditParam;
import vip.xiaonuo.biz.modular.bizpipeplan.param.BizPipePlanIdParam;
import vip.xiaonuo.biz.modular.bizpipeplan.param.BizPipePlanPageParam;
import vip.xiaonuo.biz.modular.bizpipeplan.service.BizPipePlanService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 管桩计划控制器
 *
 * @author fanzherong
 * @date  2025/06/30 10:32
 */
@Tag(name = "管桩计划控制器")
@RestController
@Validated
public class BizPipePlanController {

    @Resource
    private BizPipePlanService bizPipePlanService;

    /**
     * 获取管桩计划分页
     *
     * @author fanzherong
     * @date  2025/06/30 10:32
     */
    @Operation(summary = "获取管桩计划分页")
    @SaCheckPermission("/biz/bizpipeplan/page")
    @GetMapping("/biz/bizpipeplan/page")
    public CommonResult<Page<BizPipePlan>> page(BizPipePlanPageParam bizPipePlanPageParam) {
        return CommonResult.data(bizPipePlanService.page(bizPipePlanPageParam));
    }

    /**
     * 添加管桩计划
     *
     * @author fanzherong
     * @date  2025/06/30 10:32
     */
    @Operation(summary = "添加管桩计划")
    @CommonLog("添加管桩计划")
    @PostMapping("/biz/bizpipeplan/add")
    public CommonResult<String> add(@RequestBody @Valid BizPipePlanAddParam bizPipePlanAddParam) {
        bizPipePlanService.add(bizPipePlanAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑管桩计划
     *
     * @author fanzherong
     * @date  2025/06/30 10:32
     */
    @Operation(summary = "编辑管桩计划")
    @CommonLog("编辑管桩计划")
    @PostMapping("/biz/bizpipeplan/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizPipePlanEditParam bizPipePlanEditParam) {
        bizPipePlanService.edit(bizPipePlanEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除管桩计划
     *
     * @author fanzherong
     * @date  2025/06/30 10:32
     */
    @Operation(summary = "删除管桩计划")
    @CommonLog("删除管桩计划")
    @PostMapping("/biz/bizpipeplan/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizPipePlanIdParam> bizPipePlanIdParamList) {
        bizPipePlanService.delete(bizPipePlanIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取管桩计划详情
     *
     * @author fanzherong
     * @date  2025/06/30 10:32
     */
    @Operation(summary = "获取管桩计划详情")
    @GetMapping("/biz/bizpipeplan/detail")
    public CommonResult<BizPipePlan> detail(@Valid BizPipePlanIdParam bizPipePlanIdParam) {
        return CommonResult.data(bizPipePlanService.detail(bizPipePlanIdParam));
    }

    /**
     * 结束管桩计划
     *
     * @author fanzherong
     * @date  2025/06/30 10:32
     */
    @Operation(summary = "结束管桩计划")
    @CommonLog("结束管桩计划")
    @PostMapping("/biz/bizpipeplan/endPlan")
    public CommonResult<String> endPlan(@RequestBody @Valid BizPipePlanEditParam bizPipePlanEditParam) {
        bizPipePlanService.endPlan(bizPipePlanEditParam);
        return CommonResult.ok();
    }

    /**
     * 获取管桩计划列表
     *
     * @author fanzherong
     * @date  2025/06/30 10:32
     */
    @Operation(summary = "获取管桩计划列表")
    @GetMapping("/biz/bizpipeplan/getList")
    public CommonResult<List<BizPipePlan>> getList() {
        return CommonResult.data(bizPipePlanService.getList());
    }
}
