/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizpipeplan.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.biz.modular.bizloadappoint.entity.BizLoadAppoint;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizpipeplan.entity.BizPipePlan;
import vip.xiaonuo.biz.modular.bizpipeplan.mapper.BizPipePlanMapper;
import vip.xiaonuo.biz.modular.bizpipeplan.param.BizPipePlanAddParam;
import vip.xiaonuo.biz.modular.bizpipeplan.param.BizPipePlanEditParam;
import vip.xiaonuo.biz.modular.bizpipeplan.param.BizPipePlanIdParam;
import vip.xiaonuo.biz.modular.bizpipeplan.param.BizPipePlanPageParam;
import vip.xiaonuo.biz.modular.bizpipeplan.service.BizPipePlanService;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.concurrent.locks.ReentrantLock;

/**
 * 管桩计划Service接口实现类
 *
 * @author fanzherong
 * @date  2025/06/30 10:32
 **/
@Service
public class BizPipePlanServiceImpl extends ServiceImpl<BizPipePlanMapper, BizPipePlan> implements BizPipePlanService {

    private final ReentrantLock lock = new ReentrantLock();

    @Override
    public Page<BizPipePlan> page(BizPipePlanPageParam bizPipePlanPageParam) {
        QueryWrapper<BizPipePlan> queryWrapper = new QueryWrapper<BizPipePlan>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizPipePlanPageParam.getPlanNumber())){
            //计划编号
            queryWrapper.lambda().like(BizPipePlan::getPlanNumber,bizPipePlanPageParam.getPlanNumber());
        }
        if(ObjectUtil.isNotEmpty(bizPipePlanPageParam.getPlanName())){
            //计划名称
            queryWrapper.lambda().like(BizPipePlan::getPlanName,bizPipePlanPageParam.getPlanName());
        }
        queryWrapper.lambda().orderByDesc(BizPipePlan::getBeginTime);
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizPipePlanAddParam bizPipePlanAddParam) {
        bizPipePlanAddParam.setBeginTime(DateUtil.parse(bizPipePlanAddParam.getPlanDate()+" "+bizPipePlanAddParam.getStartDate()+":00"));
        bizPipePlanAddParam.setEndTime(DateUtil.parse(bizPipePlanAddParam.getPlanDate()+" " +bizPipePlanAddParam.getEndDate() + ":00"));
        checkParam(bizPipePlanAddParam);
        BizPipePlan bizPipePlan = BeanUtil.toBean(bizPipePlanAddParam, BizPipePlan.class);
        bizPipePlan.setPlanNumber(getNumber());
        this.save(bizPipePlan);
    }

    public void checkParam(BizPipePlanAddParam bizPipePlanAddParam){
        long count = this.count(new QueryWrapper<BizPipePlan>().lambda().
                le(BizPipePlan::getBeginTime, bizPipePlanAddParam.getEndTime()).
                ge(BizPipePlan::getEndTime, bizPipePlanAddParam.getBeginTime()));
        if(count>0){
            throw new CommonException("当前时间段存在交集！");
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizPipePlanEditParam bizPipePlanEditParam) {
        bizPipePlanEditParam.setBeginTime(DateUtil.parse(bizPipePlanEditParam.getPlanDate()+" "+bizPipePlanEditParam.getStartDate()+":00"));
        bizPipePlanEditParam.setEndTime(DateUtil.parse(bizPipePlanEditParam.getPlanDate()+" " +bizPipePlanEditParam.getEndDate() + ":00"));
        BizPipePlan bizPipePlan = this.queryEntity(bizPipePlanEditParam.getId());
        checkParam(bizPipePlanEditParam,bizPipePlan);
        BeanUtil.copyProperties(bizPipePlanEditParam, bizPipePlan);
        this.updateById(bizPipePlan);
    }

    public void checkParam(BizPipePlanEditParam bizPipePlanEditParam,BizPipePlan bizPipePlan){
        if(bizPipePlan.getBeginTime().getTime()!=bizPipePlanEditParam.getBeginTime().getTime() ||
                bizPipePlan.getEndTime().getTime()!=bizPipePlanEditParam.getEndTime().getTime()){
            long count = this.count(new QueryWrapper<BizPipePlan>().lambda().
                    le(BizPipePlan::getBeginTime, bizPipePlanEditParam.getEndTime()).
                    ge(BizPipePlan::getEndTime, bizPipePlanEditParam.getBeginTime()).
                    ne(BizPipePlan::getId,bizPipePlan.getId()));
            if(count>0){
                throw new CommonException("当前时间段存在交集！");
            }
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizPipePlanIdParam> bizPipePlanIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizPipePlanIdParamList, BizPipePlanIdParam::getId));
    }

    @Override
    public BizPipePlan detail(BizPipePlanIdParam bizPipePlanIdParam) {
        return this.queryEntity(bizPipePlanIdParam.getId());
    }

    @Override
    public BizPipePlan queryEntity(String id) {
        BizPipePlan bizPipePlan = this.getById(id);
        if(ObjectUtil.isEmpty(bizPipePlan)) {
            throw new CommonException("管桩计划不存在，id值为：{}", id);
        }
        return bizPipePlan;
    }

    @Override
    public void endPlan(BizPipePlanEditParam bizPipePlanEditParam) {
        BizPipePlan bizPipePlan = this.queryEntity(bizPipePlanEditParam.getId());
        bizPipePlan.setStatus("3");
        this.updateById(bizPipePlan);
    }

    @Override
    public List<BizPipePlan> getList() {
        List<BizPipePlan> list = this.list(new QueryWrapper<BizPipePlan>().lambda().
                in(BizPipePlan::getStatus, "1", "2"));
        return list;
    }

    public String getNumber(){
        lock.lock();
        try{
            String format = new SimpleDateFormat("yyyyMMdd").format(new Date());
            String time = new SimpleDateFormat("yyyy-MM-dd").format(new Date());
            long count = this.count(new QueryWrapper<BizPipePlan>().lambda().between(BizPipePlan::getCreateTime, time + " 00:00:00", time + " 23:59:59"));
            String settleNo = "GZ" + format + generateCode((int)count);
            return settleNo;
        }finally {
            lock.unlock(); // 释放锁
        }
    }

    public static String generateCode(Integer counter) {
        counter++;
        return String.format("%03d", counter);
    }
}
