/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizprocess.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.biz.modular.bizparkconfig.entity.BizParkConfig;
import vip.xiaonuo.biz.modular.bizparkconfig.param.BizParkConfigPageParam;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.bizprocess.entity.BizProcess;
import vip.xiaonuo.biz.modular.bizprocess.param.BizProcessAddParam;
import vip.xiaonuo.biz.modular.bizprocess.param.BizProcessEditParam;
import vip.xiaonuo.biz.modular.bizprocess.param.BizProcessIdParam;
import vip.xiaonuo.biz.modular.bizprocess.param.BizProcessPageParam;
import vip.xiaonuo.biz.modular.bizprocess.service.BizProcessService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 生产工序控制器
 *
 * @author fanzherong
 * @date  2025/05/29 15:09
 */
@Tag(name = "生产工序控制器")
@RestController
@Validated
public class BizProcessController {

    @Resource
    private BizProcessService bizProcessService;

    /**
     * 获取生产工序分页
     *
     * @author fanzherong
     * @date  2025/05/29 15:09
     */
    @Operation(summary = "获取生产工序分页")
    @SaCheckPermission("/biz/bizprocess/page")
    @GetMapping("/biz/bizprocess/page")
    public CommonResult<Page<BizProcess>> page(BizProcessPageParam bizProcessPageParam) {
        return CommonResult.data(bizProcessService.page(bizProcessPageParam));
    }

    /**
     * 添加生产工序
     *
     * @author fanzherong
     * @date  2025/05/29 15:09
     */
    @Operation(summary = "添加生产工序")
    @CommonLog("添加生产工序")
    @PostMapping("/biz/bizprocess/add")
    public CommonResult<String> add(@RequestBody @Valid BizProcessAddParam bizProcessAddParam) {
        bizProcessService.add(bizProcessAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑生产工序
     *
     * @author fanzherong
     * @date  2025/05/29 15:09
     */
    @Operation(summary = "编辑生产工序")
    @CommonLog("编辑生产工序")
    @PostMapping("/biz/bizprocess/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizProcessEditParam bizProcessEditParam) {
        bizProcessService.edit(bizProcessEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除生产工序
     *
     * @author fanzherong
     * @date  2025/05/29 15:09
     */
    @Operation(summary = "删除生产工序")
    @CommonLog("删除生产工序")
    @PostMapping("/biz/bizprocess/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizProcessIdParam> bizProcessIdParamList) {
        bizProcessService.delete(bizProcessIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取生产工序详情
     *
     * @author fanzherong
     * @date  2025/05/29 15:09
     */
    @Operation(summary = "获取生产工序详情")
    @GetMapping("/biz/bizprocess/detail")
    public CommonResult<BizProcess> detail(@Valid BizProcessIdParam bizProcessIdParam) {
        return CommonResult.data(bizProcessService.detail(bizProcessIdParam));
    }

    /**
     * 获取停车费配置列表
     *
     * @author sandy
     * @date  2025/06/03 15:11
     */
    @Operation(summary = "获取生产工序列表")
    @GetMapping("/biz/bizprocess/getList")
    public CommonResult<List<BizProcess>> getList(BizProcessPageParam bizProcessPageParam) {
        return CommonResult.data(bizProcessService.getList(bizProcessPageParam));
    }
}
