/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizprocess.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.biz.modular.bizprocess.enums.BizProcessEnum;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizprocess.entity.BizProcess;
import vip.xiaonuo.biz.modular.bizprocess.mapper.BizProcessMapper;
import vip.xiaonuo.biz.modular.bizprocess.param.BizProcessAddParam;
import vip.xiaonuo.biz.modular.bizprocess.param.BizProcessEditParam;
import vip.xiaonuo.biz.modular.bizprocess.param.BizProcessIdParam;
import vip.xiaonuo.biz.modular.bizprocess.param.BizProcessPageParam;
import vip.xiaonuo.biz.modular.bizprocess.service.BizProcessService;

import java.util.List;

/**
 * 生产工序Service接口实现类
 *
 * @author fanzherong
 * @date  2025/05/29 15:09
 **/
@Service
public class BizProcessServiceImpl extends ServiceImpl<BizProcessMapper, BizProcess> implements BizProcessService {

    @Override
    public Page<BizProcess> page(BizProcessPageParam bizProcessPageParam) {
        QueryWrapper<BizProcess> queryWrapper = new QueryWrapper<BizProcess>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizProcessPageParam.getProcessName())) {
            queryWrapper.lambda().like(BizProcess::getProcessName, bizProcessPageParam.getProcessName());
        }
        if(ObjectUtil.isAllNotEmpty(bizProcessPageParam.getSortField(), bizProcessPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizProcessPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizProcessPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizProcessPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(BizProcess::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizProcessAddParam bizProcessAddParam) {
        //查询名称是否添加过
        long countName = this.count(new QueryWrapper<BizProcess>().lambda().eq(BizProcess::getProcessName, bizProcessAddParam.getProcessName())
                                                                        .eq(BizProcess::getDeleteFlag, BizProcessEnum.NOT_DELETE.getValue()));
        if(countName>0){
            throw new CommonException("生产工序名称已存在！");
        }
        BizProcess bizProcess = BeanUtil.toBean(bizProcessAddParam, BizProcess.class);
        this.save(bizProcess);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizProcessEditParam bizProcessEditParam) {
        //查询名称是否添加过
        long countName = this.count(new QueryWrapper<BizProcess>().lambda().eq(BizProcess::getProcessName, bizProcessEditParam.getProcessName())
                                                                        .ne(BizProcess::getId, bizProcessEditParam.getId())
                                                                        .eq(BizProcess::getDeleteFlag, BizProcessEnum.NOT_DELETE.getValue()));
        if(countName>0){
            throw new CommonException("生产工序名称已存在！");
        }
        BizProcess bizProcess = this.queryEntity(bizProcessEditParam.getId());
        BeanUtil.copyProperties(bizProcessEditParam, bizProcess);
        this.updateById(bizProcess);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizProcessIdParam> bizProcessIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizProcessIdParamList, BizProcessIdParam::getId));
    }

    @Override
    public BizProcess detail(BizProcessIdParam bizProcessIdParam) {
        return this.queryEntity(bizProcessIdParam.getId());
    }

    @Override
    public BizProcess queryEntity(String id) {
        BizProcess bizProcess = this.getById(id);
        if(ObjectUtil.isEmpty(bizProcess)) {
            throw new CommonException("生产工序不存在，id值为：{}", id);
        }
        return bizProcess;
    }

    @Override
    public List<BizProcess> getList(BizProcessPageParam bizProcessPageParam) {
        QueryWrapper<BizProcess> queryWrapper = new QueryWrapper<BizProcess>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizProcessPageParam.getProcessName())) {
            queryWrapper.lambda().like(BizProcess::getProcessName, bizProcessPageParam.getProcessName());
        }
        queryWrapper.lambda().orderByAsc(BizProcess::getId);
        return this.list(queryWrapper);
    }
}
