/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizservicecustomer.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import jakarta.annotation.Resource;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.biz.modular.bizservicecustomer.entity.BizServiceCustomer;
import vip.xiaonuo.biz.modular.bizservicecustomer.enums.BizServiceCustomerAccountEnum;
import vip.xiaonuo.biz.modular.bizservicecustomer.enums.BizServiceCustomerEnum;
import vip.xiaonuo.biz.modular.bizservicecustomer.param.*;
import vip.xiaonuo.biz.modular.customer.entity.BizCustomerAccount;
import vip.xiaonuo.biz.modular.customer.param.BizCustomerAccountIdParam;
import vip.xiaonuo.biz.modular.user.entity.BizUser;
import vip.xiaonuo.biz.modular.user.enums.BizUserStatusEnum;
import vip.xiaonuo.biz.modular.user.mapper.BizUserMapper;
import vip.xiaonuo.biz.modular.user.service.BizUserService;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizservicecustomer.entity.BizServiceCustomerAccount;
import vip.xiaonuo.biz.modular.bizservicecustomer.mapper.BizServiceCustomerAccountMapper;
import vip.xiaonuo.biz.modular.bizservicecustomer.service.BizServiceCustomerAccountService;
import vip.xiaonuo.common.util.CommonCryptogramUtil;
import vip.xiaonuo.dev.api.DevConfigApi;
import vip.xiaonuo.sys.api.SysUserApi;

import java.math.BigDecimal;
import java.util.List;

/**
 * 服务客户账号管理Service接口实现类
 *
 * @author fanzherong
 * @date  2025/05/29 14:39
 **/
@Service
public class BizServiceCustomerAccountServiceImpl extends ServiceImpl<BizServiceCustomerAccountMapper, BizServiceCustomerAccount> implements BizServiceCustomerAccountService {

    private static final String SNOWY_SYS_DEFAULT_PASSWORD_KEY = "SNOWY_SYS_DEFAULT_PASSWORD";

    @Resource
    private BizUserService bizUserService;

    @Resource
    private BizUserMapper bizUserMapper;

    @Resource
    private DevConfigApi devConfigApi;

    @Resource
    private SysUserApi sysUserApi;

    @Override
    public Page<BizServiceCustomerAccount> page(BizServiceCustomerAccountPageParam bizServiceCustomerAccountPageParam) {
        QueryWrapper<BizServiceCustomerAccount> queryWrapper = new QueryWrapper<BizServiceCustomerAccount>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizServiceCustomerAccountPageParam.getServiceCustomerId())){
            queryWrapper.lambda().like(BizServiceCustomerAccount::getServiceCustomerId, bizServiceCustomerAccountPageParam.getServiceCustomerId());
        }
        if(ObjectUtil.isAllNotEmpty(bizServiceCustomerAccountPageParam.getSortField(), bizServiceCustomerAccountPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizServiceCustomerAccountPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizServiceCustomerAccountPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizServiceCustomerAccountPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(BizServiceCustomerAccount::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizServiceCustomerAccountAddParam bizServiceCustomerAccountAddParam) {
        //查询名称是否添加过
        long countName = this.count(new QueryWrapper<BizServiceCustomerAccount>().lambda().eq(BizServiceCustomerAccount::getLoginAccount, bizServiceCustomerAccountAddParam.getLoginAccount())
                                                                                .eq(BizServiceCustomerAccount::getDeleteFlag, BizServiceCustomerAccountEnum.NOT_DELETE.getValue()));
        if(countName>0){
            throw new CommonException("服务客户账号已存在！");
        }
        BizServiceCustomerAccount bizServiceCustomerAccount = BeanUtil.toBean(bizServiceCustomerAccountAddParam, BizServiceCustomerAccount.class);
        this.save(bizServiceCustomerAccount);
        addUserAccount(bizServiceCustomerAccount);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizServiceCustomerAccountEditParam bizServiceCustomerAccountEditParam) {
        //查询名称是否添加过
        long countName = this.count(new QueryWrapper<BizServiceCustomerAccount>().lambda().eq(BizServiceCustomerAccount::getLoginAccount, bizServiceCustomerAccountEditParam.getLoginAccount())
                                                                                .ne(BizServiceCustomerAccount::getId, bizServiceCustomerAccountEditParam.getId())
                                                                                .eq(BizServiceCustomerAccount::getDeleteFlag, BizServiceCustomerAccountEnum.NOT_DELETE.getValue()));
        if(countName>0){
            throw new CommonException("服务客户账号已存在！");
        }
        BizServiceCustomerAccount bizServiceCustomerAccount = this.queryEntity(bizServiceCustomerAccountEditParam.getId());

        if(!StringUtils.equals(bizServiceCustomerAccount.getLoginAccount(),bizServiceCustomerAccountEditParam.getLoginAccount())){
            // 删除原本登录账号
            BizUser userOld = bizUserService.getOne(new QueryWrapper<BizUser>().lambda().
                    eq(BizUser::getAccount, bizServiceCustomerAccountEditParam.getLoginAccount()).
                    last("limit 1"));
            if(null != userOld){
                this.bizUserService.removeById(userOld);
            }

            bizServiceCustomerAccount.setLoginAccount(bizServiceCustomerAccountEditParam.getLoginAccount());
            addUserAccount(bizServiceCustomerAccount);
        }
        BeanUtil.copyProperties(bizServiceCustomerAccountEditParam, bizServiceCustomerAccount);
        this.updateById(bizServiceCustomerAccount);
    }

    public void addUserAccount(BizServiceCustomerAccount bizServiceCustomerAccount){
        //根据账号是否存在
        BizUser user = bizUserService.getOne(new QueryWrapper<BizUser>().lambda().
                eq(BizUser::getAccount, bizServiceCustomerAccount.getLoginAccount()).
                last("limit 1"));
        if(ObjectUtil.isNotNull(user)){
            throw new CommonException("服务客户手机号已经存在！");
        }

        // 添加供应商登录账号
        BizUser bizUser = new BizUser();
        bizUser.setCustomerId(bizServiceCustomerAccount.getId());
        bizUser.setName(bizServiceCustomerAccount.getLoginAccount());
        bizUser.setAccount(bizServiceCustomerAccount.getLoginAccount());
        bizUser.setUserType("4");
        // 设置密码
        bizUser.setPassword(CommonCryptogramUtil.doHashValue(devConfigApi.getValueByKey(SNOWY_SYS_DEFAULT_PASSWORD_KEY)));
        // 设置状态
        bizUser.setUserStatus(BizUserStatusEnum.ENABLE.getValue());
        this.bizUserMapper.insert(bizUser);

        // 添加服务客户角色
        this.sysUserApi.grantRoleType(bizUser.getId(), "服务客户");
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizServiceCustomerAccountIdParam> bizServiceCustomerAccountIdParamList) {
        if(null != bizServiceCustomerAccountIdParamList && 0 < bizServiceCustomerAccountIdParamList.size()){
            for (BizServiceCustomerAccountIdParam accountIdParam : bizServiceCustomerAccountIdParamList){
                BizServiceCustomerAccount account = this.queryEntity(accountIdParam.getId());

                // 删除原本登录账号
                BizUser userOld = bizUserService.getOne(new QueryWrapper<BizUser>().lambda().
                        eq(BizUser::getAccount, account.getLoginAccount()).
                        last("limit 1"));
                if(null != userOld){
                    this.bizUserService.removeById(userOld);
                }

                // 执行删除
                this.removeById(account.getId());
            }
        }
    }

    @Override
    public BizServiceCustomerAccount detail(BizServiceCustomerAccountIdParam bizServiceCustomerAccountIdParam) {
        return this.queryEntity(bizServiceCustomerAccountIdParam.getId());
    }

    @Override
    public BizServiceCustomerAccount queryEntity(String id) {
        BizServiceCustomerAccount bizServiceCustomerAccount = this.getById(id);
        if(ObjectUtil.isEmpty(bizServiceCustomerAccount)) {
            throw new CommonException("服务客户账号管理不存在，id值为：{}", id);
        }
        return bizServiceCustomerAccount;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void lock(BizServiceCustomerAccountLockParam bizServiceCustomerFlowLockParam){
        BizServiceCustomerAccount bizServiceCustomerAccount = this.queryEntity(bizServiceCustomerFlowLockParam.getId());
        BigDecimal lockAmount = bizServiceCustomerFlowLockParam.getLockAmount();
        /** 锁定金额（占用金额） */
        BigDecimal lockAmountOld = bizServiceCustomerAccount.getLockAmount();
        /** 可用余额（账户余额） */
        BigDecimal accountAmount = bizServiceCustomerAccount.getAccountAmount();

        // 添加锁定金额
        bizServiceCustomerAccount.setLockAmount(lockAmountOld.add(lockAmount));
        // 余额扣减
        bizServiceCustomerAccount.setAccountAmount(accountAmount.subtract(lockAmount));
        this.updateById(bizServiceCustomerAccount);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void unlock(BizServiceCustomerAccountLockParam bizServiceCustomerFlowLockParam){
        BizServiceCustomerAccount bizServiceCustomerAccount = this.queryEntity(bizServiceCustomerFlowLockParam.getId());
        BigDecimal lockAmount = bizServiceCustomerFlowLockParam.getLockAmount();
        /** 锁定金额（占用金额） */
        BigDecimal lockAmountOld = bizServiceCustomerAccount.getLockAmount();
        /** 可用余额（账户余额） */
        BigDecimal accountAmount = bizServiceCustomerAccount.getAccountAmount();

        // 取消锁定金额
        bizServiceCustomerAccount.setLockAmount(lockAmountOld.subtract(lockAmount));
        // 余额恢复
        bizServiceCustomerAccount.setAccountAmount(accountAmount.add(lockAmount));
        this.updateById(bizServiceCustomerAccount);
    }

}
