/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizservicecustomer.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.annotation.Resource;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.biz.modular.bizservicecustomer.entity.BizServiceCustomerAccount;
import vip.xiaonuo.biz.modular.bizservicecustomer.param.*;
import vip.xiaonuo.biz.modular.bizservicecustomer.service.BizServiceCustomerAccountService;
import vip.xiaonuo.biz.modular.bizsupplier.entity.BizSupplierAccount;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizservicecustomer.entity.BizServiceCustomerFlow;
import vip.xiaonuo.biz.modular.bizservicecustomer.mapper.BizServiceCustomerFlowMapper;
import vip.xiaonuo.biz.modular.bizservicecustomer.service.BizServiceCustomerFlowService;

import java.math.BigDecimal;
import java.util.List;

/**
 * 服务客户资金流水Service接口实现类
 *
 * @author fanzherong
 * @date  2025/05/29 14:40
 **/
@Service
public class BizServiceCustomerFlowServiceImpl extends ServiceImpl<BizServiceCustomerFlowMapper, BizServiceCustomerFlow> implements BizServiceCustomerFlowService {

    @Resource
    private BizServiceCustomerAccountService accountService;

    @Override
    public Page<BizServiceCustomerFlow> page(BizServiceCustomerFlowPageParam bizServiceCustomerFlowPageParam) {
        QueryWrapper<BizServiceCustomerFlow> queryWrapper = new QueryWrapper<BizServiceCustomerFlow>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizServiceCustomerFlowPageParam.getServiceCustomerId())){
            queryWrapper.lambda().like(BizServiceCustomerFlow::getServiceCustomerId, bizServiceCustomerFlowPageParam.getServiceCustomerId());
        }
        if(ObjectUtil.isNotEmpty(bizServiceCustomerFlowPageParam.getScAccountId())){
            queryWrapper.lambda().like(BizServiceCustomerFlow::getScAccountId, bizServiceCustomerFlowPageParam.getScAccountId());
        }
        if(ObjectUtil.isAllNotEmpty(bizServiceCustomerFlowPageParam.getSortField(), bizServiceCustomerFlowPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizServiceCustomerFlowPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizServiceCustomerFlowPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizServiceCustomerFlowPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(BizServiceCustomerFlow::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizServiceCustomerFlowAddParam bizServiceCustomerFlowAddParam) {
        BizServiceCustomerFlow bizServiceCustomerFlow = BeanUtil.toBean(bizServiceCustomerFlowAddParam, BizServiceCustomerFlow.class);
        // 计算 获取当前账户的余额
        BizServiceCustomerAccount account = accountService.getById(bizServiceCustomerFlow.getScAccountId());
        /** 可用余额（账户余额） */
        BigDecimal accountAmount = BigDecimal.ZERO;
        /** 充值总余额 */
        BigDecimal rechargeAmount = BigDecimal.ZERO;
        /** 消费总金额 */
        BigDecimal consumptionAmount = BigDecimal.ZERO;

        if(null != account){
            accountAmount = account.getAccountAmount();
            rechargeAmount = account.getRechargeAmount();
            consumptionAmount = account.getConsumptionAmount();
        }else{
            throw new CommonException("服务客户账户不存在！");
        }
        bizServiceCustomerFlow.setOperateAmountBegin(accountAmount);
        if("1".equals(bizServiceCustomerFlow.getOperateType())){
            // 充值
            rechargeAmount = rechargeAmount.add(bizServiceCustomerFlow.getOperateAmount());
            accountAmount = accountAmount.add(bizServiceCustomerFlow.getOperateAmount());
        }else{
            consumptionAmount = consumptionAmount.add(bizServiceCustomerFlow.getOperateAmount());
            accountAmount = accountAmount.subtract(bizServiceCustomerFlow.getOperateAmount());
        }
        bizServiceCustomerFlow.setOperateAmountAfter(accountAmount);
        this.save(bizServiceCustomerFlow);

        // 更新账户信息
        account.setAccountAmount(accountAmount);
        account.setRechargeAmount(rechargeAmount);
        account.setConsumptionAmount(consumptionAmount);
        accountService.updateById(account);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void cancel(BizServiceCustomerFlowCancelParam bizServiceCustomerFlowCancelParam) {
        BizServiceCustomerFlow bizServiceCustomerFlow = this.queryEntity(bizServiceCustomerFlowCancelParam.getId());
        // 计算 获取当前账户的余额
        BizServiceCustomerAccount account = accountService.getById(bizServiceCustomerFlow.getScAccountId());
        /** 可用余额（账户余额） */
        BigDecimal accountAmount = BigDecimal.ZERO;
        /** 充值总余额 */
        BigDecimal rechargeAmount = BigDecimal.ZERO;
        /** 消费总金额 */
        BigDecimal consumptionAmount = BigDecimal.ZERO;

        if(null != account){
            accountAmount = account.getAccountAmount();
            rechargeAmount = account.getRechargeAmount();
            consumptionAmount = account.getConsumptionAmount();
        }else{
            throw new CommonException("服务客户账户不存在！");
        }
        if("1".equals(bizServiceCustomerFlow.getOperateType())){
            // 充值
            rechargeAmount = rechargeAmount.subtract(bizServiceCustomerFlow.getOperateAmount());
            accountAmount = accountAmount.subtract(bizServiceCustomerFlow.getOperateAmount());
        }else{
            consumptionAmount = consumptionAmount.subtract(bizServiceCustomerFlow.getOperateAmount());
            accountAmount = accountAmount.add(bizServiceCustomerFlow.getOperateAmount());
        }
        // 判断
        if(accountAmount.compareTo(BigDecimal.ZERO) < 0){
            throw new CommonException("服务客户账户余额不支持取消本次充值！");
        }
        // 更新账户信息
        account.setAccountAmount(accountAmount);
        account.setRechargeAmount(rechargeAmount);
        account.setConsumptionAmount(consumptionAmount);
        accountService.updateById(account);

        // 更新流水数据为取消状态
        bizServiceCustomerFlow.setDataStatus("1");
        bizServiceCustomerFlow.setOperateExplain(bizServiceCustomerFlowCancelParam.getOperateExplain());
        this.updateById(bizServiceCustomerFlow);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizServiceCustomerFlowEditParam bizServiceCustomerFlowEditParam) {
        BizServiceCustomerFlow bizServiceCustomerFlow = this.queryEntity(bizServiceCustomerFlowEditParam.getId());
        BeanUtil.copyProperties(bizServiceCustomerFlowEditParam, bizServiceCustomerFlow);
        this.updateById(bizServiceCustomerFlow);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizServiceCustomerFlowIdParam> bizServiceCustomerFlowIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizServiceCustomerFlowIdParamList, BizServiceCustomerFlowIdParam::getId));
    }

    @Override
    public BizServiceCustomerFlow detail(BizServiceCustomerFlowIdParam bizServiceCustomerFlowIdParam) {
        return this.queryEntity(bizServiceCustomerFlowIdParam.getId());
    }

    @Override
    public BizServiceCustomerFlow queryEntity(String id) {
        BizServiceCustomerFlow bizServiceCustomerFlow = this.getById(id);
        if(ObjectUtil.isEmpty(bizServiceCustomerFlow)) {
            throw new CommonException("服务客户资金流水不存在，id值为：{}", id);
        }
        return bizServiceCustomerFlow;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void lockConsume(BizServiceCustomerAccountLockParam bizServiceCustomerFlowLockParam){
        BizServiceCustomerAccount bizServiceCustomerAccount = accountService.queryEntity(bizServiceCustomerFlowLockParam.getId());
        BigDecimal lockAmount = bizServiceCustomerFlowLockParam.getLockAmount();
        /** 锁定金额（占用金额） */
        BigDecimal lockAmountOld = bizServiceCustomerAccount.getLockAmount();
        /** 消费总金额 */
        BigDecimal consumptionAmount = bizServiceCustomerAccount.getConsumptionAmount();
        /** 可用余额（账户余额） */
        BigDecimal accountAmount = bizServiceCustomerAccount.getAccountAmount();

        //释放锁定金额
        bizServiceCustomerAccount.setLockAmount(lockAmountOld.subtract(lockAmount));
        // 增加消费金额
        bizServiceCustomerAccount.setConsumptionAmount(consumptionAmount.add(lockAmount));
        accountService.updateById(bizServiceCustomerAccount);

        //添加消费扣款流水记录
        BizServiceCustomerFlow bizServiceCustomerFlow = new BizServiceCustomerFlow();
        /** 服务客户id */
        bizServiceCustomerFlow.setServiceCustomerId(bizServiceCustomerAccount.getServiceCustomerId());
        /** 服务客户账户id */
        bizServiceCustomerFlow.setScAccountId(bizServiceCustomerAccount.getId());
        /** 操作类型  1：充值   2：消费 */
        bizServiceCustomerFlow.setOperateType("2");
        /** 操作前账户余额（充值或消费前账户余额） */
        bizServiceCustomerFlow.setOperateAmountBegin(accountAmount.subtract(lockAmount));
        /** 操作金额（充值或消费金额） */
        bizServiceCustomerFlow.setOperateAmount(lockAmount);
        /** 操作后账户余额（充值或消费后账户余额） */
        bizServiceCustomerFlow.setOperateAmountAfter(accountAmount);

        this.save(bizServiceCustomerFlow);
    }
}
