/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizservicecustomer.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.PhoneUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import jakarta.annotation.Resource;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.biz.modular.bizservicecustomer.entity.BizServiceCustomerAccount;
import vip.xiaonuo.biz.modular.bizservicecustomer.entity.BizServiceCustomerFlow;
import vip.xiaonuo.biz.modular.bizservicecustomer.enums.BizServiceCustomerEnum;
import vip.xiaonuo.biz.modular.bizservicecustomer.service.BizServiceCustomerAccountService;
import vip.xiaonuo.biz.modular.bizsupplier.entity.BizSupplier;
import vip.xiaonuo.biz.modular.bizsupplier.entity.BizSupplierAccount;
import vip.xiaonuo.biz.modular.bizsupplier.enums.BizSupplierAccountEnum;
import vip.xiaonuo.biz.modular.bizsupplier.param.BizSupplierIdParam;
import vip.xiaonuo.biz.modular.user.entity.BizUser;
import vip.xiaonuo.biz.modular.user.enums.BizUserStatusEnum;
import vip.xiaonuo.biz.modular.user.mapper.BizUserMapper;
import vip.xiaonuo.biz.modular.user.service.BizUserService;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizservicecustomer.entity.BizServiceCustomer;
import vip.xiaonuo.biz.modular.bizservicecustomer.mapper.BizServiceCustomerMapper;
import vip.xiaonuo.biz.modular.bizservicecustomer.param.BizServiceCustomerAddParam;
import vip.xiaonuo.biz.modular.bizservicecustomer.param.BizServiceCustomerEditParam;
import vip.xiaonuo.biz.modular.bizservicecustomer.param.BizServiceCustomerIdParam;
import vip.xiaonuo.biz.modular.bizservicecustomer.param.BizServiceCustomerPageParam;
import vip.xiaonuo.biz.modular.bizservicecustomer.service.BizServiceCustomerService;
import vip.xiaonuo.common.util.CommonCryptogramUtil;
import vip.xiaonuo.dev.api.DevConfigApi;
import vip.xiaonuo.sys.api.SysUserApi;

import java.util.List;

/**
 * 服务客户管理Service接口实现类
 *
 * @author fanzherong
 * @date  2025/05/29 14:27
 **/
@Service
public class BizServiceCustomerServiceImpl extends ServiceImpl<BizServiceCustomerMapper, BizServiceCustomer> implements BizServiceCustomerService {

    private static final String SNOWY_SYS_DEFAULT_PASSWORD_KEY = "SNOWY_SYS_DEFAULT_PASSWORD";

    @Resource
    private BizServiceCustomerAccountService bizServiceCustomerAccountService;

    @Resource
    private BizUserService bizUserService;

    @Resource
    private BizUserMapper bizUserMapper;

    @Resource
    private DevConfigApi devConfigApi;

    @Resource
    private SysUserApi sysUserApi;

    @Override
    public Page<BizServiceCustomer> page(BizServiceCustomerPageParam bizServiceCustomerPageParam) {
        QueryWrapper<BizServiceCustomer> queryWrapper = new QueryWrapper<BizServiceCustomer>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizServiceCustomerPageParam.getCustomerName())){
            queryWrapper.lambda().like(BizServiceCustomer::getName, bizServiceCustomerPageParam.getCustomerName());
        }
        if(ObjectUtil.isAllNotEmpty(bizServiceCustomerPageParam.getSortField(), bizServiceCustomerPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizServiceCustomerPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizServiceCustomerPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizServiceCustomerPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(BizServiceCustomer::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizServiceCustomerAddParam bizServiceCustomerAddParam) {
        //校验手机号格式
        if(ObjectUtil.isNotEmpty(bizServiceCustomerAddParam.getPhone())){
            if(!PhoneUtil.isMobile(bizServiceCustomerAddParam.getPhone())) {
                throw new CommonException("手机号码：{}格式错误", bizServiceCustomerAddParam.getPhone());
            }
        }
        //查询名称是否添加过
        long countName = this.count(new QueryWrapper<BizServiceCustomer>().lambda().eq(BizServiceCustomer::getName, bizServiceCustomerAddParam.getName())
                                                                    .eq(BizServiceCustomer::getDeleteFlag, BizServiceCustomerEnum.NOT_DELETE.getValue()));
        if(countName>0){
            throw new CommonException("服务客户名称已存在！");
        }
        //查询手机号是否添加过
        long countPhone = this.count(new QueryWrapper<BizServiceCustomer>().lambda().eq(BizServiceCustomer::getPhone, bizServiceCustomerAddParam.getPhone())
                .eq(BizServiceCustomer::getDeleteFlag, BizServiceCustomerEnum.NOT_DELETE.getValue()));
        if(countPhone>0){
            throw new CommonException("服务客户手机号已存在！");
        }
        BizServiceCustomer bizServiceCustomer = BeanUtil.toBean(bizServiceCustomerAddParam, BizServiceCustomer.class);

        this.save(bizServiceCustomer);

        //查询账号是否添加过
        if(ObjectUtil.isNotEmpty(bizServiceCustomer.getPhone())){
            addUserAccount(bizServiceCustomer);
        }

    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizServiceCustomerEditParam bizServiceCustomerEditParam) {
        //校验手机号格式
        if(ObjectUtil.isNotEmpty(bizServiceCustomerEditParam.getPhone())){
            if(!PhoneUtil.isMobile(bizServiceCustomerEditParam.getPhone())) {
                throw new CommonException("手机号码：{}格式错误", bizServiceCustomerEditParam.getPhone());
            }
        }
        //查询名称是否添加过
        long countName = this.count(new QueryWrapper<BizServiceCustomer>().lambda().eq(BizServiceCustomer::getName, bizServiceCustomerEditParam.getName())
                .ne(BizServiceCustomer::getId, bizServiceCustomerEditParam.getId())
                .eq(BizServiceCustomer::getDeleteFlag, BizServiceCustomerEnum.NOT_DELETE.getValue()));
        if(countName>0){
            throw new CommonException("服务客户名称已存在！");
        }
        BizServiceCustomer bizServiceCustomer = this.queryEntity(bizServiceCustomerEditParam.getId());
        if(!StringUtils.equals(bizServiceCustomer.getPhone(),bizServiceCustomerEditParam.getPhone())){
            deleteUserAccount(bizServiceCustomer.getId());
            bizServiceCustomer.setPhone(bizServiceCustomerEditParam.getPhone());
            addUserAccount(bizServiceCustomer);
        }
        BeanUtil.copyProperties(bizServiceCustomerEditParam, bizServiceCustomer);
        this.updateById(bizServiceCustomer);
    }

    public void addUserAccount(BizServiceCustomer bizServiceCustomer){
        //根据账号是否存在
        BizUser user = bizUserService.getOne(new QueryWrapper<BizUser>().lambda().
                eq(BizUser::getAccount, bizServiceCustomer.getPhone()).
                last("limit 1"));
        if(ObjectUtil.isNotNull(user)){
            throw new CommonException("服务客户手机号已经存在！");
        }

        // 添加供应商登录账号
        BizUser bizUser = new BizUser();
        bizUser.setCustomerId(bizServiceCustomer.getId());
        bizUser.setName(bizServiceCustomer.getPhone());
        bizUser.setAccount(bizServiceCustomer.getPhone());
        bizUser.setUserType("4");
        // 设置密码
        bizUser.setPassword(CommonCryptogramUtil.doHashValue(devConfigApi.getValueByKey(SNOWY_SYS_DEFAULT_PASSWORD_KEY)));
        // 设置状态
        bizUser.setUserStatus(BizUserStatusEnum.ENABLE.getValue());
        this.bizUserMapper.insert(bizUser);

        // 添加服务客户角色
        this.sysUserApi.grantRoleType(bizUser.getId(), "服务客户");

        BizServiceCustomerAccount bizServiceCustomerAccount = new BizServiceCustomerAccount();
        bizServiceCustomerAccount.setServiceCustomerId(bizServiceCustomer.getId());
        bizServiceCustomerAccount.setLoginAccount(bizServiceCustomer.getPhone());
        bizServiceCustomerAccountService.save(bizServiceCustomerAccount);
    }

    public void deleteUserAccount(String bizServiceCustomerId){
        if(null != bizServiceCustomerId) {
            // 删除供应商对应的子账号
            List<BizServiceCustomerAccount> list = bizServiceCustomerAccountService.list(new QueryWrapper<BizServiceCustomerAccount>().lambda().eq(BizServiceCustomerAccount::getServiceCustomerId, bizServiceCustomerId));
            for (BizServiceCustomerAccount bizServiceCustomerAccount : list) {
                bizServiceCustomerAccountService.removeById(bizServiceCustomerAccount);

                // 删除用户账号
                List<BizUser> userList = bizUserService.list(new QueryWrapper<BizUser>().lambda()
                        .eq(BizUser::getAccount, bizServiceCustomerAccount.getLoginAccount()));
                bizUserService.removeByIds(CollStreamUtil.toList(userList, BizUser::getId));
            }
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizServiceCustomerIdParam> bizServiceCustomerIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizServiceCustomerIdParamList, BizServiceCustomerIdParam::getId));
        // 删除登录账号
        for(BizServiceCustomerIdParam bizServiceCustomerIdParam : bizServiceCustomerIdParamList){
            deleteUserAccount(bizServiceCustomerIdParam.getId());
        }
    }

    @Override
    public BizServiceCustomer detail(BizServiceCustomerIdParam bizServiceCustomerIdParam) {
        return this.queryEntity(bizServiceCustomerIdParam.getId());
    }

    @Override
    public BizServiceCustomer queryEntity(String id) {
        BizServiceCustomer bizServiceCustomer = this.getById(id);
        if(ObjectUtil.isEmpty(bizServiceCustomer)) {
            throw new CommonException("服务客户管理不存在，id值为：{}", id);
        }
        return bizServiceCustomer;
    }

    @Override
    public List<BizServiceCustomer> getList(BizServiceCustomerPageParam bizServiceCustomerPageParam) {
        QueryWrapper<BizServiceCustomer> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().orderByDesc(BizServiceCustomer::getCreateTime);
        List<BizServiceCustomer> list = this.list(queryWrapper);
        return list;
    }
}
