/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizsettle.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.biz.modular.bizsettle.param.*;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.bizsettle.entity.BizSettle;
import vip.xiaonuo.biz.modular.bizsettle.service.BizSettleService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 运费结算控制器
 *
 * @author xiaofan
 * @date  2025/06/12 09:54
 */
@Tag(name = "运费结算控制器")
@RestController
@Validated
public class BizSettleController {

    @Resource
    private BizSettleService bizSettleService;

    /**
     * 获取运费结算分页
     *
     * @author xiaofan
     * @date  2025/06/12 09:54
     */
    @Operation(summary = "获取运费结算分页")
    @SaCheckPermission("/biz/bizsettle/page")
    @GetMapping("/biz/bizsettle/page")
    public CommonResult<Page<BizSettle>> page(BizSettlePageParam bizSettlePageParam) {
        return CommonResult.data(bizSettleService.page(bizSettlePageParam));
    }

    /**
     * 添加运费结算
     *
     * @author xiaofan
     * @date  2025/06/12 09:54
     */
    @Operation(summary = "添加运费结算")
    @CommonLog("添加运费结算")
    @PostMapping("/biz/bizsettle/add")
    public CommonResult<String> add(@RequestBody @Valid BizSettleAddParam bizSettleAddParam) {
        bizSettleService.add(bizSettleAddParam);
        return CommonResult.ok();
    }

    /**
     * 添加船运运费结算
     *
     * @author xiaofan
     * @date  2025/06/12 09:54
     */
    @Operation(summary = "添加船运运费结算")
    @CommonLog("添加船运运费结算")
    @PostMapping("/biz/bizsettle/addShipSettle")
    public CommonResult<String> addShipSettle(@RequestBody @Valid BizSettleAddParam bizSettleAddParam) {
        bizSettleService.addShipSettle(bizSettleAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑运费结算
     *
     * @author xiaofan
     * @date  2025/06/12 09:54
     */
    @Operation(summary = "编辑运费结算")
    @CommonLog("编辑运费结算")
    @PostMapping("/biz/bizsettle/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizSettleEditParam bizSettleEditParam) {
        bizSettleService.edit(bizSettleEditParam);
        return CommonResult.ok();
    }

    /**
     * 编辑船运结算
     *
     * @author xiaofan
     * @date  2025/06/12 09:54
     */
    @Operation(summary = "编辑船运结算")
    @CommonLog("编辑船运结算")
    @PostMapping("/biz/bizsettle/editShipSettle")
    public CommonResult<String> editShipSettle(@RequestBody @Valid BizSettleEditParam bizSettleEditParam) {
        bizSettleService.editShipSettle(bizSettleEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除运费结算
     *
     * @author xiaofan
     * @date  2025/06/12 09:54
     */
    @Operation(summary = "删除运费结算")
    @CommonLog("删除运费结算")
    @PostMapping("/biz/bizsettle/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizSettleIdParam> bizSettleIdParamList) {
        bizSettleService.delete(bizSettleIdParamList);
        return CommonResult.ok();
    }

    /**
     * 删除船运运费结算
     *
     * @author xiaofan
     * @date  2025/06/12 09:54
     */
    @Operation(summary = "删除船运运费结算")
    @CommonLog("删除船运运费结算")
    @PostMapping("/biz/bizsettle/deleteArrive")
    public CommonResult<String> deleteArrive(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                       List<BizSettleIdParam> bizSettleIdParamList) {
        bizSettleService.deleteArrive(bizSettleIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取运费结算详情
     *
     * @author xiaofan
     * @date  2025/06/12 09:54
     */
    @Operation(summary = "获取运费结算详情")
    @GetMapping("/biz/bizsettle/detail")
    public CommonResult<BizSettle> detail(@Valid BizSettleIdParam bizSettleIdParam) {
        return CommonResult.data(bizSettleService.detail(bizSettleIdParam));
    }

    /**
     * 编辑获取明细
     *
     * @author xiaofan
     * @date  2025/06/12 09:54
     */
    @Operation(summary = "编辑获取明细")
    @GetMapping("/biz/bizsettle/detailOrder")
    public CommonResult<BizSettle> detailOrder(@Valid BizSettleIdParam bizSettleIdParam) {
        return CommonResult.data(bizSettleService.detailOrder(bizSettleIdParam));
    }

    /**
     * 编辑获取船运明细
     *
     * @author xiaofan
     * @date  2025/06/12 09:54
     */
    @Operation(summary = "编辑获取船运明细")
    @GetMapping("/biz/bizsettle/detailArrive")
    public CommonResult<BizSettle> detailArrive(@Valid BizSettleIdParam bizSettleIdParam) {
        return CommonResult.data(bizSettleService.detailArrive(bizSettleIdParam));
    }




    /**
     * 运费结算提交
     *
     * @author xiaofan
     * @date  2025/06/12 09:54
     */
    @Operation(summary = "运费结算提交")
    @CommonLog("运费结算提交")
    @PostMapping("/biz/bizsettle/submit")
    public CommonResult<String> submit(@RequestBody @Valid BizSettleEditParam bizSettleEditParam) {
        bizSettleService.submit(bizSettleEditParam);
        return CommonResult.ok();
    }

    /**
     * 管理员审批
     *
     * @author xiaofan
     * @date  2025/06/12 09:54
     */
    @Operation(summary = "管理员审批")
    @CommonLog("管理员审批")
    @PostMapping("/biz/bizsettle/auditAdmin")
    public CommonResult<String> auditAdmin(@RequestBody @Valid BizSettleAuditParam bizSettleAuditParam) {
        bizSettleService.auditAdmin(bizSettleAuditParam);
        return CommonResult.ok();
    }

    /**
     * 财务审批
     *
     * @author xiaofan
     * @date  2025/06/12 09:54
     */
    @Operation(summary = "财务审批")
    @CommonLog("财务审批")
    @PostMapping("/biz/bizsettle/auditFinance")
    public CommonResult<String> auditFinance(@RequestBody @Valid BizSettleAuditParam bizSettleAuditParam) {
        bizSettleService.auditFinance(bizSettleAuditParam);
        return CommonResult.ok();
    }

    /**
     * 上传发票
     *
     * @author xiaofan
     * @date  2025/06/12 09:54
     */
    @Operation(summary = "上传发票")
    @CommonLog("上传发票")
    @PostMapping("/biz/bizsettle/uploadInvoice")
    public CommonResult<String> uploadInvoice(@RequestBody @Valid BizSettleEditParam bizSettleEditParam) {
        bizSettleService.uploadInvoice(bizSettleEditParam);
        return CommonResult.ok();
    }

    /**
     * 上传结款凭证
     *
     * @author xiaofan
     * @date  2025/06/12 09:54
     */
    @Operation(summary = "上传结款凭证")
    @CommonLog("上传结款凭证")
    @PostMapping("/biz/bizsettle/uploadVoucher")
    public CommonResult<String> uploadVoucher(@RequestBody @Valid BizSettleEditParam bizSettleEditParam) {
        bizSettleService.uploadVoucher(bizSettleEditParam);
        return CommonResult.ok();
    }

    /**
     * 财务审批
     *
     * @author xiaofan
     * @date  2025/06/12 09:54
     */
    @Operation(summary = "财务审批")
    @CommonLog("财务审批")
    @PostMapping("/biz/bizsettle/auditReject")
    public CommonResult<String> auditReject(@RequestBody @Valid BizSettleAuditParam bizSettleAuditParam) {
        bizSettleService.auditReject(bizSettleAuditParam);
        return CommonResult.ok();
    }
}
