/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizsettle.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import vip.xiaonuo.biz.modular.bizsettle.entity.BizSettle;
import vip.xiaonuo.biz.modular.bizsettle.param.*;

import java.util.List;

/**
 * 运费结算Service接口
 *
 * @author xiaofan
 * @date  2025/06/12 09:54
 **/
public interface BizSettleService extends IService<BizSettle> {

    /**
     * 获取运费结算分页
     *
     * @author xiaofan
     * @date  2025/06/12 09:54
     */
    Page<BizSettle> page(BizSettlePageParam bizSettlePageParam);

    /**
     * 添加运费结算
     *
     * @author xiaofan
     * @date  2025/06/12 09:54
     */
    void add(BizSettleAddParam bizSettleAddParam);

    /**
     * 编辑运费结算
     *
     * @author xiaofan
     * @date  2025/06/12 09:54
     */
    void edit(BizSettleEditParam bizSettleEditParam);

    /**
     * 新增船运结算
     * @param bizSettleAddParam
     */
    void addShipSettle(BizSettleAddParam bizSettleAddParam);

    /**
     * 编辑船运结算
     */
    void editShipSettle(BizSettleEditParam bizSettleEditParam);



    /**
     * 删除运费结算
     *
     * @author xiaofan
     * @date  2025/06/12 09:54
     */
    void delete(List<BizSettleIdParam> bizSettleIdParamList);

    /**
     * 删除船运结算
     */
    void deleteArrive(List<BizSettleIdParam> bizSettleIdParamList);

    /**
     * 获取运费结算详情
     *
     * @author xiaofan
     * @date  2025/06/12 09:54
     */
    BizSettle detail(BizSettleIdParam bizSettleIdParam);

    /**
     * 获取运费结算详情
     *
     * @author xiaofan
     * @date  2025/06/12 09:54
     **/
    BizSettle queryEntity(String id);

    /**
     * 编辑查询明细
     */
    BizSettle detailOrder(BizSettleIdParam bizSettleIdParam);

    /**
     * 编辑船运结算查询明细
     */
    BizSettle detailArrive(BizSettleIdParam bizSettleIdParam);

    /**
     * 提交
     */
    void submit(BizSettleEditParam bizSettleEditParam);

    /**
     * 管理员审批
     */
    void auditAdmin(BizSettleAuditParam bizSettleAuditParam);

    /**
     * 财务审批
     */
    void auditFinance(BizSettleAuditParam bizSettleAuditParam);

    /**
     * 上传发票
     */
    void uploadInvoice(BizSettleEditParam bizSettleEditParam);

    /**
     * 上传结款凭证
     */
    void uploadVoucher(BizSettleEditParam bizSettleEditParam);

    /**
     * 打款驳回
     */
    void auditReject(BizSettleAuditParam bizSettleAuditParam);
}
