/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizsettleorder.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.bizsettleorder.entity.BizSettleOrder;
import vip.xiaonuo.biz.modular.bizsettleorder.param.BizSettleOrderAddParam;
import vip.xiaonuo.biz.modular.bizsettleorder.param.BizSettleOrderEditParam;
import vip.xiaonuo.biz.modular.bizsettleorder.param.BizSettleOrderIdParam;
import vip.xiaonuo.biz.modular.bizsettleorder.param.BizSettleOrderPageParam;
import vip.xiaonuo.biz.modular.bizsettleorder.service.BizSettleOrderService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 运费订单关联表控制器
 *
 * @author fanzherong
 * @date  2025/06/12 15:02
 */
@Tag(name = "运费订单关联表控制器")
@RestController
@Validated
public class BizSettleOrderController {

    @Resource
    private BizSettleOrderService bizSettleOrderService;

    /**
     * 获取运费订单关联表分页
     *
     * @author fanzherong
     * @date  2025/06/12 15:02
     */
    @Operation(summary = "获取运费订单关联表分页")
    @SaCheckPermission("/biz/bizsettleorder/page")
    @GetMapping("/biz/bizsettleorder/page")
    public CommonResult<Page<BizSettleOrder>> page(BizSettleOrderPageParam bizSettleOrderPageParam) {
        return CommonResult.data(bizSettleOrderService.page(bizSettleOrderPageParam));
    }

    /**
     * 添加运费订单关联表
     *
     * @author fanzherong
     * @date  2025/06/12 15:02
     */
    @Operation(summary = "添加运费订单关联表")
    @CommonLog("添加运费订单关联表")
    @PostMapping("/biz/bizsettleorder/add")
    public CommonResult<String> add(@RequestBody @Valid BizSettleOrderAddParam bizSettleOrderAddParam) {
        bizSettleOrderService.add(bizSettleOrderAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑运费订单关联表
     *
     * @author fanzherong
     * @date  2025/06/12 15:02
     */
    @Operation(summary = "编辑运费订单关联表")
    @CommonLog("编辑运费订单关联表")
    @PostMapping("/biz/bizsettleorder/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizSettleOrderEditParam bizSettleOrderEditParam) {
        bizSettleOrderService.edit(bizSettleOrderEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除运费订单关联表
     *
     * @author fanzherong
     * @date  2025/06/12 15:02
     */
    @Operation(summary = "删除运费订单关联表")
    @CommonLog("删除运费订单关联表")
    @PostMapping("/biz/bizsettleorder/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizSettleOrderIdParam> bizSettleOrderIdParamList) {
        bizSettleOrderService.delete(bizSettleOrderIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取运费订单关联表详情
     *
     * @author fanzherong
     * @date  2025/06/12 15:02
     */
    @Operation(summary = "获取运费订单关联表详情")
    @GetMapping("/biz/bizsettleorder/detail")
    public CommonResult<BizSettleOrder> detail(@Valid BizSettleOrderIdParam bizSettleOrderIdParam) {
        return CommonResult.data(bizSettleOrderService.detail(bizSettleOrderIdParam));
    }
}
