/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizsettleorder.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizsettleorder.entity.BizSettleOrder;
import vip.xiaonuo.biz.modular.bizsettleorder.mapper.BizSettleOrderMapper;
import vip.xiaonuo.biz.modular.bizsettleorder.param.BizSettleOrderAddParam;
import vip.xiaonuo.biz.modular.bizsettleorder.param.BizSettleOrderEditParam;
import vip.xiaonuo.biz.modular.bizsettleorder.param.BizSettleOrderIdParam;
import vip.xiaonuo.biz.modular.bizsettleorder.param.BizSettleOrderPageParam;
import vip.xiaonuo.biz.modular.bizsettleorder.service.BizSettleOrderService;

import java.util.List;

/**
 * 运费订单关联表Service接口实现类
 *
 * @author fanzherong
 * @date  2025/06/12 15:02
 **/
@Service
public class BizSettleOrderServiceImpl extends ServiceImpl<BizSettleOrderMapper, BizSettleOrder> implements BizSettleOrderService {

    @Override
    public Page<BizSettleOrder> page(BizSettleOrderPageParam bizSettleOrderPageParam) {
        QueryWrapper<BizSettleOrder> queryWrapper = new QueryWrapper<BizSettleOrder>().checkSqlInjection();
        if(ObjectUtil.isAllNotEmpty(bizSettleOrderPageParam.getSortField(), bizSettleOrderPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizSettleOrderPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizSettleOrderPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizSettleOrderPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizSettleOrder::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizSettleOrderAddParam bizSettleOrderAddParam) {
        BizSettleOrder bizSettleOrder = BeanUtil.toBean(bizSettleOrderAddParam, BizSettleOrder.class);
        this.save(bizSettleOrder);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizSettleOrderEditParam bizSettleOrderEditParam) {
        BizSettleOrder bizSettleOrder = this.queryEntity(bizSettleOrderEditParam.getId());
        BeanUtil.copyProperties(bizSettleOrderEditParam, bizSettleOrder);
        this.updateById(bizSettleOrder);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizSettleOrderIdParam> bizSettleOrderIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizSettleOrderIdParamList, BizSettleOrderIdParam::getId));
    }

    @Override
    public BizSettleOrder detail(BizSettleOrderIdParam bizSettleOrderIdParam) {
        return this.queryEntity(bizSettleOrderIdParam.getId());
    }

    @Override
    public BizSettleOrder queryEntity(String id) {
        BizSettleOrder bizSettleOrder = this.getById(id);
        if(ObjectUtil.isEmpty(bizSettleOrder)) {
            throw new CommonException("运费订单关联表不存在，id值为：{}", id);
        }
        return bizSettleOrder;
    }
}
