/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizship.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.biz.modular.bizship.param.*;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.bizship.entity.BizShip;
import vip.xiaonuo.biz.modular.bizship.service.BizShipService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 船舶管理控制器
 *
 * @author fanzherong
 * @date  2025/07/12 15:32
 */
@Tag(name = "船舶管理控制器")
@RestController
@Validated
public class BizShipController {

    @Resource
    private BizShipService bizShipService;

    /**
     * 获取船舶管理分页
     *
     * @author fanzherong
     * @date  2025/07/12 15:32
     */
    @Operation(summary = "获取船舶管理分页")
    @SaCheckPermission("/biz/bizship/page")
    @GetMapping("/biz/bizship/page")
    public CommonResult<Page<BizShip>> page(BizShipPageParam bizShipPageParam) {
        return CommonResult.data(bizShipService.page(bizShipPageParam));
    }

    /**
     * 添加船舶管理
     *
     * @author fanzherong
     * @date  2025/07/12 15:32
     */
    @Operation(summary = "添加船舶管理")
    @CommonLog("添加船舶管理")
    @PostMapping("/biz/bizship/add")
    public CommonResult<String> add(@RequestBody @Valid BizShipAddParam bizShipAddParam) {
        bizShipService.add(bizShipAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑船舶管理
     *
     * @author fanzherong
     * @date  2025/07/12 15:32
     */
    @Operation(summary = "编辑船舶管理")
    @CommonLog("编辑船舶管理")
    @PostMapping("/biz/bizship/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizShipEditParam bizShipEditParam) {
        bizShipService.edit(bizShipEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除船舶管理
     *
     * @author fanzherong
     * @date  2025/07/12 15:32
     */
    @Operation(summary = "删除船舶管理")
    @CommonLog("删除船舶管理")
    @PostMapping("/biz/bizship/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizShipIdParam> bizShipIdParamList) {
        bizShipService.delete(bizShipIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取船舶管理详情
     *
     * @author fanzherong
     * @date  2025/07/12 15:32
     */
    @Operation(summary = "获取船舶管理详情")
    @GetMapping("/biz/bizship/detail")
    public CommonResult<BizShip> detail(@Valid BizShipIdParam bizShipIdParam) {
        return CommonResult.data(bizShipService.detail(bizShipIdParam));
    }

    /**
     * 获取船型下拉
     *
     * @author fanzherong
     * @date  2025/07/12 15:32
     */
    @Operation(summary = "获取船型下拉")
    @GetMapping("/biz/bizship/getShipTypeList")
    public CommonResult<List<BizShipValue>> getShipTypeList() {
        return CommonResult.data(bizShipService.getShipTypeList());
    }

    /**
     * 个人长期船舶
     *
     * @author fanzherong
     * @date  2025/07/12 15:32
     */
    @Operation(summary = "个人长期船舶")
    @GetMapping("/biz/bizship/getShip")
    public CommonResult<BizShip> getShip() {
        return CommonResult.data(bizShipService.getShip());
    }
}
