/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizship.param;

import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Getter;
import lombok.Setter;

import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 船舶管理编辑参数
 *
 * @author fanzherong
 * @date  2025/07/12 15:32
 **/
@Getter
@Setter
public class BizShipEditParam {

    /** 主键ID */
    @Schema(description = "主键ID", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotBlank(message = "id不能为空")
    private String id;

    /** 船舶号 */
    @Schema(description = "船舶号")
    private String shipNumber;

    /** 船型 */
    @Schema(description = "船型")
    private String shipType;

    /** 船舶证书 */
    @Schema(description = "船舶证书")
    private String shipCertificateName;

    /** 船舶证书路径 */
    @Schema(description = "船舶证书路径")
    private String shipCertificatePath;

    /** 荷载吨位 */
    @Schema(description = "荷载吨位")
    private BigDecimal shipLoad;

    /** 船舶所有人 */
    @Schema(description = "船舶所有人")
    private String shipOwner;

    /** 船舶身份信息 */
    @Schema(description = "船舶身份信息")
    private String shipIdentity;

    /** 联系人姓名 */
    @Schema(description = "联系人姓名")
    private String contactName;

    /** 联系人电话 */
    @Schema(description = "联系人电话")
    private String contactPhone;

    /** 收款单位 */
    @Schema(description = "收款单位")
    private String receiveUnit;

    /** 收款银行 */
    @Schema(description = "收款银行")
    private String receiveBank;

    /** 收款账户 */
    @Schema(description = "收款账户")
    private String receiveAccount;

    /** 合同名称 */
    @Schema(description = "合同名称")
    private String contractName;

    /** 合同路径 */
    @Schema(description = "合同路径")
    private String contractPath;

    /** 船主id */
    @Schema(description = "船主id")
    private String shipId;

    /** 状态 1：启用   2：停用 */
    @Schema(description = "状态 1：启用   2：停用")
    private String status;


    private List<String> certificatePathList;

    private List<String> certificateNameList;

    private List<String> contractPathList;

    private List<String> contractNameList;

    /**船舶注册号码**/
    private String registerNumber;

}
