/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizsupplier.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import jakarta.annotation.Resource;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.biz.modular.bizloadpoint.entity.BizLoadPoint;
import vip.xiaonuo.biz.modular.bizorder.entity.BizOrder;
import vip.xiaonuo.biz.modular.bizsupplier.entity.BizSupplier;
import vip.xiaonuo.biz.modular.bizsupplier.enums.BizSupplierAccountEnum;
import vip.xiaonuo.biz.modular.bizsupplier.param.*;
import vip.xiaonuo.biz.modular.customer.entity.BizCustomer;
import vip.xiaonuo.biz.modular.customer.entity.BizCustomerAccount;
import vip.xiaonuo.biz.modular.customer.enums.BizCustomerAccountEnum;
import vip.xiaonuo.biz.modular.customer.param.BizCustomerAccountIdParam;
import vip.xiaonuo.biz.modular.user.entity.BizUser;
import vip.xiaonuo.biz.modular.user.enums.BizUserStatusEnum;
import vip.xiaonuo.biz.modular.user.mapper.BizUserMapper;
import vip.xiaonuo.biz.modular.user.service.BizUserService;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizsupplier.entity.BizSupplierAccount;
import vip.xiaonuo.biz.modular.bizsupplier.mapper.BizSupplierAccountMapper;
import vip.xiaonuo.biz.modular.bizsupplier.service.BizSupplierAccountService;
import vip.xiaonuo.common.util.CommonCryptogramUtil;
import vip.xiaonuo.dev.api.DevConfigApi;
import vip.xiaonuo.sys.api.SysUserApi;

import java.util.List;

/**
 * 供应商账号信息Service接口实现类
 *
 * @author fanzherong
 * @date  2025/05/29 14:47
 **/
@Service
public class BizSupplierAccountServiceImpl extends ServiceImpl<BizSupplierAccountMapper, BizSupplierAccount> implements BizSupplierAccountService {

    @Resource
    private BizUserService bizUserService;

    @Resource
    private BizUserMapper bizUserMapper;

    @Resource
    private DevConfigApi devConfigApi;

    private static final String SNOWY_SYS_DEFAULT_PASSWORD_KEY = "SNOWY_SYS_DEFAULT_PASSWORD";
    @Resource
    private SysUserApi sysUserApi;

    @Override
    public Page<BizSupplierAccount> page(BizSupplierAccountPageParam bizSupplierAccountPageParam) {
        QueryWrapper<BizSupplierAccount> queryWrapper = new QueryWrapper<BizSupplierAccount>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizSupplierAccountPageParam.getSupplierId())){
            queryWrapper.lambda().like(BizSupplierAccount::getSupplierId,bizSupplierAccountPageParam.getSupplierId());
        }
        queryWrapper.lambda().eq(BizSupplierAccount::getDeleteFlag, "NOT_DELETE");
        if(ObjectUtil.isAllNotEmpty(bizSupplierAccountPageParam.getSortField(), bizSupplierAccountPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizSupplierAccountPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizSupplierAccountPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizSupplierAccountPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(BizSupplierAccount::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizSupplierAccountAddParam bizSupplierAccountAddParam) {
        //查询名称是否添加过
        long countName = this.count(new QueryWrapper<BizSupplierAccount>().lambda().eq(BizSupplierAccount::getSupplierAccount, bizSupplierAccountAddParam.getSupplierAccount())
                                                                                    .eq(BizSupplierAccount::getDeleteFlag, BizSupplierAccountEnum.NOT_DELETE.getValue()));
        if(countName>0){
            throw new CommonException("供应商账号已存在！");
        }
        BizSupplierAccount bizSupplierAccount = BeanUtil.toBean(bizSupplierAccountAddParam, BizSupplierAccount.class);

        //查询账号是否添加过
        if(ObjectUtil.isNotEmpty(bizSupplierAccount.getSupplierAccount())){
            addAccount(bizSupplierAccount);
        }

        //添加供应商账号
        this.save(bizSupplierAccount);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizSupplierAccountEditParam bizSupplierAccountEditParam) {
        //查询名称是否添加过
        long countName = this.count(new QueryWrapper<BizSupplierAccount>().lambda().eq(BizSupplierAccount::getSupplierAccount, bizSupplierAccountEditParam.getSupplierAccount())
                                                                                    .ne(BizSupplierAccount::getId, bizSupplierAccountEditParam.getId())
                                                                                    .eq(BizSupplierAccount::getDeleteFlag, BizSupplierAccountEnum.NOT_DELETE.getValue()));
        if(countName>0){
            throw new CommonException("供应商账号已存在！");
        }
        BizSupplierAccount bizSupplierAccount = this.queryEntity(bizSupplierAccountEditParam.getId());

        if(!StringUtils.equals(bizSupplierAccount.getSupplierAccount(),bizSupplierAccountEditParam.getSupplierAccount())){
            deleteAccount(bizSupplierAccount);
            bizSupplierAccount.setSupplierAccount(bizSupplierAccountEditParam.getSupplierAccount());
            addAccount(bizSupplierAccount);
        }

        BeanUtil.copyProperties(bizSupplierAccountEditParam, bizSupplierAccount);
        this.updateById(bizSupplierAccount);
    }

    public void addAccount(BizSupplierAccount bizSupplierAccount){
        //根据账号是否存在
        BizUser user = bizUserService.getOne(new QueryWrapper<BizUser>().lambda().
                eq(BizUser::getAccount, bizSupplierAccount.getSupplierAccount()).
                last("limit 1"));
        if(ObjectUtil.isNotNull(user)){
            throw new CommonException("供应商账号已经存在！");
        }

        // 添加供应商登录账号
        BizUser bizUser = new BizUser();
        bizUser.setCustomerId(bizSupplierAccount.getSupplierId());
        bizUser.setName(bizSupplierAccount.getSupplierAccount());
        bizUser.setAccount(bizSupplierAccount.getSupplierAccount());
        bizUser.setUserType("4");
        // 设置密码
        bizUser.setPassword(CommonCryptogramUtil.doHashValue(devConfigApi.getValueByKey(SNOWY_SYS_DEFAULT_PASSWORD_KEY)));
        // 设置状态
        bizUser.setUserStatus(BizUserStatusEnum.ENABLE.getValue());
        this.bizUserMapper.insert(bizUser);

        // 添加供应商角色
        this.sysUserApi.grantRoleType(bizUser.getId(), "供应商");
    }

    public void deleteAccount(BizSupplierAccount bizSupplierAccount){
        if(null != bizSupplierAccount){
            // 删除原本登录账号
            BizUser userOld = bizUserService.getOne(new QueryWrapper<BizUser>().lambda().
                    eq(BizUser::getAccount, bizSupplierAccount.getSupplierAccount()).
                    last("limit 1"));
            if(null != userOld){
                this.bizUserMapper.updateById(userOld);
            }
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizSupplierAccountIdParam> bizSupplierAccountIdParamList) {
        if(null != bizSupplierAccountIdParamList && 0 < bizSupplierAccountIdParamList.size()){
            for (BizSupplierAccountIdParam accountIdParam : bizSupplierAccountIdParamList){
                BizSupplierAccount account = this.queryEntity(accountIdParam.getId());
                deleteAccount(account);

                // 执行删除
                this.removeById(account.getId());
            }
        }
    }

    @Override
    public BizSupplierAccount detail(BizSupplierAccountIdParam bizSupplierAccountIdParam) {
        return this.queryEntity(bizSupplierAccountIdParam.getId());
    }

    @Override
    public BizSupplierAccount queryEntity(String id) {
        BizSupplierAccount bizSupplierAccount = this.getById(id);
        if(ObjectUtil.isEmpty(bizSupplierAccount)) {
            throw new CommonException("供应商账号信息不存在，id值为：{}", id);
        }
        return bizSupplierAccount;
    }
}
