/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizsupplier.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.PhoneUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import jakarta.annotation.Resource;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.auth.core.util.StpLoginUserUtil;
import vip.xiaonuo.biz.modular.bizsupplier.entity.BizSupplierAccount;
import vip.xiaonuo.biz.modular.bizsupplier.entity.BizSupplierTransport;
import vip.xiaonuo.biz.modular.bizsupplier.enums.BizSupplierAccountEnum;
import vip.xiaonuo.biz.modular.bizsupplier.enums.BizSupplierEnum;
import vip.xiaonuo.biz.modular.bizsupplier.service.BizSupplierAccountService;
import vip.xiaonuo.biz.modular.customer.entity.BizCustomer;
import vip.xiaonuo.biz.modular.customer.entity.BizCustomerAccount;
import vip.xiaonuo.biz.modular.customer.param.BizCustomerIdParam;
import vip.xiaonuo.biz.modular.user.entity.BizUser;
import vip.xiaonuo.biz.modular.user.enums.BizUserStatusEnum;
import vip.xiaonuo.biz.modular.user.mapper.BizUserMapper;
import vip.xiaonuo.biz.modular.user.service.BizUserService;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizsupplier.entity.BizSupplier;
import vip.xiaonuo.biz.modular.bizsupplier.mapper.BizSupplierMapper;
import vip.xiaonuo.biz.modular.bizsupplier.param.BizSupplierAddParam;
import vip.xiaonuo.biz.modular.bizsupplier.param.BizSupplierEditParam;
import vip.xiaonuo.biz.modular.bizsupplier.param.BizSupplierIdParam;
import vip.xiaonuo.biz.modular.bizsupplier.param.BizSupplierPageParam;
import vip.xiaonuo.biz.modular.bizsupplier.service.BizSupplierService;
import vip.xiaonuo.common.util.CommonCryptogramUtil;
import vip.xiaonuo.dev.api.DevConfigApi;
import vip.xiaonuo.sys.api.SysUserApi;

import java.util.List;

/**
 * 供货商Service接口实现类
 *
 * @author fanzherong
 * @date  2025/03/21 10:38
 **/
@Service
public class BizSupplierServiceImpl extends ServiceImpl<BizSupplierMapper, BizSupplier> implements BizSupplierService {

    private static final String SNOWY_SYS_DEFAULT_PASSWORD_KEY = "SNOWY_SYS_DEFAULT_PASSWORD";

    @Resource
    private BizSupplierAccountService bizSupplierAccountService;

    @Resource
    private BizUserService bizUserService;

    @Resource
    private BizUserMapper bizUserMapper;

    @Resource
    private DevConfigApi devConfigApi;

    @Resource
    private SysUserApi sysUserApi;

    @Override
    public Page<BizSupplier> page(BizSupplierPageParam bizSupplierPageParam) {
        QueryWrapper<BizSupplier> queryWrapper = new QueryWrapper<BizSupplier>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizSupplierPageParam.getSupplierName())){
            queryWrapper.lambda().like(BizSupplier::getSupplierName,bizSupplierPageParam.getSupplierName());
        }
        if(ObjectUtil.isNotEmpty(bizSupplierPageParam.getSupplierContactName())){
            queryWrapper.lambda().like(BizSupplier::getSupplierContactName,bizSupplierPageParam.getSupplierContactName());
        }
        if(StpLoginUserUtil.getLoginUser().getRoleCodeList().contains("supplier")){
            //供应商角色查询自己
            queryWrapper.lambda().eq(BizSupplier::getId,StpLoginUserUtil.getLoginUser().getCustomerId());
        }
        queryWrapper.lambda().eq(BizSupplier::getDeleteFlag, "NOT_DELETE");
        queryWrapper.lambda().orderByDesc(BizSupplier::getCreateTime);
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizSupplierAddParam bizSupplierAddParam) {
        //校验手机号格式
        if(ObjectUtil.isNotEmpty(bizSupplierAddParam.getSupplierPhone())){
            if(!PhoneUtil.isMobile(bizSupplierAddParam.getSupplierPhone())) {
                throw new CommonException("手机号码：{}格式错误", bizSupplierAddParam.getSupplierPhone());
            }
        }
        //判断供货商是否存在
        long count = this.count(new QueryWrapper<BizSupplier>().lambda().eq(BizSupplier::getSupplierName, bizSupplierAddParam.getSupplierName())
                                                        .eq(BizSupplier::getDeleteFlag, BizSupplierEnum.NOT_DELETE.getValue()));
        if(count>0){
            throw new CommonException("供货商已存在！");
        }
        BizSupplier bizSupplier = BeanUtil.toBean(bizSupplierAddParam, BizSupplier.class);

        this.save(bizSupplier);

        //查询账号是否添加过
        if(ObjectUtil.isNotEmpty(bizSupplierAddParam.getSupplierPhone())){
            addUserAccount(bizSupplier);
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizSupplierEditParam bizSupplierEditParam) {
        //校验手机号格式
        if(ObjectUtil.isNotEmpty(bizSupplierEditParam.getSupplierPhone())){
            if(!PhoneUtil.isMobile(bizSupplierEditParam.getSupplierPhone())) {
                throw new CommonException("手机号码：{}格式错误", bizSupplierEditParam.getSupplierPhone());
            }
        }
        BizSupplier bizSupplier = this.queryEntity(bizSupplierEditParam.getId());
        if(!StringUtils.equals(bizSupplier.getSupplierName(),bizSupplierEditParam.getSupplierName())){
            //修改过供货商名称，判断供货商是否存在
            long count = this.count(new QueryWrapper<BizSupplier>().lambda().eq(BizSupplier::getSupplierName, bizSupplierEditParam.getSupplierName())
                                                                    .ne(BizSupplier::getId, bizSupplierEditParam.getId())
                                                                    .eq(BizSupplier::getDeleteFlag, BizSupplierEnum.NOT_DELETE.getValue()));
            if(count>0){
                throw new CommonException("供货商名称已存在！");
            }
        }
        if(!StringUtils.equals(bizSupplier.getSupplierPhone(),bizSupplierEditParam.getSupplierPhone())){
            //修改过供货商名称，判断供货商是否存在
            long count = this.count(new QueryWrapper<BizSupplier>().lambda().eq(BizSupplier::getSupplierPhone, bizSupplierEditParam.getSupplierPhone())
                    .ne(BizSupplier::getId, bizSupplierEditParam.getId())
                    .eq(BizSupplier::getDeleteFlag, BizSupplierEnum.NOT_DELETE.getValue()));
            if(count>0){
                throw new CommonException("供货商手机号已存在！");
            }
        }
        if(!StringUtils.equals(bizSupplier.getSupplierPhone(),bizSupplierEditParam.getSupplierPhone())){
            deleteUserAccount(bizSupplier.getId());
            bizSupplier.setSupplierPhone(bizSupplierEditParam.getSupplierPhone());
            addUserAccount(bizSupplier);
        }
        BeanUtil.copyProperties(bizSupplierEditParam, bizSupplier);
        this.updateById(bizSupplier);
    }

    public void addUserAccount(BizSupplier bizSupplier){
        //根据账号是否存在
        BizUser user = bizUserService.getOne(new QueryWrapper<BizUser>().lambda().
                eq(BizUser::getAccount, bizSupplier.getSupplierPhone()).
                last("limit 1"));
        if(ObjectUtil.isNotNull(user)){
            throw new CommonException("供应商手机号已经存在！");
        }

        // 添加供应商登录账号
        BizUser bizUser = new BizUser();
        bizUser.setCustomerId(bizSupplier.getId());
        bizUser.setName(bizSupplier.getSupplierPhone());
        bizUser.setAccount(bizSupplier.getSupplierPhone());
        bizUser.setUserType("4");
        // 设置密码
        bizUser.setPassword(CommonCryptogramUtil.doHashValue(devConfigApi.getValueByKey(SNOWY_SYS_DEFAULT_PASSWORD_KEY)));
        // 设置状态
        bizUser.setUserStatus(BizUserStatusEnum.ENABLE.getValue());
        this.bizUserMapper.insert(bizUser);

        // 添加供应商角色
        this.sysUserApi.grantRoleType(bizUser.getId(), "供应商");

        BizSupplierAccount bizSupplierAccount = new BizSupplierAccount();
        bizSupplierAccount.setSupplierId(bizSupplier.getId());
        bizSupplierAccount.setSupplierAccount(bizSupplier.getSupplierPhone());
        bizSupplierAccountService.save(bizSupplierAccount);
    }

    public void deleteUserAccount(String bizSupplierId){
        if(null != bizSupplierId) {
            // 删除供应商对应的子账号
            List<BizSupplierAccount> list = bizSupplierAccountService.list(new QueryWrapper<BizSupplierAccount>().lambda().eq(BizSupplierAccount::getSupplierId, bizSupplierId));
            for (BizSupplierAccount bizSupplierAccount : list) {
                bizSupplierAccountService.removeById(bizSupplierAccount);

                // 删除用户账号
                List<BizUser> userList = bizUserService.list(new QueryWrapper<BizUser>().lambda()
                        .eq(BizUser::getAccount, bizSupplierAccount.getSupplierAccount()));
                bizUserService.removeByIds(CollStreamUtil.toList(userList, BizUser::getId));
            }
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizSupplierIdParam> bizSupplierIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizSupplierIdParamList, BizSupplierIdParam::getId));

        for(BizSupplierIdParam bizSupplierIdParam : bizSupplierIdParamList){
            deleteUserAccount(bizSupplierIdParam.getId());
        }
    }

    @Override
    public BizSupplier detail(BizSupplierIdParam bizSupplierIdParam) {
        return this.queryEntity(bizSupplierIdParam.getId());
    }

    @Override
    public BizSupplier queryEntity(String id) {
        BizSupplier bizSupplier = this.getById(id);
        if(ObjectUtil.isEmpty(bizSupplier)) {
            throw new CommonException("供货商不存在，id值为：{}", id);
        }
        return bizSupplier;
    }

    @Override
    public List<BizSupplier> getList(BizSupplierPageParam bizSupplierPageParam) {
        QueryWrapper<BizSupplier> queryWrapper = new QueryWrapper<BizSupplier>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizSupplierPageParam.getSupplierName())){
            queryWrapper.lambda().like(BizSupplier::getSupplierName,bizSupplierPageParam.getSupplierName());
        }
        if(ObjectUtil.isNotEmpty(bizSupplierPageParam.getSupplierContactName())){
            queryWrapper.lambda().like(BizSupplier::getSupplierContactName,bizSupplierPageParam.getSupplierContactName());
        }
        if(ObjectUtil.isNotEmpty(bizSupplierPageParam.getTransportType())){
            if(StringUtils.equals(bizSupplierPageParam.getTransportType(),"1")){
                queryWrapper.lambda().in(BizSupplier::getTransportType,"1","3");
            }
            if(StringUtils.equals(bizSupplierPageParam.getTransportType(),"2")){
                queryWrapper.lambda().in(BizSupplier::getTransportType,"2","3");
            }
        }
        queryWrapper.lambda().eq(BizSupplier::getDeleteFlag, "NOT_DELETE");
        queryWrapper.lambda().orderByDesc(BizSupplier::getCreateTime);
        return this.list(queryWrapper);
    }
}
